@@ -7,6 +7,7 @@ OC.L10N.register(
     "Activity feed" : "Fonte delle attività",
     "Your settings have been updated." : "Le tue impostazioni sono state aggiornate.",
     "Settings have been updated." : "Le impostazioni sono state aggiornate.",
+    "remote user" : "utente remoto",
     "Recent activity" : "Attività recente",
     "No activities" : "Nessuna attività",
     "More activities" : "Altre attività",
@@ -20,6 +21,8 @@ OC.L10N.register(
     "Hello %s," : "Ciao %s,",
     "There was some activity at %s" : "Attività registrata su %s",
     "_and %n more _::_and %n more _" : ["e %n altro ","e %n altri ","e %n altri "],
+    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Puoi cambiare la frequenza di queste email o disattivarle nelle <a href=\"%s\">impostazioni</a>.",
+    "You can change the frequency of these emails or disable them in the settings: %s" : "Puoi cambiare la frequenza di queste email o disattivarle nelle impostazioni: %s",
     "Mail" : "Posta",
     "Push" : "Push",
     "Activity" : "Attività",
