@@ -758,6 +758,10 @@ class FederatedUserService {
 	 * @return FederatedUser
 	 */
 	public function generateFederatedUser(string $federatedId, int $type = 0): FederatedUser {
+		if ($federatedId === '') {
+			throw new MemberNotFoundException('empty user id');
+		}
+
 		if ($type === Member::TYPE_MAIL) {
 			$federatedId = strtolower($federatedId);
 		}
@@ -974,7 +978,9 @@ class FederatedUserService {
 
 		$circle = $this->getSingleCircle($federatedUser, $generate);
 		$federatedUser->setSingleId($circle->getSingleId());
-		$federatedUser->setDisplayName($circle->getDisplayName());
+		if ($federatedUser->getUserType() !== Member::TYPE_USER || $federatedUser->getDisplayName() === '') {
+			$federatedUser->setDisplayName($circle->getDisplayName());
+		}
 		$federatedUser->setBasedOn($circle);
 	}
 
