@@ -60,11 +60,11 @@ OC.L10N.register(
     "Date:" : "Датум:",
     "Where:" : "Каде: ",
     "Description:" : "Опис:",
-    "_%n year_::_%n years_" : ["една година","%n години"],
+    "_%n year_::_%n years_" : ["%n година","%n години"],
     "_%n month_::_%n months_" : ["%n месец","%n месеци"],
-    "_%n day_::_%n days_" : ["еден ден","%n дена"],
-    "_%n hour_::_%n hours_" : ["еден час","%n часа"],
-    "_%n minute_::_%n minutes_" : ["една минута","%n минути"],
+    "_%n day_::_%n days_" : ["%n ден","%n дена"],
+    "_%n hour_::_%n hours_" : ["%n час","%n часа"],
+    "_%n minute_::_%n minutes_" : ["%n минута","%n минути"],
     "%s (in %s)" : "%s (во %s)",
     "%s (%s ago)" : "%s (пред %s)",
     "Calendar: %s" : "Календар: %s",
@@ -172,7 +172,6 @@ OC.L10N.register(
     "Failed to load availability" : "Неуспешно вчитување на достапноста",
     "Saved availability" : "Достапноста е зачувана",
     "Failed to save availability" : "Неуспешно зачувување на достапноста",
-    "Time zone:" : "Временска зона:",
     "to" : "до",
     "Delete slot" : "Избриши слот",
     "No working hours set" : "Не се поставени работни часови",
@@ -181,6 +180,9 @@ OC.L10N.register(
     "Pick a start time for {dayName}" : "Избери почетно време за {dayName}",
     "Pick a end time for {dayName}" : "Избери крајно време за {dayName}",
     "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Автоматско поставување на статус во \"Не вознемирувај\" недостапен за да ги занемите сите известувања.",
+    "Cancel" : "Откажи",
+    "Import" : "Увези",
+    "Reset to default" : "Ресетирај на стандардно",
     "Availability" : "Достапност",
     "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Ако ги поставите работните часови, другите корисници ќе можат да видат кога сте слободни за да можат да закажат состанок.",
     "Absence" : "Отсуство",
@@ -202,7 +204,6 @@ OC.L10N.register(
     "Are you accepting the invitation?" : "Дали ја прифаќате поканата?",
     "Tentative" : "Прелиминарно",
     "Your attendance was updated successfully." : "Вашето присуство е успешно ажурирано.",
-    "Time:" : "Време:",
-    "Could not open file" : "Неможе да се отвори датотеката"
+    "Time zone:" : "Временска зона:"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
