@@ -47,18 +47,18 @@ OC.L10N.register(
     "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Sdílejte se mnou prostřednictvím mého #Nextcloud identifikátoru v rámci federovaného cloudu – více na {url}",
     "Share with me through my #Nextcloud Federated Cloud ID" : "Sdílejte se mnou pomocí mého #Nextcloud identifikátoru v rámci federovaného cloudu",
     "Share with me via Nextcloud" : "Sdílet se mnou přes Nextcloud",
-    "Cloud ID copied to the clipboard" : "Cloudový identifikátor zkopírován do schránky",
-    "Copy to clipboard" : "Zkopírovat do schránky",
+    "Cloud ID copied" : "Cloudový identifikátor zkopírován",
+    "Copy" : "Zkopírovat",
     "Clipboard not available. Please copy the cloud ID manually." : "Schránka není k dispozici. Zkopírujte cloudový identifikátor ručně.",
     "Copied!" : "Zkopírováno",
     "Federated Cloud" : "Federovaný cloud",
-    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Můžete sdílet s kýmkoliv, kdo používá Nextcloud nebo jiný server či služby, kompatibilní se standardem Open Cloud Mesh (OCM)! Stačí do dialogu pro sdílení zadat jejich jejich identif. v rámci sdruženého cloudu. Má podobu person@cloud.example.com",
     "Your Federated Cloud ID" : "Váš identifikátor v rámci fedorovaného cloudu",
     "Share it so your friends can share files with you:" : "Podělte se o to, aby mohli vaši přátelé s vámi mohli sdílet soubory:",
     "Facebook" : "Facebook",
     "X (formerly Twitter)" : "X (dříve Twitter)",
     "formerly Twitter" : "dříve Twitter",
     "Mastodon" : "Mastodon",
+    "Bluesky" : "Bluesky",
     "Add to your website" : "Přidat na svou webovou stránku",
     "HTML Code:" : "HTML kód:",
     "Cancel" : "Storno",
@@ -66,6 +66,9 @@ OC.L10N.register(
     "Remote share" : "Vzdálené sdílení",
     "Do you want to add the remote share {name} from {owner}@{remote}?" : "Chcete přidat vzdálené sdílení {name} od {owner}@{remote}?",
     "Remote share password" : "Heslo ke vzdálenému sdílení",
-    "Incoming share could not be processed" : "Příchozí sdílení se nepodařilo zpracovat"
+    "Incoming share could not be processed" : "Příchozí sdílení se nepodařilo zpracovat",
+    "Cloud ID copied to the clipboard" : "Cloudový identifikátor zkopírován do schránky",
+    "Copy to clipboard" : "Zkopírovat do schránky",
+    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Můžete sdílet s kýmkoliv, kdo používá Nextcloud nebo jiný server či služby, kompatibilní se standardem Open Cloud Mesh (OCM)! Stačí do dialogu pro sdílení zadat jejich jejich identif. v rámci sdruženého cloudu. Má podobu person@cloud.example.com"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
