@@ -23,34 +23,43 @@ OC.L10N.register(
     "Sharing" : "Deling",
     "Federated file sharing" : "Sammenkoblet fildeling",
     "Provide federated file sharing across servers" : "Lever sammenkoblet fildeling på tværs af servere",
+    "Confirm data upload to lookup server" : "Bekræft dataoverførsel til opslagsserver",
+    "When enabled, all account properties (e.g. email address) with scope visibility set to \"published\", will be automatically synced and transmitted to an external system and made available in a public, global address book." : "Når det er aktiveret, så vil alle kontoegenskaber (f.eks. e-mailadresse) med omfangssynlighed indstillet til \"publiceret\", automatisk blive synkroniseret og transmitteret til et eksternt system og gjort tilgængelige i en offentlig, global adressebog.",
     "Disable upload" : "Deaktivér upload",
     "Enable data upload" : "Aktivér data upload",
+    "Confirm querying lookup server" : "Bekræft forespørgsel til opslagsserver",
+    "When enabled, the search input when creating shares will be sent to an external system that provides a public and global address book." : "Når det er aktiveret, vil søgeinputtet, når der oprettes delinger, blive sendt til et eksternt system, der leverer en offentlig og global adressebog.",
+    "This is used to retrieve the federated cloud ID to make federated sharing easier." : "Dette bruges til at hente det fødererede cloud ID for at gøre fødereret deling nemmere.",
+    "Moreover, email addresses of users might be sent to that system in order to verify them." : "Desuden kan e-mailadresser på brugere blive sendt til dette system for at verificere dem.",
+    "Disable querying" : "Deaktivér forespørgsler",
+    "Enable querying" : "Aktivér forespørgsler",
     "Unable to update federated files sharing config" : "Kan ikke opdatere sammenkoblet fildelingskonfiguration",
     "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Juster, hvordan brugere kan dele mellem servere. Dette inkluderer også delinger mellem brugere på denne server, hvis de bruger sammenkoblet deling.",
     "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Tillad brugere på denne server at sende shares til andre servere (denne mulighed giver også WebDAV adgang til offentlige shares)",
     "Allow people on this server to receive shares from other servers" : "Tillad brugere på denne server at modtage delinger fra andre servere",
     "Allow people on this server to send shares to groups on other servers" : "Tillad brugere på denne server at sende delinger til grupper på andre servere",
     "Allow people on this server to receive group shares from other servers" : "Tillad brugere på denne server at modtage gruppedelinger fra andre servere",
+    "The lookup server is only available for global scale." : "Opslagsserveren er kun tilgængelig for globalt omfang.",
     "Search global and public address book for people" : "Søg global og offentlig adressebog efter personer",
     "Allow people to publish their data to a global and public address book" : "Tillad brugere at udgive deres data til en global og offentlig adressebog",
     "Trusted federation" : "Betroet sammenkobling",
     "Automatically accept shares from trusted federated accounts and groups by default" : "Accepter automatisk delinger fra betorede sammenkoblings konti og grupper som standard",
     "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Del med mig gennem min #Nextcloud Sammenkoblings Cloud ID, se {url}",
     "Share with me through my #Nextcloud Federated Cloud ID" : "Del med mig gennem min #Nextcloud sammenkoblings Cloud ID",
-    "Cloud ID copied to the clipboard" : "Cloud ID er kopieret til udklipsholderen.",
-    "Copy to clipboard" : "Kopier til udklipsholder",
+    "Share with me via Nextcloud" : "Del med mig gennem Nextcloud",
+    "Cloud ID copied" : "Cloud ID kopieret",
+    "Copy" : "Kopiér",
     "Clipboard not available. Please copy the cloud ID manually." : "Udklipsholder ikke tilgængelig. Kopier venligst Cloud ID'et manuelt.",
     "Copied!" : "Kopieret!",
     "Federated Cloud" : "Sammenkoblet Cloud",
-    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Du kan dele med alle, der bruger en Nextcloud-server eller andre Open Cloud Mesh (OCM)-kompatible servere og tjenester! Indsæt blot deres Sammenkoblings Cloud ID i delingsdialogen. Det ligner person@cloud.example.com",
     "Your Federated Cloud ID" : "Dit sammenkoblings Cloud ID",
     "Share it so your friends can share files with you:" : "Del så dine venner kan dele filer med dig:",
     "Facebook" : "Facebook",
     "X (formerly Twitter)" : "X (tidligere Twitter)",
     "formerly Twitter" : "tidligere Twitter",
     "Mastodon" : "Mastodont",
+    "Bluesky" : "Bluesky",
     "Add to your website" : "Tilføj til dit websted",
-    "Share with me via Nextcloud" : "Del med mig gennem Nextcloud",
     "HTML Code:" : "HTML kode:",
     "Cancel" : "Annuller",
     "Add remote share" : "Tilføj ekstern deling",
@@ -58,9 +67,8 @@ OC.L10N.register(
     "Do you want to add the remote share {name} from {owner}@{remote}?" : "Ønsker du at tilføje det eksterne drev  {name} fra {owner}@{remote}?",
     "Remote share password" : "Fjerndrev adgangskode",
     "Incoming share could not be processed" : "Indgående deling kunne ikke behandles",
-    "Clipboard is not available" : "Udklipsholderen er ikke tilgængelig",
-    "Your Federated Cloud ID:" : "Din Sammenkoblings Cloud ID:",
-    "Twitter" : "Twitter",
-    "Diaspora" : "Diaspora"
+    "Cloud ID copied to the clipboard" : "Cloud ID er kopieret til udklipsholderen.",
+    "Copy to clipboard" : "Kopier til udklipsholder",
+    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Du kan dele med alle, der bruger en Nextcloud-server eller andre Open Cloud Mesh (OCM)-kompatible servere og tjenester! Indsæt blot deres Sammenkoblings Cloud ID i delingsdialogen. Det ligner person@cloud.example.com"
 },
 "nplurals=2; plural=(n != 1);");
