@@ -51,10 +51,13 @@ OC.L10N.register(
     "You do not have permission to create a file at the specified location" : "Vde. non ten permiso para crear un ficheiro na localización especificada",
     "The file could not be converted." : "Non foi posíbel converter o ficheiro.",
     "Could not get relative path to converted file" : "Non foi posíbel obter a ruta relativa ao ficheiro convertido",
+    "Limit must be a positive integer." : "O límite debe ser un número enteiro positivo.",
+    "The replacement character may only be a single character." : "O carácter de substitución só poderá ser un carácter único.",
+    "Filename sanitization already started." : "Xa foi iniciado o saneamento dos nomes do ficheiro.",
+    "No filename sanitization inprogress." : "O saneamento dos nomes de ficheiro non está en proceso.",
     "Favorite files" : "Ficheiros favoritos",
     "No favorites" : "Non hai favoritos",
     "More favorites" : "Máis favoritos",
-    "Upload (max. %s)" : "Envío (máx. %s)",
     "Accept" : "Aceptar",
     "Reject" : "Rexeitar",
     "Incoming ownership transfer from {user}" : "Transferencia da propiedade entrante de {user}",
@@ -69,10 +72,6 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Completouse a transferencia da propiedade de {path} cara a {user}.",
     "in %s" : "en %s",
     "Transferred from %1$s on %2$s" : "Transferido desde %1$s en %2$s",
-    "Files compatibility" : "Compatibilidade de ficheiros",
-    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Permitir restrinxir os nomes de ficheiros para garantir que os ficheiros se poidan sincronizar con todos os clientes. De xeito predeterminado, permítense todos os nomes de ficheiro válidos en POSIX (p. ex., Linux ou macOS).",
-    "Enforce Windows compatibility" : "Forzar a compatibilidade con Windows",
-    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Isto bloqueará os nomes de ficheiros non válidos en sistemas Windows, coma o uso de nomes reservados ou caracteres especiais. Porén, isto non forzará á compatibilidade da distinción entre maiúsculas e minúsculas.",
     "File Management" : "Xestión de ficheiros",
     "Home" : "Inicio",
     "Target folder does not exist any more" : "O cartafol de destino xa non existe",
@@ -95,20 +94,28 @@ OC.L10N.register(
     "Invalid filename." : "Nome de ficheiro incorrecto.",
     "Renamed \"{oldName}\" to \"{newName}\"" : "Cambiouse o nome de «{oldName}» a «{newName}»",
     "Rename file" : "Cambiar o nome do ficheiro",
+    "Folder" : "Cartafol",
+    "Unknown file type" : "Tipo de ficheiro descoñecido",
+    "{ext} image" : "Imaxe {ext}",
+    "{ext} video" : "Vídeo {ext}",
+    "{ext} audio" : "Son {ext}",
+    "{ext} text" : "Texto {ext}",
     "Pending" : "Pendentes",
     "Unknown date" : "Data descoñecida",
     "Clear filter" : "Limpar o filtro",
     "Modified" : "Modificado",
+    "Search everywhere" : "Buscar en todos os sitios",
     "Type" : "Escribir",
     "Active filters" : "Filtros activos",
     "Remove filter" : "Retirar o filtro",
     "Total rows summary" : "Resumo total de filas",
     "Toggle selection for all files and folders" : "Conmutar a selección para todos os ficheiros e cartafoles",
     "Name" : "Nome",
+    "File type" : "Tipo do ficheiro",
     "Size" : "Tamaño",
-    "\"{displayName}\" failed on some elements" : "Produciuse un fallo nalgúns elementos de «{displayName}»",
-    "\"{displayName}\" batch action executed successfully" : "A acción por lotes «{displayName}» executouse correctamente",
-    "\"{displayName}\" action failed" : "Produciuse un fallo na acción «{displayName}»",
+    "{displayName}: failed on some elements" : "Produciuse un fallo nalgúns elementos de {displayName}",
+    "{displayName}: done" : "{displayName}: feito",
+    "{displayName}: failed" : "{displayName}: produciuse un fallo",
     "Actions" : "Accións",
     "(selected)" : "(seleccionado)",
     "List of files and folders." : "Lista de ficheiros e cartafoles",
@@ -116,7 +123,11 @@ OC.L10N.register(
     "Column headers with buttons are sortable." : "As cabeceiras das columnas con botóns pódense ordenar.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Esta lista non se representa de xeito completo por mor do rendemento. Os ficheiros represéntanse mentres se despraza pola lista.",
     "File not found" : "Non se atopou o ficheiro",
-    "{count} selected" : "{count} seleccionados",
+    "_{count} selected_::_{count} selected_" : ["{count} seleccionado","{count} seleccionados"],
+    "Search everywhere …" : "Buscar en todos os sitios…",
+    "Search here …" : "Buscar aquí…",
+    "Search scope options" : "Opcións do alcance da busca",
+    "Search here" : "Buscar aquí",
     "{usedQuotaByte} used" : "{usedQuotaByte} usado",
     "{used} of {quota} used" : "Usados {used} de {quota}",
     "{relative}% used" : "{relative}% usado",
@@ -128,6 +139,25 @@ OC.L10N.register(
     "Create new folder" : "Crear un cartafol novo",
     "This name is already in use." : "Este nome xa está a ser usado",
     "Create" : "Crear",
+    "Files starting with a dot are hidden by default" : "Os ficheiros que comezan cun punto están agochados de xeito predeterminado",
+    "Failed to start filename sanitization." : "Produciuse un fallo ao iniciar o saneamento dos nomes de ficheiro.",
+    "Failed to refresh filename sanitization status." : "Produciuse un fallo ao actualizar o estado de saneamento dos nomes de ficheiro.",
+    "Filename sanitization in progress." : "O saneamento dos nomes de ficheiro está en proceso.",
+    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "Xa foron procesadas {processedUsers} de {totalUsers} contas.",
+    "Preparing …" : "Preparando…",
+    "Refresh" : "Actualizar",
+    "All files have been santized for Windows filename support." : "Todos os ficheiros foron saneados para que sexan compatíbeis cos nomes de ficheiro de Windows.",
+    "Some files could not be sanitized, please check your logs." : "Non foi posíbel sanear algúns ficheiros, revise os rexistros.",
+    "Sanitization errors" : "Erros de saneamento",
+    "Not sanitized filenames" : "Nomes de ficheiro sen sanear",
+    "Windows filename support has been enabled." : "Está activada a compatibilidade cos nomes de ficheiro de Windows.",
+    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "Aínda que isto impide aos usuarios crear novos ficheiros con nomes de ficheiro non compatíbeis, os ficheiros existentes aínda non foron renomeados e, polo tanto, aínda poden rachar a sincronización en Windows.",
+    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "Pode activar o cambio de nome dos ficheiros con nomes non válidos, isto farase en segundo plano e pode levar algún tempo.",
+    "Please note that this may cause high workload on the sync clients." : "Teña en conta que isto pode causar unha alta carga de traballo nos clientes de sincronización.",
+    "Limit" : "Límite",
+    "This allows to configure how many users should be processed in one background job run." : "Isto permite configurar o número de usuarios que deben ser procesados nunha execución de tarefas en segundo plano.",
+    "Sanitize filenames" : "Sanear os nomes dos ficheiros",
+    "(starting)" : "(iniciando)",
     "Fill template fields" : "Encher os campos do modelo",
     "Submitting fields …" : "Enviando os campos...",
     "Submit" : "Enviar",
@@ -152,7 +182,7 @@ OC.L10N.register(
     "Adding the file extension \"{new}\" may render the file unreadable." : "Engadir a extensión de ficheiro «{new}» pode facer que o ficheiro sexa ilexíbel.",
     "Do not show this dialog again." : "Non volver amosar este diálogo",
     "Select file or folder to link to" : "Seleccione o ficheiro ou cartafol ao que ligar",
-    "Choose {file}" : "Escoller  {file}",
+    "Choose {file}" : "Escoller {file}",
     "Share" : "Compartir",
     "Shared by link" : "Compartido por ligazón",
     "Shared" : "Compartido",
@@ -165,60 +195,72 @@ OC.L10N.register(
     "Error during upload: {message}" : "Produciuse un erro durante o envío: {message}",
     "Error during upload, status code {status}" : "Produciuse un erro durante o envío, código de estado {status}",
     "Unknown error during upload" : "Produciuse un erro descoñecido durante o envío",
-    "\"{displayName}\" action executed successfully" : "A acción «{displayName}» executouse correctamente",
     "Loading current folder" : "Cargando o cartafol actual",
     "Retry" : "Volver tentar",
     "No files in here" : "Aquí non hai ficheiros",
     "Upload some content or sync with your devices!" : "Envíe algún contido ou sincronice cos seus dispositivos!",
     "Go back" : "Volver",
-    "Filter file names …" : "Filtrar os nomes de ficheiro…",
     "Views" : "Vistas",
     "Files settings" : "Axustes de Ficheiros",
     "Your files" : "Os seus ficheiros",
     "Open in files" : "Abrir en ficheiros",
     "File cannot be accessed" : "Non é posíbel acceder ao ficheiro",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Non foi posíbel atopar o ficheiro ou non ten permiso para velo. Pídalle ao remitente que o comparta.",
+    "No search results for “{query}”" : "Sen resultados de busca para «{query}»",
+    "Search for files" : "Buscar ficheiros",
     "Clipboard is not available" : "O portapapeis non está dispoñíbel",
-    "WebDAV URL copied to clipboard" : "O URL de WebDAV foi copiado no portapapeis",
+    "WebDAV URL copied" : "URL de WebDAV copiado",
+    "General" : "Xeral",
+    "Default view" : "Vista predeterminada",
+    "All files" : "Todos os ficheiros",
+    "Personal files" : "Ficheiros persoais",
     "Sort favorites first" : "Ordene antes os favoritos",
     "Sort folders before files" : "Ordenar os cartafoles diante dos ficheiros",
+    "Folder tree" : "Árbore de cartafoles",
+    "Appearance" : "Aparencia",
     "Show hidden files" : "Amosar os ficheiros agochados",
+    "Show file type column" : "Amosar a columna de tipo de ficheiro",
+    "Show file extensions" : "Amosar as extensións de ficheiro",
     "Crop image previews" : "Recortar a vista previa das imaxes",
-    "Enable the grid view" : "Activar á vista de grade",
-    "Enable folder tree" : "Activar a árbore de cartafoles",
     "Additional settings" : "Axustes adicionais",
     "WebDAV" : "WebDAV",
     "WebDAV URL" : "URL de WebDAV",
-    "Copy to clipboard" : "Copiar no portapapeis.",
-    "Use this address to access your Files via WebDAV" : "Empregue este enderezo para acceder ao seu Ficheiros mediante WebDAV",
-    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Se activou 2FA, cree e utilice un novo contrasinal de aplicación premendo aquí.",
+    "Copy" : "Copiar",
+    "How to access files using WebDAV" : "Como acceder aos ficheiros empregando WebDAV",
+    "Two-Factor Authentication is enabled for your account, and therefore you need to use an app password to connect an external WebDAV client." : "A autenticación de dous factores está activada para a súa conta e, polo tanto, necesita usar un contrasinal de aplicación para conectar un cliente WebDAV externo.",
     "Warnings" : "Advertencias",
-    "Prevent warning dialogs from open or reenable them." : "Impedir abrir ou reactivar os diálogos de advertencia",
-    "Show a warning dialog when changing a file extension." : "Amosar un diálogo de advertencia ao cambiar unha extensión de ficheiro.",
+    "Warn before changing a file extension" : "Advertir antes de cambiar unha extensión de ficheiro",
+    "Warn before deleting files" : "Advertir antes de borrar ficheiros",
     "Keyboard shortcuts" : "Atallos de teclado",
-    "Speed up your Files experience with these quick shortcuts." : "Acelere a súa experiencia con Ficheiros con estes atallos rápidos.",
-    "Open the actions menu for a file" : "Abrir o menú de accións dun ficheiro",
-    "Rename a file" : "Cambiar o nome dun ficheiro",
-    "Delete a file" : "Eliminar un ficheiro",
-    "Favorite or remove a file from favorites" : "Marcar como favorito ou retirar un ficheiro dos favoritos",
-    "Manage tags for a file" : "Xestionar etiquetas para un ficheiro",
+    "File actions" : "Accións de ficheiro",
+    "Rename" : "Cambiar o nome",
+    "Delete" : "Eliminar",
+    "Add or remove favorite" : "Engadir ou retirar favoritos",
+    "Manage tags" : "Xestionar as etiquetas",
     "Selection" : "Selección",
     "Select all files" : "Seleccionar todos os ficheiros",
-    "Deselect all files" : "Deseleccionar todos os ficheiros",
-    "Select or deselect a file" : "Seleccione ou deseleccione un ficheiro",
-    "Select a range of files" : "Seleccionar un intervalo de ficheiros",
+    "Deselect all" : "Deseleccionar todo",
+    "Select or deselect" : "Seleccionar ou deseleccionar",
+    "Select a range" : "Seleccionar un intervalo",
     "Navigation" : "Navegación",
-    "Navigate to the parent folder" : "Navegar ata o cartafol principal",
-    "Navigate to the file above" : "Navegar ata o ficheiro anterior",
-    "Navigate to the file below" : "Navegar ata o ficheiro seguinte",
-    "Navigate to the file on the left (in grid mode)" : "Navegar ata o ficheiro da esquerda (en modo de grade)",
-    "Navigate to the file on the right (in grid mode)" : "Navegar ata o ficheiro da dereita (en modo de grade)",
+    "Go to parent folder" : "Ir ao cartafol superior",
+    "Go to file above" : "Ir ao ficheiro de arriba",
+    "Go to file below" : "Ir ao ficheiro de abaixo",
+    "Go left in grid" : "Ir á esquerda na grella",
+    "Go right in grid" : "Ir á dereita na grella",
     "View" : "Ver",
-    "Toggle the grid view" : "Cambiar á vista de grade",
-    "Open the sidebar for a file" : "Abrir a barra lateral dun ficheiro",
+    "Toggle grid view" : "Alternar a vista como grade",
+    "Open file sidebar" : "Abrir a barra lateral do ficheiro",
     "Show those shortcuts" : "Amosar eses atallos",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Permitir restrinxir os nomes de ficheiros para garantir que os ficheiros se poidan sincronizar con todos os clientes. De xeito predeterminado, permítense todos os nomes de ficheiro válidos en POSIX (p. ex., Linux ou macOS).",
+    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Após activar os nomes de ficheiro compatíbeis con Windows, os ficheiros existentes xa non poden ser modificados, mais poden ser renomeados con novos nomes válidos polo seu propietario.",
+    "Failed to toggle Windows filename support" : "Poduciuse un fallo ao activar a compatibilidade cos nomes de ficheiro de Windows",
+    "Files compatibility" : "Compatibilidade de ficheiros",
+    "Enforce Windows compatibility" : "Forzar a compatibilidade con Windows",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Isto bloqueará os nomes de ficheiros non válidos en sistemas Windows, coma o uso de nomes reservados ou caracteres especiais. Porén, isto non forzará á compatibilidade da distinción entre maiúsculas e minúsculas.",
     "You" : "Vde.",
     "Shared multiple times with different people" : "Compartido varias veces con diferentes persoas",
+    "Unable to change the favorite state of the file" : "Non é posíbel cambiar o estado de favorito do ficheiro",
     "Error while loading the file data" : "Produciuse un erro ao cargar os datos do ficheiro",
     "Owner" : "Propietario",
     "Remove from favorites" : "Retirar de favoritos",
@@ -235,13 +277,14 @@ OC.L10N.register(
     "Failed to convert files: {message}" : "Produciuse un fallo ao converter os ficheiros: {message}",
     "All files failed to be converted" : "Non foi posíbel converter ningún ficheiro",
     "One file could not be converted: {message}" : "Non foi posíbel converter un ficheiro: {message}",
+    "_One file could not be converted_::_%n files could not be converted_" : ["Non foi posíbel converter un ficheiro","Non foi posíbel converter %n ficheiros"],
+    "_One file successfully converted_::_%n files successfully converted_" : ["Foi convertido correctamente un ficheiro","%n ficheiros foron convertidos correctamente"],
     "Files successfully converted" : "Os ficheiros foron convertidos correctamente",
     "Failed to convert files" : "Produciuse un fallo ao converter os ficheiros",
     "Converting file …" : "Convertendo o ficheiro…",
     "File successfully converted" : "O ficheiro foi convertido correctamente",
     "Failed to convert file: {message}" : "Produciuse un fallo ao converter o ficheiro: {message}",
     "Failed to convert file" : "Produciuse un fallo ao converter o ficheiro",
-    "Deletion cancelled" : "Foi cancelada a eliminación",
     "Leave this share" : "Deixar esta compartición",
     "Leave these shares" : "Deixar estas comparticións",
     "Disconnect storage" : "Desconectar o almacenamento",
@@ -252,39 +295,38 @@ OC.L10N.register(
     "Delete files" : "Eliminar ficheiros",
     "Delete folder" : "Eliminar o cartafol",
     "Delete folders" : "Eliminar cartafoles",
-    "Delete" : "Eliminar",
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Está a piques de eliminar definitivamente {count} elemento","Está a piques de eliminar definitivamente {count} elementos"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Está a piques de eliminar {count} elemento","Está a piques de eliminar {count} elementos"],
     "Confirm deletion" : "Confirmar a eliminación",
     "Cancel" : "Cancelar",
+    "Download" : "Descargar",
+    "The requested file is not available." : "O ficheiro solicitado non está dispoñible.",
+    "The requested files are not available." : "Os ficheiros solicitados non están dispoñíbeis",
     "Moving \"{source}\" to \"{destination}\" …" : "Movendo «{source}» a «{destination}»…",
     "Copying \"{source}\" to \"{destination}\" …" : "Copiando «{source}» en «{destination}»…",
+    "Destination is not a folder" : "O destino non é un cartafol",
+    "This file/folder is already in that directory" : "Este ficheiro/cartafol xa está nese directorio",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Non é posíbel mover un ficheiro/cartafol sobre si mesmo ou a un subcartafol de si mesmo",
     "(copy)" : "(copiar)",
     "(copy %n)" : "(copiar %n)",
-    "Move cancelled" : "Cancelouse o movemento",
     "A file or folder with that name already exists in this folder" : "Neste cartafol xa existe un ficheiro ou cartafol con ese nome",
     "The files are locked" : "Os ficheiros están bloqueados",
     "The file does not exist anymore" : "O ficheiro xa non existe",
     "Choose destination" : "Escoller o destino",
     "Copy to {target}" : "Copiar en {target}",
-    "Copy" : "Copiar",
     "Move to {target}" : "Mover a {target}",
     "Move" : "Mover",
     "Move or copy operation failed" : "Produciuse un erro na operación de copia ou de movemento",
     "Move or copy" : "Mover ou copiar",
-    "Cancelled move or copy of \"{filename}\"." : "Foi cancelado o movemento ou copia de «{filename}»",
-    "Cancelled move or copy operation" : "Foi cancelada a operación de movemento ou copia",
     "Open folder {displayName}" : "Abrir o cartafol  {displayName}",
     "Open in Files" : "Abrir en Ficheiros",
+    "Open locally" : "Abrir localmente",
+    "Failed to redirect to client" : "Produciuse un fallo ao redirixir ao cliente",
     "Open file locally" : "Abrir o ficheiro localmente",
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "O ficheiro debería abrirse agora no seu dispositivo. Se non é así, comprobe se ten instalada a aplicación de escritorio.",
     "Retry and close" : "Tentar de novo e pechar",
     "Open online" : "Abrir en liña",
-    "Failed to redirect to client" : "Produciuse un fallo ao redirixir ao cliente",
-    "Open locally" : "Abrir localmente",
-    "Rename" : "Cambiar o nome",
-    "Open details" : "Abrir detalles",
+    "Details" : "Detalles",
     "View in folder" : "Ver no cartafol",
     "Today" : "Hoxe",
     "Last 7 days" : "Últimos 7 días",
@@ -297,15 +339,15 @@ OC.L10N.register(
     "PDFs" : "PDF",
     "Folders" : "Cartafoles",
     "Audio" : "Son",
-    "Photos and images" : "Fotos e imaxes",
+    "Images" : "Imaxes",
     "Videos" : "Vídeos",
-    "New folder creation cancelled" : "Cancelouse a creación dun novo cartafol",
     "Created new folder \"{name}\"" : "Creouse un novo cartafol «{name}»",
     "Unable to initialize the templates directory" : "Non é posíbel iniciar o directorio de modelos",
     "Create templates folder" : "Crear o cartafol de modelos",
     "Templates" : "Modelos",
     "New template folder" : "Novo cartafol de modelos",
     "In folder" : "No cartafol",
+    "Search in all files" : "Buscar en todos os ficheiros",
     "Search in folder: {folder}" : "Buscar no cartafol: {folder}",
     "One of the dropped files could not be processed" : "Non foi posíbel procesar un dos ficheiros arrastrados",
     "Your browser does not support the Filesystem API. Directories will not be uploaded" : "O seu navegador non é compatíbel coa API do sistema de ficheiros. Os directorios non van ser enviados",
@@ -320,15 +362,16 @@ OC.L10N.register(
     "Files moved successfully" : "Ficheiros movidos correctamente",
     "Conflicts resolution skipped" : "Omitiuse a resolución dos conflitos",
     "Upload cancelled" : "Envío cancelado",
+    "Could not rename \"{oldName}\", it does not exist any more" : "Non foi posíbel cambiarlle o nome a «{oldName}», xa non existe",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "O nome «{newName}» xa se utiliza no cartafol «{dir}». Escolla un nome diferente.",
+    "Could not rename \"{oldName}\"" : "Non foi posíbel cambiarlle o nome a «{oldName}»",
     "This operation is forbidden" : "Esta operación está prohibida",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Este directorio non está dispoñíbel, consulte os ficheiros de rexistro ou póñase en contacto coa administración desta instancia.",
+    "This folder is unavailable, please try again later or contact the administration" : "Este cartafol non está dispoñíbel, ténteo de novo máis tarde ou póñase en contacto coa administración",
     "Storage is temporarily not available" : "O almacenamento non está dispoñíbel temporalmente",
     "Unexpected error: {error}" : "Produciuse un erro non agardado: {error}",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} cartafol","{folderCount} cartafoles"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} ficheiro","{fileCount} ficheiros"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 ficheiro e {folderCount} cartafol","1 ficheiro e {folderCount} cartafoles"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} ficheiro e 1 cartafol","{fileCount} ficheiros e 1 cartafol"],
-    "{fileCount} files and {folderCount} folders" : "{fileCount} ficheiros e {folderCount} cartafoles",
+    "_%n file_::_%n files_" : ["%n ficheiro","%n ficheiros"],
+    "_%n folder_::_%n folders_" : ["%n cartafol","%n cartafoles"],
+    "_%n hidden_::_%n hidden_" : ["%n agochado","%n agochados"],
     "Filename must not be empty." : "O nome de ficheiro non debe estar baleiro",
     "\"{char}\" is not allowed inside a filename." : "«{char}» non está permitido nun nome de ficheiro.",
     "\"{segment}\" is a reserved name and not allowed for filenames." : "«{segment}» é un nome reservado e non está permitido para os nomes de ficheiro.",
@@ -337,10 +380,7 @@ OC.L10N.register(
     "List of favorite files and folders." : "Lista de ficheiros e cartafoles favoritos.",
     "No favorites yet" : "Aínda non hai favoritos",
     "Files and folders you mark as favorite will show up here" : "Os ficheiros e cartafoles que marque como favoritos amosaranse aquí",
-    "All files" : "Todos os ficheiros",
     "List of your files and folders." : "Lista dos seus ficheiros e cartafoles",
-    "All folders" : "Todos os cartafoles",
-    "Personal files" : "Ficheiros persoais",
     "List of your files and folders that are not shared." : "Lista dos seus ficheiros e cartafoles que non están a seren compartidos.",
     "No personal files found" : "Non se atopou ningún ficheiro persoal",
     "Files that are not shared will show up here." : "Os ficheiros que non se comparten amosaranse aquí.",
@@ -348,12 +388,13 @@ OC.L10N.register(
     "List of recently modified files and folders." : "Lista de ficheiros e cartafoles modificados recentemente.",
     "No recently modified files" : "Non hai ficheiros modificados recentemente",
     "Files and folders you recently modified will show up here." : "Os ficheiros e cartafoles que modificou recentemente amosaranse aquí.",
+    "Search" : "Buscar",
+    "Search results within your files." : "Buscar resultados nos seus ficheiros.",
     "No entries found in this folder" : "Non se atopou ningunha entrada neste cartafol",
     "Select all" : "Seleccionar todo",
     "Upload too large" : "Envío grande de máis",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Os ficheiros que tenta enviar exceden do tamaño máximo permitido neste servidor",
     "File could not be found" : "Non foi posíbel atopar o ficheiro",
-    "Download" : "Descargar",
     "Show list view" : "Amosar a vista de lista",
     "Show grid view" : "Amosar a vista de grade",
     "Close" : "Pechar",
@@ -378,12 +419,12 @@ OC.L10N.register(
     "Edit locally" : "Editar localmente",
     "Open" : "Abrir",
     "Could not load info for file \"{file}\"" : "Non foi posíbel cargar información para o ficheiro «{file}»",
-    "Details" : "Detalles",
     "Please select tag(s) to add to the selection" : "Escolla a etiqueta(s) para engadir á selección",
     "Apply tag(s) to selection" : "Aplicar etiqueta(s) á selección",
     "Select directory \"{dirName}\"" : "Seleccione o directorio «{dirName}»",
     "Select file \"{fileName}\"" : "Seleccione o ficheiro «{fileName}»",
     "Unable to determine date" : "Non é posíbel determinar a data",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Este directorio non está dispoñíbel, consulte os ficheiros de rexistro ou póñase en contacto coa administración desta instancia.",
     "Could not move \"{file}\", target exists" : "Non foi posíbel mover «{file}», o destino xa existe",
     "Could not move \"{file}\"" : "Non foi posíbel mover «{file}»",
     "copy" : "copiar",
@@ -392,9 +433,6 @@ OC.L10N.register(
     "Copied {origin} inside {destination}" : "Copiado {origin} en {destination}",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "Copiado {origin} e outros {nbfiles} ficheiros en {destination} ",
     "{newName} already exists" : "Xa existe {newName}",
-    "Could not rename \"{fileName}\", it does not exist any more" : "Non foi posíbel cambiarlle o nome a «{fileName}», xa non existe",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "O nome «{targetName}» xa se utiliza no cartafol «{dir}». Escolla outro nome.",
-    "Could not rename \"{fileName}\"" : "Non foi posíbel cambiarlle o nome a «{fileName}»",
     "Could not create file \"{file}\"" : "Non foi posíbel crear o ficheiro «{file}»",
     "Could not create file \"{file}\" because it already exists" : "Non foi posíbel crear o ficheiro «{file}» por mor de que xa existe",
     "Could not create folder \"{dir}\" because it already exists" : "Non foi posíbel crear o cartafol «{dir}» por mor de que xa existe",
@@ -402,8 +440,6 @@ OC.L10N.register(
     "Error deleting file \"{fileName}\"." : "Produciuse un erro ao eliminar o ficheiro «{fileName}».",
     "No search results in other folders for {tag}{filter}{endtag}" : "Non foi posíbel atopar resultados de busca noutros cartafoles para {tag}{filter}{endtag}",
     "Enter more than two characters to search in other folders" : "Introduza máis de dous caracteres para buscar noutros cartafoles",
-    "_%n folder_::_%n folders_" : ["%n cartafol","%n cartafoles"],
-    "_%n file_::_%n files_" : ["%n ficheiro","%n ficheiros"],
     "{dirs} and {files}" : "{dirs} e {files}",
     "_including %n hidden_::_including %n hidden_" : ["incluíndo %n agachado","incluíndo %n agochados"],
     "You do not have permission to upload or create files here" : "Non ten permiso para enviar ou crear ficheiros aquí",
@@ -429,30 +465,63 @@ OC.L10N.register(
     "Direct link was copied (only works for people who have access to this file/folder)" : "Foi copiada a ligazón directa (só funciona para as persoas que teñen acceso a este ficheiro/cartafol)",
     "Path" : "Ruta",
     "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
-    "Favorited" : "Marcado como favorito",
+    "Favored" : "Favorecido",
+    "Favor" : "Favorecer",
     "Copy direct link (only works for people who have access to this file/folder)" : "Copiar a ligazón directa (só funciona para persoas con acceso a este ficheiro/cartafol)",
     "Upload file" : "Enviar ficheiro",
-    "Not favorited" : "Non marcado como favorito",
+    "Not favored" : "Non favorecido",
     "An error occurred while trying to update the tags" : "Produciuse un erro ao tentar actualizar as etiquetas",
-    "You don't have permission to upload or create files here." : "Non ten permiso para enviar ou crear ficheiros aquí.",
-    "Storage informations" : "Información de almacenamento",
-    "Choose file" : "Escoller o ficheiro",
-    "Go to the previous folder" : "Ir ao cartafol anterior",
-    "Open the files app settings" : "Abrir os axustes da aplicación de ficheiros",
-    "Unable to change the favourite state of the file" : "Non é posíbel cambiar o estado favorito do ficheiro",
-    "Edit file locally" : "Editar o ficheiro localmente",
-    "Edit online" : "Editar en liña",
-    "Create new templates folder" : "Crear un novo cartafol de modelos",
-    "List of favorites files and folders." : "Lista de ficheiros e cartafoles favoritos.",
+    "Upload (max. %s)" : "Envío (máx. %s)",
+    "\"{displayName}\" action executed successfully" : "A acción «{displayName}» executouse correctamente",
+    "\"{displayName}\" action failed" : "Produciuse un fallo na acción «{displayName}»",
+    "\"{displayName}\" failed on some elements" : "Produciuse un fallo nalgúns elementos de «{displayName}»",
+    "\"{displayName}\" batch action executed successfully" : "A acción por lotes «{displayName}» executouse correctamente",
+    "Submitting fields…" : "Enviando os campos...",
+    "Filter filenames…" : "Filtrar os nomes de ficheiro…",
+    "WebDAV URL copied to clipboard" : "O URL de WebDAV foi copiado no portapapeis",
+    "Enable the grid view" : "Activar á vista de grade",
+    "Enable folder tree" : "Activar a árbore de cartafoles",
+    "Copy to clipboard" : "Copiar no portapapeis.",
+    "Use this address to access your Files via WebDAV" : "Empregue este enderezo para acceder ao seu Ficheiros mediante WebDAV",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Se activou 2FA, cree e utilice un novo contrasinal de aplicación premendo aquí.",
+    "Deletion cancelled" : "Foi cancelada a eliminación",
+    "Move cancelled" : "Cancelouse o movemento",
+    "Cancelled move or copy of \"{filename}\"." : "Foi cancelado o movemento ou copia de «{filename}»",
+    "Cancelled move or copy operation" : "Foi cancelada a operación de movemento ou copia",
+    "Open details" : "Abrir detalles",
+    "Photos and images" : "Fotos e imaxes",
+    "New folder creation cancelled" : "Cancelouse a creación dun novo cartafol",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} cartafol","{folderCount} cartafoles"],
+    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} ficheiro","{fileCount} ficheiros"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 ficheiro e {folderCount} cartafol","1 ficheiro e {folderCount} cartafoles"],
+    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} ficheiro e 1 cartafol","{fileCount} ficheiros e 1 cartafol"],
+    "{fileCount} files and {folderCount} folders" : "{fileCount} ficheiros e {folderCount} cartafoles",
+    "All folders" : "Todos os cartafoles",
     "Personal Files" : "Ficheiros persoais",
     "Text file" : "Ficheiro de texto",
     "New text file.txt" : "Novo ficheiro de texto.txt",
-    "Favored" : "Favorecido",
-    "Favor" : "Favorecer",
-    "Not favored" : "Non favorecido",
-    "Submitting fields…" : "Enviando os campos...",
-    "Filter filenames…" : "Filtrar os nomes de ficheiro…",
-    "{count} files could not be converted" : "Non foi posíbel converter {count} ficheiros",
-    "{count} files successfully converted" : "{count} ficheiros foron convertidos correctamente"
+    "%1$s (renamed)" : "%1$s (renomeado)",
+    "renamed file" : "ficheiro renomeado",
+    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Após activar os nomes de ficheiro compatíbeis con Windows, os ficheiros existentes xa non poden ser modificados, mais poden ser renomeados con novos nomes válidos polo seu propietario.",
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Tamén é posíbel migrar os ficheiros automaticamente após activar esta configuración, consulte a documentación sobre a orde occ.",
+    "Filter file names …" : "Filtrar os nomes de ficheiro…",
+    "Prevent warning dialogs from open or reenable them." : "Impedir abrir ou reactivar os diálogos de advertencia",
+    "Show a warning dialog when changing a file extension." : "Amosar un diálogo de advertencia ao cambiar unha extensión de ficheiro.",
+    "Speed up your Files experience with these quick shortcuts." : "Acelere a súa experiencia con Ficheiros con estes atallos rápidos.",
+    "Open the actions menu for a file" : "Abrir o menú de accións dun ficheiro",
+    "Rename a file" : "Cambiar o nome dun ficheiro",
+    "Delete a file" : "Eliminar un ficheiro",
+    "Favorite or remove a file from favorites" : "Marcar como favorito ou retirar un ficheiro dos favoritos",
+    "Manage tags for a file" : "Xestionar etiquetas para un ficheiro",
+    "Deselect all files" : "Deseleccionar todos os ficheiros",
+    "Select or deselect a file" : "Seleccione ou deseleccione un ficheiro",
+    "Select a range of files" : "Seleccionar un intervalo de ficheiros",
+    "Navigate to the parent folder" : "Navegar ata o cartafol principal",
+    "Navigate to the file above" : "Navegar ata o ficheiro anterior",
+    "Navigate to the file below" : "Navegar ata o ficheiro seguinte",
+    "Navigate to the file on the left (in grid mode)" : "Navegar ata o ficheiro da esquerda (en modo de grade)",
+    "Navigate to the file on the right (in grid mode)" : "Navegar ata o ficheiro da dereita (en modo de grade)",
+    "Toggle the grid view" : "Cambiar á vista de grade",
+    "Open the sidebar for a file" : "Abrir a barra lateral dun ficheiro"
 },
 "nplurals=2; plural=(n != 1);");
