@@ -51,10 +51,13 @@ OC.L10N.register(
     "You do not have permission to create a file at the specified location" : "У вас нет разрешения на создание файла в указанном месте",
     "The file could not be converted." : "Файл не может быть преобразован.",
     "Could not get relative path to converted file" : "Не удалось получить относительный путь к преобразованному файлу",
+    "Limit must be a positive integer." : "Предел должен быть положительным целым числом.",
+    "The replacement character may only be a single character." : "Заменяющий символ может состоять только из одного символа.",
+    "Filename sanitization already started." : "Очистка имени файла уже начата.",
+    "No filename sanitization inprogress." : "В процессе работы не выполняется очистка имени файла.",
     "Favorite files" : "Избранные файлы",
     "No favorites" : "Нет избранного",
     "More favorites" : "Больше избранного",
-    "Upload (max. %s)" : "Загрузка (максимум %s)",
     "Accept" : "Принять",
     "Reject" : "Отклонить",
     "Incoming ownership transfer from {user}" : "Запрос передачи владения от пользователя {user}",
@@ -69,10 +72,6 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Завершена передача владения «{path}» от пользователя {user}.",
     "in %s" : "в %s",
     "Transferred from %1$s on %2$s" : "Передано от %1$s %2$s",
-    "Files compatibility" : "Совместимость файлов",
-    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Разрешить ограничения на имена файлов для обеспечения возможности их синхронизации со всеми клиентами. По умолчанию разрешены все имена файлов, допустимые в POSIX (например, в Linux или macOS).",
-    "Enforce Windows compatibility" : "Обеспечить совместимость с Windows",
-    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Это позволит блокировать имена файлов, недопустимые в системах Windows, например, использующие зарезервированные имена или специальные символы. Однако это не обеспечит совместимость в части чувствительности к регистру.",
     "File Management" : "Управление файлами",
     "Home" : "Главная",
     "Target folder does not exist any more" : "Каталог больше не существует",
@@ -95,20 +94,28 @@ OC.L10N.register(
     "Invalid filename." : "Недопустимое имя файла.",
     "Renamed \"{oldName}\" to \"{newName}\"" : "Переименовано «{oldName}» в \"{newName}\"",
     "Rename file" : "Переименовать файл",
+    "Folder" : "Каталог",
+    "Unknown file type" : "Неизвестный тип файла",
+    "{ext} image" : "{ext} изображение",
+    "{ext} video" : "{ext} видео",
+    "{ext} audio" : "{ext} аудио",
+    "{ext} text" : "{ext} текст",
     "Pending" : "Ожидается",
     "Unknown date" : "Неизвестная дата",
     "Clear filter" : "Сбросить фильтр",
     "Modified" : "Изменён",
+    "Search everywhere" : "Искать везде",
     "Type" : "Тип",
     "Active filters" : "Активные фильтры",
     "Remove filter" : "Удалить фильтр",
     "Total rows summary" : "Количество строк в общем",
     "Toggle selection for all files and folders" : "Установить или снять выделение всех файлов и папок",
     "Name" : "Имя",
+    "File type" : "Тип файла",
     "Size" : "Размер",
-    "\"{displayName}\" failed on some elements" : "\"{displayName}\" не удалось выполнить некоторые элементы",
-    "\"{displayName}\" batch action executed successfully" : "Пакетное действие \"{displayName}\" выполнено успешно",
-    "\"{displayName}\" action failed" : "Действие «{displayName}» завершилось неудачно",
+    "{displayName}: failed on some elements" : "{displayName}: не удалось выполнить некоторые элементы",
+    "{displayName}: done" : "{displayName}: сделано",
+    "{displayName}: failed" : "{displayName}: сбой",
     "Actions" : "Действия",
     "(selected)" : "(выбранный)",
     "List of files and folders." : "Список файлов и каталогов.",
@@ -116,7 +123,11 @@ OC.L10N.register(
     "Column headers with buttons are sortable." : "Заголовки столбцов с кнопками можно сортировать.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Этот список отображается не полностью из соображений производительности. Файлы будут отображаться по мере перемещения по списку.",
     "File not found" : "Файл не найден",
-    "{count} selected" : "{count} выбрано",
+    "_{count} selected_::_{count} selected_" : ["Выбран {count}","Выбрано {count}","Выбрано {count}","Выбрано {count} "],
+    "Search everywhere …" : "Искать везде …",
+    "Search here …" : "Искать здесь …",
+    "Search scope options" : "Настройки области поиска",
+    "Search here" : "Искать здесь",
     "{usedQuotaByte} used" : "Использовано {usedQuotaByte}",
     "{used} of {quota} used" : "использовано {used} из {quota}",
     "{relative}% used" : "Использовано {relative}%",
@@ -128,6 +139,25 @@ OC.L10N.register(
     "Create new folder" : "Создать папку",
     "This name is already in use." : "Это название уже используется.",
     "Create" : "Создать",
+    "Files starting with a dot are hidden by default" : "Файлы, начинающиеся с точки, скрыты по умолчанию",
+    "Failed to start filename sanitization." : "Не удалось начать очистку имени файла.",
+    "Failed to refresh filename sanitization status." : "Не удалось обновить статус очистки имени файла.",
+    "Filename sanitization in progress." : "Выполняется очистка имени файла.",
+    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "В настоящее время {processedUsers} из {totalUsers}учётных записей обработаны.",
+    "Preparing …" : "Подготовка…",
+    "Refresh" : "Обновить",
+    "All files have been santized for Windows filename support." : "Все файлы были очищены для поддержки имен файлов Windows.",
+    "Some files could not be sanitized, please check your logs." : "Некоторые файлы не удалось очистить, проверьте журналы.",
+    "Sanitization errors" : "Ошибка очистки",
+    "Not sanitized filenames" : "Не очищенные имена файлов",
+    "Windows filename support has been enabled." : "Включена поддержка имен файлов Windows.",
+    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "Хотя это не позволяет пользователям создавать новые файлы с неподдерживаемыми именами, существующие файлы пока не переименовываются и, следовательно, могут по-прежнему нарушать синхронизацию в Windows.",
+    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "Вы можете инициировать переименование файлов с недопустимыми именами. Это будет выполнено в фоновом режиме и может занять некоторое время.",
+    "Please note that this may cause high workload on the sync clients." : "Обратите внимание, что это может привести к высокой нагрузке на клиентов синхронизации.",
+    "Limit" : "Лимит",
+    "This allows to configure how many users should be processed in one background job run." : "Это позволяет настроить количество пользователей, которые должны быть обработаны за один запуск фонового задания.",
+    "Sanitize filenames" : "Очистить имена файлов",
+    "(starting)" : "(старт)",
     "Fill template fields" : "Заполните поля шаблона",
     "Submitting fields …" : "Отправка полей…",
     "Submit" : "Отправить ответ",
@@ -165,60 +195,72 @@ OC.L10N.register(
     "Error during upload: {message}" : "Ошибка при загрузке: {message}",
     "Error during upload, status code {status}" : "Ошибка при передаче на сервер. Сообщение об ошибке: {status}",
     "Unknown error during upload" : "Неизвестная ошибка при загрузке",
-    "\"{displayName}\" action executed successfully" : "Действие «{displayName}» выполнено успешно",
     "Loading current folder" : "Загрузка текущей папки",
     "Retry" : "Попробовать снова",
     "No files in here" : "Здесь нет файлов",
     "Upload some content or sync with your devices!" : "Загрузите что-нибудь или синхронизируйте со своими устройствами!",
     "Go back" : "Назад",
-    "Filter file names …" : "Фильтровать имена файлов…",
     "Views" : "Представления",
     "Files settings" : "Настройки файлов",
     "Your files" : "Ваши файлы",
     "Open in files" : "Открыть в приложении Файлы",
     "File cannot be accessed" : "Не удалось получить доступ к файлу",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Не удалось найти файл или у вас отсутствуют права на его просмотр.  Попросите отправителя предоставить вам доступ к этому файлу.",
+    "No search results for “{query}”" : "Нет результатов поиска по запросу «{query}»",
+    "Search for files" : "Поиск файлов",
     "Clipboard is not available" : "Буфер обмена недоступен",
-    "WebDAV URL copied to clipboard" : "Ссылка CalDAV скопирована в буфер обмена",
+    "WebDAV URL copied" : "URL-адрес WebDAV скопирован ",
+    "General" : "Основные",
+    "Default view" : "Вид по умолчанию",
+    "All files" : "Все файлы",
+    "Personal files" : "Личные файлы",
     "Sort favorites first" : "Сначала избранное",
     "Sort folders before files" : "Начинать список с папок",
+    "Folder tree" : "Дерево папок",
+    "Appearance" : "Внешний вид",
     "Show hidden files" : "Показывать скрытые файлы",
+    "Show file type column" : "Показать колонку с типом файла",
+    "Show file extensions" : "Показать расширения файлов",
     "Crop image previews" : "Обрезать пред. просмотр",
-    "Enable the grid view" : "Включить режим просмотра сеткой",
-    "Enable folder tree" : "Включить дерево папок",
     "Additional settings" : "Дополнительные параметры",
     "WebDAV" : "WebDAV",
     "WebDAV URL" : "Ссылка WebDAV",
-    "Copy to clipboard" : "Копировать в буфер",
-    "Use this address to access your Files via WebDAV" : "Используйте этот адрес для подключения WebDAV",
-    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Если вы включили двухфакторную аутентификацию, то нажмите здесь, чтобы создать пароль приложения.",
+    "Copy" : "Копировать",
+    "How to access files using WebDAV" : "Как получить доступ к файлам с помощью WebDAV",
+    "Two-Factor Authentication is enabled for your account, and therefore you need to use an app password to connect an external WebDAV client." : "Для вашего аккаунта включена двухфакторная аутентификация, поэтому вам необходимо использовать пароль приложения чтобы подключить внешний WebDAV клиент.",
     "Warnings" : "Предупреждения",
-    "Prevent warning dialogs from open or reenable them." : "Предотвратить открытие диалоговых окон с предупреждениями или включить их повторно.",
-    "Show a warning dialog when changing a file extension." : "Показать диалоговое окно предупреждения при изменении расширения файла.",
+    "Warn before changing a file extension" : "Предупреждать перед изменением расширения файла",
+    "Warn before deleting files" : "Предупреждать перед удалением файлов",
     "Keyboard shortcuts" : "Сочетания клавиш",
-    "Speed up your Files experience with these quick shortcuts." : "Ускорьте работу с файлами с помощью сочетаний клавиш.",
-    "Open the actions menu for a file" : "Открыть меню действий для файла",
-    "Rename a file" : "Переименовать файл",
-    "Delete a file" : "Удалить файл",
-    "Favorite or remove a file from favorites" : "Добавить или убрать из избранного ",
-    "Manage tags for a file" : "Управление тегами файла",
+    "File actions" : "Сценарии файла",
+    "Rename" : "Переименовать",
+    "Delete" : "Удалить",
+    "Add or remove favorite" : "Добавление или удаление избранного",
+    "Manage tags" : "Управление метками",
     "Selection" : "Выбор",
     "Select all files" : "Выбрать все файлы",
-    "Deselect all files" : "Отменить выбор всех файлов",
-    "Select or deselect a file" : "Выберите или отмените выбор файла",
-    "Select a range of files" : "Выбрать диапазон файлов",
+    "Deselect all" : "Снять выбор со всех",
+    "Select or deselect" : "Выбрать или отменить выбор",
+    "Select a range" : "Выберите диапазон",
     "Navigation" : "Навигация",
-    "Navigate to the parent folder" : "Перейти к родительской папке",
-    "Navigate to the file above" : "Перейти к файлу выше",
-    "Navigate to the file below" : "Перейти к файлу ниже",
-    "Navigate to the file on the left (in grid mode)" : "Перейдите к файлу слева (в режиме сетки)",
-    "Navigate to the file on the right (in grid mode)" : "Перейдите к файлу справа (в режиме сетки)",
+    "Go to parent folder" : "Перейти в родительскую папку",
+    "Go to file above" : "Перейдите к файлу, указанному выше",
+    "Go to file below" : "Перейдите к файлу ниже",
+    "Go left in grid" : "Идите налево по сетке",
+    "Go right in grid" : "Идите направо по сетке",
     "View" : "Режим просмотра",
-    "Toggle the grid view" : "Переключение вида сетки",
-    "Open the sidebar for a file" : "Откройте боковую панель для поиска файла",
+    "Toggle grid view" : "Включить или отключить режим просмотра сеткой",
+    "Open file sidebar" : "Открыть боковую панель файлов",
     "Show those shortcuts" : "Показать ярлыки",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Разрешить ограничения на имена файлов для обеспечения возможности их синхронизации со всеми клиентами. По умолчанию разрешены все имена файлов, допустимые в POSIX (например, в Linux или macOS).",
+    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "После включения совместимых с Windows названий файлов, существующие файлы нельзя будет изменить, но они могут быть переименованы их владельцем в допустимые новые имена.",
+    "Failed to toggle Windows filename support" : "Не удалось включить поддержку имен файлов в Windows",
+    "Files compatibility" : "Совместимость файлов",
+    "Enforce Windows compatibility" : "Обеспечить совместимость с Windows",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Это позволит блокировать имена файлов, недопустимые в системах Windows, например, использующие зарезервированные имена или специальные символы. Однако это не обеспечит совместимость в части чувствительности к регистру.",
     "You" : "Вы",
     "Shared multiple times with different people" : "Делиться несколько раз с разными людьми",
+    "Unable to change the favorite state of the file" : "Невозможно изменить избранное состояние файла",
     "Error while loading the file data" : "Не удалось загрузить данные файла",
     "Owner" : "Владелец",
     "Remove from favorites" : "Удалить из избранных",
@@ -243,7 +285,6 @@ OC.L10N.register(
     "File successfully converted" : "Файл успешно преобразован",
     "Failed to convert file: {message}" : "Не удалось преобразовать файл: {message}",
     "Failed to convert file" : "Не удалось преобразовать файл",
-    "Deletion cancelled" : "Удаление отменено",
     "Leave this share" : "Перестать использовать общий ресурс",
     "Leave these shares" : "Отказаться от доступа к общим ресурсам",
     "Disconnect storage" : "Отсоединить хранилище",
@@ -254,39 +295,38 @@ OC.L10N.register(
     "Delete files" : "Удалить файлы",
     "Delete folder" : "Удалить папку",
     "Delete folders" : "Удалить папки",
-    "Delete" : "Удалить",
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Вы собираетесь безвозвратно удалить {count} элемент","Вы собираетесь безвозвратно удалить {count} элемента","Вы собираетесь безвозвратно удалить {count} элементов","Вы собираетесь безвозвратно удалить {count} элементов"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Подтвердите удаление {count} объекта.","Подтвердите удаление {count} объектов","Подтвердите удаление {count} объектов","Подтвердите удаление {count} объектов"],
     "Confirm deletion" : "Подтвердить удаление",
     "Cancel" : "Отменить",
+    "Download" : "Скачать",
+    "The requested file is not available." : "Запрошенный файл недоступен.",
+    "The requested files are not available." : "Запрошенные файлы недоступны.",
     "Moving \"{source}\" to \"{destination}\" …" : "Перемещение \"{source}\" в \"{destination}\" …",
     "Copying \"{source}\" to \"{destination}\" …" : "Копирование \"{source}\" в \"{destination}\" …",
+    "Destination is not a folder" : "Указанное назначение не является папкой",
+    "This file/folder is already in that directory" : "Файл или папка уже расположены в этой папке",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Папка или файл не могут быть перемещены во вложенную папку или в себя",
     "(copy)" : "(копия)",
     "(copy %n)" : "(копия %n)",
-    "Move cancelled" : "Перемещение отменено",
     "A file or folder with that name already exists in this folder" : "В этой папке уже есть файл или папка с этим именем",
     "The files are locked" : "Файлы заблокированы",
     "The file does not exist anymore" : "Файл больше не существует",
     "Choose destination" : "Выберите место назначения",
     "Copy to {target}" : "Скопировать в «{target}»",
-    "Copy" : "Копировать",
     "Move to {target}" : "Переместить в «{target}»",
     "Move" : "Переместить",
     "Move or copy operation failed" : "Ошибка перемещение или копирования",
     "Move or copy" : "Переместить или копировать",
-    "Cancelled move or copy of \"{filename}\"." : "Отменено перемещение или копирование \"{filename}\".",
-    "Cancelled move or copy operation" : "Копирование или перемещение отменено",
     "Open folder {displayName}" : "Открыть папку «{displayName}»",
     "Open in Files" : "Открыть в приложении «Файлы»",
+    "Open locally" : "Открыть локально",
+    "Failed to redirect to client" : "Ошибка перенаправления в клиент",
     "Open file locally" : "Открыть файл локально",
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Теперь файл должен открыться на вашем устройстве. Если это не произошло, пожалуйста, убедитесь, что у вас установлено настольное приложение.",
     "Retry and close" : "Повторить попытку и закрыть",
     "Open online" : "Открыть онлайн",
-    "Failed to redirect to client" : "Ошибка перенаправления в клиент",
-    "Open locally" : "Открыть локально",
-    "Rename" : "Переименовать",
-    "Open details" : "Открыть подробности",
+    "Details" : "Подробно",
     "View in folder" : "Посмотреть в каталоге",
     "Today" : "Сегодня",
     "Last 7 days" : "Последние 7 дней",
@@ -299,39 +339,39 @@ OC.L10N.register(
     "PDFs" : "PDFs",
     "Folders" : "Папки",
     "Audio" : "Звук",
-    "Photos and images" : "Фотографии и изображения",
+    "Images" : "Изображения",
     "Videos" : "Видео",
-    "New folder creation cancelled" : "Создание новой папки отменено",
     "Created new folder \"{name}\"" : "Создана новая папка \"{name}\"",
     "Unable to initialize the templates directory" : "Не удалось инициализировать каталог шаблонов",
     "Create templates folder" : "Создать папку шаблонов",
     "Templates" : "Шаблоны",
     "New template folder" : "Новая папка шаблонов",
     "In folder" : "В папке",
+    "Search in all files" : "Поиск во всех файлах",
     "Search in folder: {folder}" : "Поиск в папке: «{folder}»",
     "One of the dropped files could not be processed" : "Один из перетащенных файлов не может быть обработан",
     "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Папки не будут загружены, так как используемый браузер не поддерживает работу с файловой системой.",
     "No files to upload" : "Не выбрано ни одного файла для передачи на сервер",
     "Unable to create the directory {directory}" : "Не удалось создать папку «{directory}»",
-    "Some files could not be uploaded" : "Некоторые файлы не могут быть загружены",
+    "Some files could not be uploaded" : "Не удалось загрузить некоторые файлы",
     "Files uploaded successfully" : "Файлы успешно обновлены",
-    "No files to process" : "Не ни одного файла для обработки",
-    "Some files could not be copied" : "Некоторые файлы не могут быть скопированы",
-    "Some files could not be moved" : "Некоторые файлы не могут быть перемещены",
+    "No files to process" : "Нет файлов для обработки",
+    "Some files could not be copied" : "Не удалось скопировать некоторые файлы",
+    "Some files could not be moved" : "Не удалось переместить некоторые файлы",
     "Files copied successfully" : "Файлы успешно скопированы",
     "Files moved successfully" : "Файлы успешно перемещены",
     "Conflicts resolution skipped" : "Разрешение конфликтов пропущено",
     "Upload cancelled" : "Передача на сервер отменена",
+    "Could not rename \"{oldName}\", it does not exist any more" : "Не удалось переименовать \"{oldName}\", его больше не существует",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Имя \"{newName}\" уже используется в каталоге \"{dir}\". Выберите другое имя.",
+    "Could not rename \"{oldName}\"" : "Не удалось переименовать «{oldName}»",
     "This operation is forbidden" : "Операция запрещена",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Каталог недоступен. Проверьте журналы событий или свяжитесь с администратором",
+    "This folder is unavailable, please try again later or contact the administration" : "Эта папка недоступна, пожалуйста, повторите попытку позже или свяжитесь с администрацией",
     "Storage is temporarily not available" : "Хранилище временно недоступно",
     "Unexpected error: {error}" : "Неожиданная ошибка: {error}",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} папка","{folderCount} папки","{folderCount} папок","{folderCount} папки"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} файл","{fileCount} файла","{fileCount} файлов","{fileCount} файла"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["один файл и {folderCount} папка","один файл и {folderCount} папки","один файл и {folderCount} папок","один файл и {folderCount} папки"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} файл и одна папка","{fileCount} файла и одна папка","{fileCount} файлов и одна папка","{fileCount} файла и одна папка"],
-    "{fileCount} files and {folderCount} folders" : "файлов: {fileCount}, папок: {folderCount}",
-    "_(%n hidden)_::_ (%n hidden)_" : ["(%n скрытый)","(%n скрытых)","(%n скрытых)","(%n скрытых)"],
+    "_%n file_::_%n files_" : ["%n файл","%n файла","%n файлов","%n файлов"],
+    "_%n folder_::_%n folders_" : ["%n каталог","%n каталога","%n каталогов","%n каталогов"],
+    "_%n hidden_::_%n hidden_" : ["скрыто %n","скрыто %n","скрыто %n","скрыто %n"],
     "Filename must not be empty." : "Имя файла не должно быть пустым.",
     "\"{char}\" is not allowed inside a filename." : "не допускается внутри имени файла.",
     "\"{segment}\" is a reserved name and not allowed for filenames." : "является зарезервированным именем и не допускается для имен файлов.",
@@ -340,10 +380,7 @@ OC.L10N.register(
     "List of favorite files and folders." : "Список избранных файлов и папок.",
     "No favorites yet" : "В избранное ещё ничего не добавлено ",
     "Files and folders you mark as favorite will show up here" : "Здесь будут показаны файлы и каталоги, отмеченные как избранные",
-    "All files" : "Все файлы",
     "List of your files and folders." : "Список ваших файлов и каталогов.",
-    "All folders" : "Все папки",
-    "Personal files" : "Личные файлы",
     "List of your files and folders that are not shared." : "Список ваших неопубликованных файлов и папок.",
     "No personal files found" : "Личные файлы не найдены",
     "Files that are not shared will show up here." : "Файлы, которые не опубликованы, показаны здесь.",
@@ -351,12 +388,13 @@ OC.L10N.register(
     "List of recently modified files and folders." : "Список недавно измененных файлов и директорий.",
     "No recently modified files" : "Нет недавно измененных файлов",
     "Files and folders you recently modified will show up here." : "Здесь будут показаны недавно изменённые файлы и папки",
+    "Search" : "Поиск",
+    "Search results within your files." : "Результаты поиска в ваших файлах.",
     "No entries found in this folder" : "В этом каталоге ничего не найдено",
     "Select all" : "Выбрать всё",
     "Upload too large" : "Файл слишком велик",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Файлы, которые вы пытаетесь передать, превышают лимит максимального размера на этом сервере.",
     "File could not be found" : "Невозможно найти файл",
-    "Download" : "Скачать",
     "Show list view" : "Просмотр списком",
     "Show grid view" : "Просмотр сеткой",
     "Close" : "Закрыть",
@@ -381,12 +419,12 @@ OC.L10N.register(
     "Edit locally" : "Редактировать локально",
     "Open" : "Открыть",
     "Could not load info for file \"{file}\"" : "Не удаётся загрузить информацию для файла \"{file}\"",
-    "Details" : "Подробно",
     "Please select tag(s) to add to the selection" : "Выберите метки для назначения выбранным объектам",
     "Apply tag(s) to selection" : "Назначить метки выбранным объектам",
     "Select directory \"{dirName}\"" : "Выберите каталог \"{dirName}\"",
     "Select file \"{fileName}\"" : "Выберите файл \"{fileName}\"",
     "Unable to determine date" : "Невозможно определить дату",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Каталог недоступен. Проверьте журналы событий или свяжитесь с администратором",
     "Could not move \"{file}\", target exists" : "Невозможно переместить файл «{file}», он уже существует в каталоге назначения",
     "Could not move \"{file}\"" : "Невозможно переместить файл «{file}»",
     "copy" : "копия",
@@ -395,9 +433,6 @@ OC.L10N.register(
     "Copied {origin} inside {destination}" : "{origin} скопирован в {destination}",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} и {nbfiles} других файлов скопированы в {destination}",
     "{newName} already exists" : "«{newName}» уже существует",
-    "Could not rename \"{fileName}\", it does not exist any more" : "Невозможно переименовать «{fileName}», файл больше не существует",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Имя «{targetName}» уже используется в каталоге «{dir}». Выберите другое имя.",
-    "Could not rename \"{fileName}\"" : "Невозможно переименовать «{fileName}»",
     "Could not create file \"{file}\"" : "Невозможно создать файл «{file}»",
     "Could not create file \"{file}\" because it already exists" : "Невозможно создать файл «{file}», он уже существует",
     "Could not create folder \"{dir}\" because it already exists" : "Невозможно создать каталог «{dir}», он уже существует",
@@ -405,8 +440,6 @@ OC.L10N.register(
     "Error deleting file \"{fileName}\"." : "Ошибка удаления файла «{fileName}».",
     "No search results in other folders for {tag}{filter}{endtag}" : "Нет результатов поиска в других папках для {tag}{filter}{endtag}",
     "Enter more than two characters to search in other folders" : "Введите более двух символов для поиска в других каталогах",
-    "_%n folder_::_%n folders_" : ["%n каталог","%n каталога","%n каталогов","%n каталогов"],
-    "_%n file_::_%n files_" : ["%n файл","%n файла","%n файлов","%n файлов"],
     "{dirs} and {files}" : "{dirs} и {files}",
     "_including %n hidden_::_including %n hidden_" : ["включая %n скрытый","включая %n скрытых","включая %n скрытых","включая %n скрытых"],
     "You do not have permission to upload or create files here" : "У вас нет разрешения на загрузку или создание файлов здесь",
@@ -432,30 +465,63 @@ OC.L10N.register(
     "Direct link was copied (only works for people who have access to this file/folder)" : "Внутренняя ссылка скопирована. Она может быть использована только пользователями, у которых уже есть доступ к этому файлу или папке. ",
     "Path" : "Путь",
     "_%n byte_::_%n bytes_" : ["%n байт","%n байта","%n байт","%n байт"],
-    "Favorited" : "Избранное",
+    "Favored" : "Избранные",
+    "Favor" : "Услуга",
     "Copy direct link (only works for people who have access to this file/folder)" : "Копировать прямую ссылку (она сработает только для пользователей, у которых уже есть доступ к этому файлу или каталогу)",
     "Upload file" : "Загрузить файл",
-    "Not favorited" : "Не избранное",
+    "Not favored" : "Не одобрен",
     "An error occurred while trying to update the tags" : "Во время обновления тегов возникла ошибка",
-    "You don't have permission to upload or create files here." : "У вас нет разрешения на загрузку или создание файлов здесь.",
-    "Storage informations" : "Сведения о хранилище",
-    "Choose file" : "Выберите файл",
-    "Go to the previous folder" : "Перейти к предыдущей папке",
-    "Open the files app settings" : "Открыть параметры приложения «Файлы»",
-    "Unable to change the favourite state of the file" : "Не удалось изменить состояние «избранный» этого файла.",
-    "Edit file locally" : "Редактировать файл локально",
-    "Edit online" : "Редактировать онлайн",
-    "Create new templates folder" : "Создать новую папку шаблонов",
-    "List of favorites files and folders." : "Список избранных файлов и каталогов.",
+    "Upload (max. %s)" : "Загрузка (максимум %s)",
+    "\"{displayName}\" action executed successfully" : "Действие «{displayName}» выполнено успешно",
+    "\"{displayName}\" action failed" : "Действие «{displayName}» завершилось неудачно",
+    "\"{displayName}\" failed on some elements" : "\"{displayName}\" не удалось выполнить некоторые элементы",
+    "\"{displayName}\" batch action executed successfully" : "Пакетное действие \"{displayName}\" выполнено успешно",
+    "Submitting fields…" : "Отправка полей…",
+    "Filter filenames…" : "Фильтровать имена файлов…",
+    "WebDAV URL copied to clipboard" : "Ссылка CalDAV скопирована в буфер обмена",
+    "Enable the grid view" : "Включить режим просмотра сеткой",
+    "Enable folder tree" : "Включить дерево папок",
+    "Copy to clipboard" : "Копировать в буфер",
+    "Use this address to access your Files via WebDAV" : "Используйте этот адрес для подключения WebDAV",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Если вы включили двухфакторную аутентификацию, то нажмите здесь, чтобы создать пароль приложения.",
+    "Deletion cancelled" : "Удаление отменено",
+    "Move cancelled" : "Перемещение отменено",
+    "Cancelled move or copy of \"{filename}\"." : "Отменено перемещение или копирование \"{filename}\".",
+    "Cancelled move or copy operation" : "Копирование или перемещение отменено",
+    "Open details" : "Открыть подробности",
+    "Photos and images" : "Фотографии и изображения",
+    "New folder creation cancelled" : "Создание новой папки отменено",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} папка","{folderCount} папки","{folderCount} папок","{folderCount} папки"],
+    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} файл","{fileCount} файла","{fileCount} файлов","{fileCount} файла"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["один файл и {folderCount} папка","один файл и {folderCount} папки","один файл и {folderCount} папок","один файл и {folderCount} папки"],
+    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} файл и одна папка","{fileCount} файла и одна папка","{fileCount} файлов и одна папка","{fileCount} файла и одна папка"],
+    "{fileCount} files and {folderCount} folders" : "файлов: {fileCount}, папок: {folderCount}",
+    "All folders" : "Все папки",
     "Personal Files" : "Личные файлы",
     "Text file" : "Текстовый файл",
     "New text file.txt" : "Новый текстовый файл.txt",
-    "Favored" : "Избранные",
-    "Favor" : "Услуга",
-    "Not favored" : "Не одобрен",
-    "Submitting fields…" : "Отправка полей…",
-    "Filter filenames…" : "Фильтровать имена файлов…",
-    "{count} files could not be converted" : "{count} файлы не могут быть преобразованы",
-    "{count} files successfully converted" : "{count} файлы успешно преобразованы"
+    "%1$s (renamed)" : "%1$s (переименовано)",
+    "renamed file" : "переименованный файл",
+    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "После включения совместимых с Windows названий файлов, существующие файлы нельзя будет изменить, но они могут быть переименованы их владельцем в допустимые новые имена.",
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Также возможно мигрировать файлы автоматически после включения этой настройки, пожалуйста, обратитесь к документации о команде occ.",
+    "Filter file names …" : "Фильтровать имена файлов…",
+    "Prevent warning dialogs from open or reenable them." : "Предотвратить открытие диалоговых окон с предупреждениями или включить их повторно.",
+    "Show a warning dialog when changing a file extension." : "Показать диалоговое окно предупреждения при изменении расширения файла.",
+    "Speed up your Files experience with these quick shortcuts." : "Ускорьте работу с файлами с помощью сочетаний клавиш.",
+    "Open the actions menu for a file" : "Открыть меню действий для файла",
+    "Rename a file" : "Переименовать файл",
+    "Delete a file" : "Удалить файл",
+    "Favorite or remove a file from favorites" : "Добавить или убрать из избранного ",
+    "Manage tags for a file" : "Управление тегами файла",
+    "Deselect all files" : "Отменить выбор всех файлов",
+    "Select or deselect a file" : "Выберите или отмените выбор файла",
+    "Select a range of files" : "Выбрать диапазон файлов",
+    "Navigate to the parent folder" : "Перейти к родительской папке",
+    "Navigate to the file above" : "Перейти к файлу выше",
+    "Navigate to the file below" : "Перейти к файлу ниже",
+    "Navigate to the file on the left (in grid mode)" : "Перейдите к файлу слева (в режиме сетки)",
+    "Navigate to the file on the right (in grid mode)" : "Перейдите к файлу справа (в режиме сетки)",
+    "Toggle the grid view" : "Переключение вида сетки",
+    "Open the sidebar for a file" : "Откройте боковую панель для поиска файла"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
