@@ -51,10 +51,11 @@ OC.L10N.register(
     "You do not have permission to create a file at the specified location" : "У вас відсутні права на створення файлу у визначеному розташуванні",
     "The file could not be converted." : "Файл неможливо конвертувати",
     "Could not get relative path to converted file" : "Не вдалося отримати відносний шлях до сконвертованого файлу",
+    "Limit must be a positive integer." : "Ліміт має бути позитивним числом.",
+    "The replacement character may only be a single character." : "Символ заміни може містити тільки один знак.",
     "Favorite files" : "Файли із зіркою",
     "No favorites" : "Немає улюблених",
     "More favorites" : "Ще файли із зіркою",
-    "Upload (max. %s)" : "Завантаження (макс. %s)",
     "Accept" : "Прийняти",
     "Reject" : "Відхилити",
     "Incoming ownership transfer from {user}" : "Запит від користувача {user} на передавання прав власника",
@@ -69,10 +70,6 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Завершено передавання права власника на {path} від користувача {user}.",
     "in %s" : "в %s",
     "Transferred from %1$s on %2$s" : "Перенесено від %1$s до %2$s",
-    "Files compatibility" : "Сумісність файлів",
-    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Дозволити обмежувати імена файлів для забезпечення сумісності з різними клієнтами. Типово всі імена файлів, які  відповідають моделі POSIX (напр., Linux, macOS), дозволені.",
-    "Enforce Windows compatibility" : "Увімкнути сумісність із Windows",
-    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Це унеможливить використання імен файлів, які не сумісні з системами Windows, напр., використанння зарезервованих імен або спеціальних символів. Зауважте, що це не обмежить сумісність за регістром символів.",
     "File Management" : "Керування файлами",
     "Home" : "Домівка",
     "Target folder does not exist any more" : "Каталог призначення більше не дійсний",
@@ -95,20 +92,28 @@ OC.L10N.register(
     "Invalid filename." : "Недійсне ім'я файлу.",
     "Renamed \"{oldName}\" to \"{newName}\"" : "Перейменовано \"{oldName}\" на \"{newName}\"",
     "Rename file" : "Перейменувати файл",
+    "Folder" : "Каталог",
+    "Unknown file type" : "Невідомий тип файлу",
+    "{ext} image" : "{ext} зображення",
+    "{ext} video" : "{ext} відео",
+    "{ext} audio" : "{ext} аудіо",
+    "{ext} text" : "{ext} текст",
     "Pending" : "Очікування",
     "Unknown date" : "Невідома дата",
     "Clear filter" : "Очистити фільтр",
     "Modified" : "Змінено",
+    "Search everywhere" : "Шукати всюди",
     "Type" : "Тип",
     "Active filters" : "Активні фільтри",
     "Remove filter" : "Вилучити фільтр",
     "Total rows summary" : "Загалом рядків",
     "Toggle selection for all files and folders" : "Перемкнути вибір для всіх файлів та каталогів",
     "Name" : "Ім'я",
+    "File type" : "Тип файлу",
     "Size" : "Розмір",
-    "\"{displayName}\" failed on some elements" : "\"{displayName}\" не спрацював у деяких елементах",
-    "\"{displayName}\" batch action executed successfully" : "Операцію \"{displayName}\" успішно виконано",
-    "\"{displayName}\" action failed" : "Не вдалося виконати \"{displayName}\"",
+    "{displayName}: failed on some elements" : "{displayName}: не вдалося виконати деякі елементи",
+    "{displayName}: done" : "{displayName}: готово",
+    "{displayName}: failed" : "{displayName}: не вдалося",
     "Actions" : "Дії",
     "(selected)" : "(вибрано)",
     "List of files and folders." : "Список файлів та каталогів",
@@ -116,7 +121,11 @@ OC.L10N.register(
     "Column headers with buttons are sortable." : "Назви стовпців з кнопками можна впорядковувати",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Список не подається повністю з міркувань обчислювальних потужностей. Файли показуватимуться під час прокручування списку.",
     "File not found" : "Файл не знайдено",
-    "{count} selected" : "{count} вибрано",
+    "_{count} selected_::_{count} selected_" : ["Вибрано {count}","Вибрано {count}","Вибрано {count} ","Вибрано {count} "],
+    "Search everywhere …" : "Шукати всюди ...",
+    "Search here …" : "Шукати тут …",
+    "Search scope options" : "Визначити місце пошуку",
+    "Search here" : "Шукати тут",
     "{usedQuotaByte} used" : "{usedQuotaByte} використано",
     "{used} of {quota} used" : "Використано {used} із {quota}",
     "{relative}% used" : "{relative}% використано",
@@ -128,6 +137,11 @@ OC.L10N.register(
     "Create new folder" : "Створити новий каталог",
     "This name is already in use." : "Це ім'я вже використовується",
     "Create" : "Створити",
+    "Files starting with a dot are hidden by default" : "Файли, що починаються з крапки, типово приховано",
+    "Preparing …" : "Підготовка ...",
+    "Refresh" : "Оновити",
+    "Limit" : "Ліміт",
+    "(starting)" : "(початок)",
     "Fill template fields" : "Заповнити поля шаблону",
     "Submitting fields …" : "Надсилання полів ...",
     "Submit" : "Відправити",
@@ -139,7 +153,7 @@ OC.L10N.register(
     "Ownership transfer request sent" : "Запит на передавання прав власника надіслано",
     "Cannot transfer ownership of a file or folder you do not own" : "Неможливо передати права власності на файл або каталог, якими ви не володієте",
     "Transfer ownership of a file or folder" : "Передавання прав власника на файл або каталог",
-    "Choose file or folder to transfer" : "Виберіть файл або каталог, права на який ви бажаєте передати",
+    "Choose file or folder to transfer" : "Виберіть цільовий файл або каталог",
     "Change" : "Змінити",
     "New owner" : "Новий власник",
     "Keep {old}" : "Зберегти {old}",
@@ -165,60 +179,72 @@ OC.L10N.register(
     "Error during upload: {message}" : "Помилка під час завантаження: {message}",
     "Error during upload, status code {status}" : "Помилка під час завантаження, код стану {status}",
     "Unknown error during upload" : "Невідома помилка під час завантаження",
-    "\"{displayName}\" action executed successfully" : "\"{displayName}\" успішно виконано",
     "Loading current folder" : "Отримання поточного каталогу",
     "Retry" : "Ще раз",
     "No files in here" : "Тут немає файлів",
     "Upload some content or sync with your devices!" : "Завантажте вміст або синхронізуйтеся з вашими пристроями!",
     "Go back" : "Повернутися назад",
-    "Filter file names …" : "Фільтр за іменем файлу ...",
     "Views" : "Подання",
     "Files settings" : "Налаштування",
     "Your files" : "Ваші файли",
     "Open in files" : "Відкрити у файлах",
     "File cannot be accessed" : "Неможливо отримати доступ до файлу",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Не вдалося знайти файл або у вас відсутній дозвіл на перегляд файлу. Попросіть поділитися цим файлом.",
+    "No search results for “{query}”" : "Відсутні результати для \"{query}\"",
+    "Search for files" : "Шукати файли",
     "Clipboard is not available" : "Буфер обміну недоступний",
-    "WebDAV URL copied to clipboard" : "Послиання WebDAV скопійовано до буферу обміну",
-    "Sort favorites first" : "Спочатку впорядковувати із зірочкою",
-    "Sort folders before files" : "Впорядковувати каталоги перед списком файлів",
+    "WebDAV URL copied" : "URL-адреса WebDAV скопійована",
+    "General" : "Загальне",
+    "Default view" : "Типовий вигляд",
+    "All files" : "Усі файли",
+    "Personal files" : "Мої документи",
+    "Sort favorites first" : "Спочатку показувати із зірочкою",
+    "Sort folders before files" : "Показувати каталоги перед файлами",
+    "Folder tree" : "Дерево каталогів",
+    "Appearance" : "Вигляд",
     "Show hidden files" : "Показувати приховані файли",
+    "Show file type column" : "Показувати стовпець з типом файлу",
+    "Show file extensions" : "Show file extensions",
     "Crop image previews" : "Попередній перегляд перед кадруванням",
-    "Enable the grid view" : "Увімкнути подання сіткою",
-    "Enable folder tree" : "Увімкнути дерево каталогів",
     "Additional settings" : "Додатково",
     "WebDAV" : "WebDAV",
     "WebDAV URL" : "URL-адреса WebDAV",
-    "Copy to clipboard" : "Копіювати до буферу обміну",
-    "Use this address to access your Files via WebDAV" : "Адреса для доступу до файлів за допомогою протоколу WebDAV",
-    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Якщо увімкнено двофакторної авторизацію, вам потрібно створити та використовувати окремий пароль на застосунок. Для цього клацніть тут.",
+    "Copy" : "Копіювати",
+    "How to access files using WebDAV" : "Як отримати доступ до файлів за допомогою WebDAV",
+    "Two-Factor Authentication is enabled for your account, and therefore you need to use an app password to connect an external WebDAV client." : "Для вашого облікового запису увімкнено двофакторну авторизацію, таким чином вам потрібно буде використовувати пароль для застосунку для з'єднання із зовнішнім клієнтом WebDAV.",
     "Warnings" : "Застереження",
-    "Prevent warning dialogs from open or reenable them." : "Не дозволяти показувати діялоги застережень або повторно увімкнути їх.",
-    "Show a warning dialog when changing a file extension." : "Показувати діялог застереження у разі зміни розширення файлу.",
+    "Warn before changing a file extension" : "Попереджати перед зміною розширення файлу",
+    "Warn before deleting files" : "Попереджати перед видаленням файлів",
     "Keyboard shortcuts" : "Скорочення",
-    "Speed up your Files experience with these quick shortcuts." : "Пришвідшіть взаємодію у застосунку \"Файли\" за скорочень",
-    "Open the actions menu for a file" : "Відкрити меню дій для файлу",
-    "Rename a file" : "Перейменувати файл",
-    "Delete a file" : "Вилучити файл",
-    "Favorite or remove a file from favorites" : "Додати або прибрати зірочку з файлу",
-    "Manage tags for a file" : "Керувати мітками файлу",
+    "File actions" : "Дії з файлами",
+    "Rename" : "Перейменувати",
+    "Delete" : "Вилучити",
+    "Add or remove favorite" : "Додати або видалити з улюблених",
+    "Manage tags" : "Керування мітками",
     "Selection" : "Вибір",
     "Select all files" : "Вибрати всі файли",
-    "Deselect all files" : "Прибрати вибір всіх файлів",
-    "Select or deselect a file" : "Вибрати чи прибрати вибір файлу",
-    "Select a range of files" : "Вибрати кілька файлів",
+    "Deselect all" : "Зняти всі мітки",
+    "Select or deselect" : "Вибрати або скасувати вибір",
+    "Select a range" : "Виберіть діапазон",
     "Navigation" : "Навігація",
-    "Navigate to the parent folder" : "Перейти до каталогу вищого рівня",
-    "Navigate to the file above" : "Перейти до файлу вище",
-    "Navigate to the file below" : "Перейти до фйлу нижче",
-    "Navigate to the file on the left (in grid mode)" : "Перейти до файлу ліворуч (подання сіткою)",
-    "Navigate to the file on the right (in grid mode)" : "Перейти до файлу праворуч (подання сіткою)",
+    "Go to parent folder" : "Перейти до батьківської папки",
+    "Go to file above" : "Перейти до файлу вище",
+    "Go to file below" : "Перейти до файлу нижче",
+    "Go left in grid" : "Перейти ліворуч у сітці",
+    "Go right in grid" : "Перейти праворуч у сітці",
     "View" : "Подання",
-    "Toggle the grid view" : "Перемкнути у подання сіткою",
-    "Open the sidebar for a file" : "Відкрити бокове меню для файлу",
+    "Toggle grid view" : "Перемкнути подання сіткою",
+    "Open file sidebar" : "Відкрити бічну панель файлів",
     "Show those shortcuts" : "Показувати ці скорочення",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Дозволити обмежувати імена файлів для забезпечення сумісності з різними клієнтами. Типово всі імена файлів, які  відповідають моделі POSIX (напр., Linux, macOS), дозволені.",
+    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Після увімкнення сумісности імен файлів з системою Windows наявні файли неможливо буде змінити, але власники зможуть перейменувати ці файли на нові з дійсними іменами.",
+    "Failed to toggle Windows filename support" : "Не вдалося перемкнути підтримку файлів для Windows",
+    "Files compatibility" : "Сумісність файлів",
+    "Enforce Windows compatibility" : "Увімкнути сумісність із Windows",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Це унеможливить використання імен файлів, які не сумісні з системами Windows, напр., використанння зарезервованих імен або спеціальних символів. Зауважте, що це не обмежить сумісність за регістром символів.",
     "You" : "Ви",
     "Shared multiple times with different people" : "Поділилися кілька разів з різними людьми",
+    "Unable to change the favorite state of the file" : "Неможливо змінити статус вподобаного файлу",
     "Error while loading the file data" : "Помилка під час отримання даних щодо файлу",
     "Owner" : "Власник",
     "Remove from favorites" : "Прибрати зірочку",
@@ -243,7 +269,6 @@ OC.L10N.register(
     "File successfully converted" : "Файл успішно конвертовано",
     "Failed to convert file: {message}" : "Не вдалося конвертувати файл: {message}",
     "Failed to convert file" : "Не вдалося конвертувати файл",
-    "Deletion cancelled" : "Вилучення скасовано",
     "Leave this share" : "Вийти зі спільного доступу",
     "Leave these shares" : "Вийти зі спільного доступу",
     "Disconnect storage" : "Від’єднати сховище",
@@ -254,39 +279,38 @@ OC.L10N.register(
     "Delete files" : "Вилучити файли",
     "Delete folder" : "Вилучити каталог",
     "Delete folders" : "Вилучити каталоги",
-    "Delete" : "Вилучити",
     "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Ви намагаєтеся назавжли вилучити {count} ресурс","Ви намагаєтеся назавжли вилучити {count} ресурси","Ви намагаєтеся назавжли вилучити {count} ресурсів","Ви намагаєтеся назавжли вилучити {count} ресурсів"],
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Ви намагаєтеся вилучити {count} ресурс","Ви намагаєтеся вилучити {count} ресурси","Ви намагаєтеся  вилучити {count} ресурсів","Ви намагаєтеся вилучити {count} ресурсів"],
     "Confirm deletion" : "Підтвердіть вилучення",
     "Cancel" : "Скасувати",
+    "Download" : "Звантажити",
+    "The requested file is not available." : "Запитаний файл відсутній.",
+    "The requested files are not available." : "Запитані файли відсутні.",
     "Moving \"{source}\" to \"{destination}\" …" : "Переміщення \"{source}\" до \"{destination}\" …",
     "Copying \"{source}\" to \"{destination}\" …" : "Копіювання \"{source}\" до \"{destination}\" …",
+    "Destination is not a folder" : "Місце призначення не є каталогом",
+    "This file/folder is already in that directory" : "Такий файл чи каталог вже присутні в цьому каталозі",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Неможливо перемістити файл чи каталог до самого себе або у цей саме підкаталог",
     "(copy)" : "(копія)",
     "(copy %n)" : "(копія %n)",
-    "Move cancelled" : "Переміщення скасовано",
     "A file or folder with that name already exists in this folder" : "Файл чи каталог з таким ім'ям вже присутній в цьому каталозі",
     "The files are locked" : "Файли заблоковано",
     "The file does not exist anymore" : "Цей файл більше недоступний",
     "Choose destination" : "Виберіть каталог призначення",
     "Copy to {target}" : "Копіювати до {target}",
-    "Copy" : "Копіювати",
     "Move to {target}" : "Перемістити до {target}",
     "Move" : "Перемістити",
     "Move or copy operation failed" : "Не вдалося скопіювати або перемістити",
     "Move or copy" : "Перемістити або копіювати",
-    "Cancelled move or copy of \"{filename}\"." : "Скасовано переміщення або копіювання \"{filename}\".",
-    "Cancelled move or copy operation" : "Переміщення або копіювання скасовано",
     "Open folder {displayName}" : "Відкрити каталог {displayName}",
     "Open in Files" : "Відкрити у Файлах",
+    "Open locally" : "Відкрити локально",
+    "Failed to redirect to client" : "Не вдалося перенаправити на клієнта",
     "Open file locally" : "Відкрити файл локально",
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Тепер файл можна відкрити на вашому пристрої. Якщо він не відкривається, перевірте, що у вас встановлено настільний клієнт синхронізації.",
     "Retry and close" : "Спробувати ще раз",
     "Open online" : "Відкрити віддалено",
-    "Failed to redirect to client" : "Не вдалося перенаправити на клієнта",
-    "Open locally" : "Відкрити локально",
-    "Rename" : "Перейменувати",
-    "Open details" : "Показати деталі",
+    "Details" : "Деталі",
     "View in folder" : "Переглянути у каталозі",
     "Today" : "Сьогодні",
     "Last 7 days" : "За останні 7 днів",
@@ -299,15 +323,15 @@ OC.L10N.register(
     "PDFs" : "Файли PDF",
     "Folders" : "Каталоги",
     "Audio" : "Аудіо",
-    "Photos and images" : "Зображення",
+    "Images" : "Зображення",
     "Videos" : "Відео",
-    "New folder creation cancelled" : "Створення нового каталогу скасовано",
     "Created new folder \"{name}\"" : "Створив(-ла) новий каталог \"{name}\"",
     "Unable to initialize the templates directory" : "Неможливо встановити каталог з шаблонами",
     "Create templates folder" : "Створити каталог для шаблонів",
     "Templates" : "Шаблони",
     "New template folder" : "Новий каталог шаблонів",
     "In folder" : "У каталозі",
+    "Search in all files" : "Пошук у всіх файлах",
     "Search in folder: {folder}" : "Шукати у каталозі: {folder}",
     "One of the dropped files could not be processed" : "Один із завантажених файлів не вдалося обробити",
     "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Ваш бравзер не підтримує Filesystem API. Каталоги не буде завантажено",
@@ -322,16 +346,16 @@ OC.L10N.register(
     "Files moved successfully" : "Файли успішно переміщено",
     "Conflicts resolution skipped" : "Пропущено розв'язання конфліктів",
     "Upload cancelled" : "Завантаження скасовано",
+    "Could not rename \"{oldName}\", it does not exist any more" : "Не вдалося перейментувати \"{oldName}\", оскільки він вже відсутній",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Ім'я \"{newName}\" вже використовується у каталозі \"{dir}\". Виберіть інше ім'я.",
+    "Could not rename \"{oldName}\"" : "Не вдалося перейменувати \"{oldName}\"",
     "This operation is forbidden" : "Операцію заборонено",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Каталог недоступний, будь ласка, перевірте файл журналу або зверніться до адміністратора  ",
+    "This folder is unavailable, please try again later or contact the administration" : "Ця папка недоступна, спробуйте пізніше або зверніться до адміністрації.",
     "Storage is temporarily not available" : "Сховище тимчасово недоступне",
     "Unexpected error: {error}" : "Неочікувана помилка: {error}",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} каталог","{folderCount} каталоги","{folderCount} каталогів","{folderCount} каталогів"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} файл","{fileCount} файли","{fileCount} файлів","{fileCount} файлів"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 файл та {folderCount} каталог","1 файл та {folderCount} каталоги","1 файл та {folderCount} каталогів","1 файл та {folderCount} каталогів"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} файл та 1 каталог","{fileCount} файли та 1 каталог","{fileCount} файлів та 1 каталог","{fileCount} файлів та 1 каталог"],
-    "{fileCount} files and {folderCount} folders" : "{fileCount} файлів та {folderCount} каталогів",
-    "_(%n hidden)_::_ (%n hidden)_" : ["(%n приховано)"," (%n прихованих)"," (%n прихованих)"," (%n прихованих)"],
+    "_%n file_::_%n files_" : ["%n файл","%n файли","%n файлів","%n файлів"],
+    "_%n folder_::_%n folders_" : ["%n каталог ","%n каталоги ","%n каталогів ","%n каталогів"],
+    "_%n hidden_::_%n hidden_" : ["%n приховано","%n приховано","%n приховано","%n приховано"],
     "Filename must not be empty." : "Імена файлів не мають бути порожні.",
     "\"{char}\" is not allowed inside a filename." : "Символ \"{char}\" не дозволено у імені файлу.",
     "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" є зарезервованим ім'ям і не дозволяється у іменах файлів.",
@@ -340,10 +364,7 @@ OC.L10N.register(
     "List of favorite files and folders." : "Список файлів та каталогів із зірочкою.",
     "No favorites yet" : "Поки немає нічого, позначеного зірочкою",
     "Files and folders you mark as favorite will show up here" : "Файли та каталоги із зірочкою з’являться тут",
-    "All files" : "Усі файли",
     "List of your files and folders." : "Список ваших файлів та каталогів.",
-    "All folders" : "Усі каталоги",
-    "Personal files" : "Мої документи",
     "List of your files and folders that are not shared." : "Перелік ваших файлів та каталогів, які не є у спільному доступі.",
     "No personal files found" : "Мої документи не знайдено",
     "Files that are not shared will show up here." : "Тут показуватимуться файли, які не є у спільному доступі.",
@@ -351,12 +372,13 @@ OC.L10N.register(
     "List of recently modified files and folders." : "Список нещодавно змінених файлів та каталогів.",
     "No recently modified files" : "Відсутні файли із нещодавними змінами",
     "Files and folders you recently modified will show up here." : "Тут показуватимуться файли та каталоги, які було нещодавно змінено.",
+    "Search" : "Пошук",
+    "Search results within your files." : "Шукати результати серед ваших файлів.",
     "No entries found in this folder" : "В цьому каталозі нічого не знайдено",
     "Select all" : "Вибрати все",
     "Upload too large" : "Файл занадто великий",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Файли, які ви намагаєтеся завантажити, перевищують максимально дозволений розмір завантаження файлів на сервер.",
     "File could not be found" : "Неможливо знайти файл",
-    "Download" : "Звантажити",
     "Show list view" : "Подання списком",
     "Show grid view" : "Подання сіткою",
     "Close" : "Закрити",
@@ -381,12 +403,12 @@ OC.L10N.register(
     "Edit locally" : "Відкрити на пристрої",
     "Open" : "Відкрити",
     "Could not load info for file \"{file}\"" : "Не вдалося отримати дані щодо файлу \"{file}\"",
-    "Details" : "Деталі",
     "Please select tag(s) to add to the selection" : "Виберіть мітки, які ви додасте до вибраного",
     "Apply tag(s) to selection" : "Додатки мітки до вибраного",
     "Select directory \"{dirName}\"" : "Виберіть каталог \"{dirName}\"",
     "Select file \"{fileName}\"" : "Вибрати файл \"{fileName}\"",
     "Unable to determine date" : "Неможливо визначити дату",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Каталог недоступний, будь ласка, перевірте файл журналу або зверніться до адміністратора  ",
     "Could not move \"{file}\", target exists" : "Не вдалося перемістити файл \"{file}\", оскільки файл з таким ім'ям вже присутній",
     "Could not move \"{file}\"" : "Неможливо перемістити файл \"{file}\"",
     "copy" : "копія",
@@ -395,9 +417,6 @@ OC.L10N.register(
     "Copied {origin} inside {destination}" : "Скопійовано {origin} до {destination}",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} та {nbfiles} інших файлів скопійовано до {destination}",
     "{newName} already exists" : "{newName} вже існує",
-    "Could not rename \"{fileName}\", it does not exist any more" : "Неможливо перейменувати \"{fileName}\", оскільки такий файл більше не існує",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Ім'я \"{targetName}\" вже використовується у каталозі \"{dir}\". Будь-ласка, виберіть іншу назву.",
-    "Could not rename \"{fileName}\"" : "Неможливо перейменувати \"{fileName}\"",
     "Could not create file \"{file}\"" : "Неможливо створити файл \"{file}\"",
     "Could not create file \"{file}\" because it already exists" : "Неможливо створити файл \"{file}\", оскільки файл з таким ім'ям вже присутній.",
     "Could not create folder \"{dir}\" because it already exists" : "Неможливо створити каталог \"{dir}\", оскільки каталог з таким ім'ям він вже присутній.",
@@ -405,8 +424,6 @@ OC.L10N.register(
     "Error deleting file \"{fileName}\"." : "Помилка вилучення файлу \"{fileName}\".",
     "No search results in other folders for {tag}{filter}{endtag}" : "Нічого не знайдено в інших каталогах за запитом {tag}{filter}{endtag}",
     "Enter more than two characters to search in other folders" : "Для пошуку в інших каталогах потрібно зазначити більше двох символів",
-    "_%n folder_::_%n folders_" : ["%n каталог ","%n каталоги ","%n каталогів ","%n каталогів"],
-    "_%n file_::_%n files_" : ["%n файл","%n файли","%n файлів","%n файлів"],
     "{dirs} and {files}" : "{dirs} та {files}",
     "_including %n hidden_::_including %n hidden_" : ["включаючи %n прихований","включаючи %n прихованих","включаючи %n прихованих","включно %n прихованих"],
     "You do not have permission to upload or create files here" : "У вас відсутні повноваження для завантаження або створення файлів тут",
@@ -432,30 +449,63 @@ OC.L10N.register(
     "Direct link was copied (only works for people who have access to this file/folder)" : "Пряме посилання було скопійовано (дійсне лише для користувачів, які мають відповідні права доступу)",
     "Path" : "Шлях",
     "_%n byte_::_%n bytes_" : ["%n байт","%n байти","%n байт","%n байт(ів)"],
-    "Favorited" : "Із зірочкою",
+    "Favored" : "Із зірочкою",
+    "Favor" : "Додати зірочку",
     "Copy direct link (only works for people who have access to this file/folder)" : "Копіювати пряме посилання (дійсне лише для користувачів, які мають відповідні права доступу)",
     "Upload file" : "Завантажити файл",
-    "Not favorited" : "Без зірочки",
+    "Not favored" : "Без зірочки",
     "An error occurred while trying to update the tags" : "Виникла помилка при спробі оновити мітки",
-    "You don't have permission to upload or create files here." : "У вас відсутні дозволи для завантаження або створення файлів в цьому каталозі.",
-    "Storage informations" : "Інформація про сховище",
-    "Choose file" : "Вибрати файл",
-    "Go to the previous folder" : "До попереднього каталогу",
-    "Open the files app settings" : "Перейти до налаштувань застосунку файлів",
-    "Unable to change the favourite state of the file" : "Неможливо змінити стан \"зірочка\" для цього файла",
-    "Edit file locally" : "Редагувати файл на пристрої",
-    "Edit online" : "Відкрити онлайн",
-    "Create new templates folder" : "Створіть новий каталог для шаблонів",
-    "List of favorites files and folders." : "Список файлів та каталогів із зірочкою.",
+    "Upload (max. %s)" : "Завантаження (макс. %s)",
+    "\"{displayName}\" action executed successfully" : "\"{displayName}\" успішно виконано",
+    "\"{displayName}\" action failed" : "Не вдалося виконати \"{displayName}\"",
+    "\"{displayName}\" failed on some elements" : "\"{displayName}\" не спрацював у деяких елементах",
+    "\"{displayName}\" batch action executed successfully" : "Операцію \"{displayName}\" успішно виконано",
+    "Submitting fields…" : "Поля для надсилання...",
+    "Filter filenames…" : "Вибрати файли за ім'ям ...",
+    "WebDAV URL copied to clipboard" : "Послиання WebDAV скопійовано до буферу обміну",
+    "Enable the grid view" : "Увімкнути подання сіткою",
+    "Enable folder tree" : "Увімкнути дерево каталогів",
+    "Copy to clipboard" : "Копіювати до буферу обміну",
+    "Use this address to access your Files via WebDAV" : "Адреса для доступу до файлів за допомогою протоколу WebDAV",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Якщо увімкнено двофакторної авторизацію, вам потрібно створити та використовувати окремий пароль на застосунок. Для цього клацніть тут.",
+    "Deletion cancelled" : "Вилучення скасовано",
+    "Move cancelled" : "Переміщення скасовано",
+    "Cancelled move or copy of \"{filename}\"." : "Скасовано переміщення або копіювання \"{filename}\".",
+    "Cancelled move or copy operation" : "Переміщення або копіювання скасовано",
+    "Open details" : "Показати деталі",
+    "Photos and images" : "Зображення",
+    "New folder creation cancelled" : "Створення нового каталогу скасовано",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} каталог","{folderCount} каталоги","{folderCount} каталогів","{folderCount} каталогів"],
+    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} файл","{fileCount} файли","{fileCount} файлів","{fileCount} файлів"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 файл та {folderCount} каталог","1 файл та {folderCount} каталоги","1 файл та {folderCount} каталогів","1 файл та {folderCount} каталогів"],
+    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} файл та 1 каталог","{fileCount} файли та 1 каталог","{fileCount} файлів та 1 каталог","{fileCount} файлів та 1 каталог"],
+    "{fileCount} files and {folderCount} folders" : "{fileCount} файлів та {folderCount} каталогів",
+    "All folders" : "Усі каталоги",
     "Personal Files" : "Мої документи",
     "Text file" : "Текстовий файл",
     "New text file.txt" : "Новий текстовий файл.txt",
-    "Favored" : "Із зірочкою",
-    "Favor" : "Додати зірочку",
-    "Not favored" : "Без зірочки",
-    "Submitting fields…" : "Поля для надсилання...",
-    "Filter filenames…" : "Відфільтрувати за ім'ям файлу ...",
-    "{count} files could not be converted" : "Неможливо конвертувати {count} файлів",
-    "{count} files successfully converted" : "Успішно конвертовано {count} файлів"
+    "%1$s (renamed)" : "%1$s (перейменовано)",
+    "renamed file" : "перейменовано файл",
+    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Після увімкнення сумісности імен файлів з системою Windows наявні файли неможливо буде змінити, але власники зможуть перейменувати ці файли на нові з дійсними іменами.",
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Також можлива автоматична міграція файлів після увімкнення цих налаштувань. Ознайомтеся з документацією відповідної команди occ.",
+    "Filter file names …" : "Фільтр за іменем файлу ...",
+    "Prevent warning dialogs from open or reenable them." : "Не дозволяти показувати діялоги застережень або повторно увімкнути їх.",
+    "Show a warning dialog when changing a file extension." : "Показувати діялог застереження у разі зміни розширення файлу.",
+    "Speed up your Files experience with these quick shortcuts." : "Пришвідшіть взаємодію у застосунку \"Файли\" за скорочень",
+    "Open the actions menu for a file" : "Відкрити меню дій для файлу",
+    "Rename a file" : "Перейменувати файл",
+    "Delete a file" : "Вилучити файл",
+    "Favorite or remove a file from favorites" : "Додати або прибрати зірочку з файлу",
+    "Manage tags for a file" : "Керувати мітками файлу",
+    "Deselect all files" : "Прибрати вибір всіх файлів",
+    "Select or deselect a file" : "Вибрати чи прибрати вибір файлу",
+    "Select a range of files" : "Вибрати кілька файлів",
+    "Navigate to the parent folder" : "Перейти до каталогу вищого рівня",
+    "Navigate to the file above" : "Перейти до файлу вище",
+    "Navigate to the file below" : "Перейти до фйлу нижче",
+    "Navigate to the file on the left (in grid mode)" : "Перейти до файлу ліворуч (подання сіткою)",
+    "Navigate to the file on the right (in grid mode)" : "Перейти до файлу праворуч (подання сіткою)",
+    "Toggle the grid view" : "Перемкнути у подання сіткою",
+    "Open the sidebar for a file" : "Відкрити бокове меню для файлу"
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
