@@ -30,7 +30,9 @@ class LoadAdditionalScriptsListener implements IEventListener {
 			return;
 		}
 
-		if (!$this->appManager->isEnabledForUser('notifications')) {
+		if (!$this->appManager->isEnabledForUser(Application::APP_ID)
+			|| !$this->appManager->isEnabledForUser('notifications')
+		) {
 			return;
 		}
 
