@@ -1,6 +1,7 @@
 OC.L10N.register(
     "photos",
     {
+    "Public link" : "Openbare skakel",
     "Photos" : "Foto’s",
     "Videos" : "Video's ",
     "Folders" : "Vouers",
@@ -9,11 +10,15 @@ OC.L10N.register(
     "Tags" : "Etikette",
     "Back" : "Terug",
     "Save" : "Bewaar",
+    "Shared by" : "Gedeel deur",
     "An error occurred" : "'n Fout het voorgekom",
-    "View" : "Bekyk",
     "Favorite" : "Gunsteling",
+    "Go back" : "Gaan terug",
+    "Add folder" : "Voeg 'n gids by",
+    "Home" : "Tuis",
+    "View" : "Bekyk",
     "Remove from favorites" : "Verwyder uit gunstelinge",
-    "Add" : "Voeg by",
-    "Settings" : "Instellings"
+    "Details" : "Besonderhede",
+    "Add" : "Voeg by"
 },
 "nplurals=2; plural=(n != 1);");
