@@ -38,8 +38,6 @@ OC.L10N.register(
     "Add people or groups who can edit your album" : "Agregar personas o grupos que puedan editar tu álbum",
     "Search people or groups" : "Buscar personas o grupos",
     "No recommendations. Start typing." : "No hay recomendaciones. Comienza a escribir.",
-    "Group" : "Grupo",
-    "Remove {collaboratorLabel} from the collaborators list" : "Eliminar {etiquetaColaborador} de la lista de colaboradores",
     "Copy the public link" : "Copiar el enlace público",
     "Public link copied!" : "¡Enlace público copiado!",
     "Copy public link" : "Copiar enlace público",
@@ -48,13 +46,12 @@ OC.L10N.register(
     "Share via public link" : "Compartir mediante enlace público",
     "This collection does not exist" : "Esta colección no existe",
     "An error occurred" : "Se produjo un error",
+    "_%n photos_::_%n photos_" : ["%n fotos","%n fotos","%n fotos"],
     "_%n unassigned photo_::_%n unassigned photos_" : ["%n foto sin asignar","%n fotos sin asignar","%n fotos sin asignar"],
     "Favorite" : "Hacer favorito",
     "Open the full size \"{name}\" image" : "Abrir la imagen \"{nombre}\" en tamaño completo",
     "Select image {imageName}" : "Seleccionar imagen {nombreImagen}",
-    "Back to {folder}" : "Volver a {carpeta}",
     "Go back" : "Regresar",
-    "Share this folder" : "Compartir esta carpeta",
     "Dates" : "Fechas",
     "Add to {destination}" : "Agregar a {destino}",
     "There are no photos or videos yet!" : "¡Aún no hay fotos o videos!",
@@ -94,7 +91,7 @@ OC.L10N.register(
     "This might take some time depending on the size of your photo library." : "Esto podría llevar algún tiempo dependiendo del tamaño de tu biblioteca de fotos.",
     "Recognized people will show up here" : "Aquí aparecerán las personas reconocidas",
     "This folder does not exist" : "Esta carpeta no existe",
-    "Loading folders …" : "Cargando carpetas...",
+    "Loading folders…" : "Cargando carpetas…",
     "No photos in here" : "No hay fotos aquí",
     "This place does not have any photos or videos yet!" : "¡Este lugar aún no tiene fotos o videos!",
     "Add photos to this place" : "Agregar fotos a este lugar",
@@ -109,7 +106,6 @@ OC.L10N.register(
     "Delete selection" : "Eliminar selección",
     "No photos or videos in here" : "No hay fotos o videos aquí",
     "Unassigned faces" : "Rostros sin asignar",
-    "_%n photos_::_%n photos_" : ["%n fotos","%n fotos","%n fotos"],
     "Failed to fetch collection." : "Error al obtener la colección.",
     "Failed to fetch collections list." : "Error al obtener la lista de colecciones.",
     "Failed to fetch faces list." : "Error al obtener la lista de rostros.",
@@ -121,7 +117,13 @@ OC.L10N.register(
     "Tagged photos" : "Fotos etiquetadas",
     "Tagged photo {title}" : "Foto etiquetada {título}",
     "{title}'s face" : "Rostro de {título}",
+    "Last week" : "La semana pasada",
     "Details" : "Detalles",
+    "Group" : "Grupo",
+    "Remove {collaboratorLabel} from the collaborators list" : "Eliminar {etiquetaColaborador} de la lista de colaboradores",
+    "Back to {folder}" : "Volver a {carpeta}",
+    "Share this folder" : "Compartir esta carpeta",
+    "Loading folders …" : "Cargando carpetas...",
     "Add" : "Agregar"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
