@@ -39,8 +39,6 @@ OC.L10N.register(
     "Add people or groups who can edit your album" : "Bættu við fólki eða hópum sem geta breytt albúminu þínu",
     "Search people or groups" : "Leita að fólki eða hópum",
     "No recommendations. Start typing." : "Engar tillögur. Byrjaðu að skrifa.",
-    "Group" : "Hópur",
-    "Remove {collaboratorLabel} from the collaborators list" : "Fjarlægja {collaboratorLabel} af listanum yfir samstarfsfólk",
     "Copy the public link" : "Afrita opinbera tengilinn",
     "Public link copied!" : "Opinber tengill afritaður!",
     "Copy public link" : "Afrita opinberan tengil",
@@ -52,15 +50,14 @@ OC.L10N.register(
     "No picture for this day" : "Engin mynd frá þessum degi",
     "Picture taken on this day will show up here." : "Myndir teknar á þessum degi munu birtast hér.",
     "More photos from this day" : "Fleiri ljósmyndir frá þessum degi",
+    "_%n photos_::_%n photos_" : ["%n ljósmynd","%n ljósmyndir"],
     "_%n unassigned photo_::_%n unassigned photos_" : ["%n óúthlutuð ljósmynd","%n óúthlutaðar ljósmyndir"],
     "Favorite" : "Eftirlæti",
     "Favorite image, open the full size \"{name}\" image" : "Eftirlætismynd, opna myndina \"{name}\" í fullri stærð",
     "Open the full size \"{name}\" image" : "Opna myndina \"{name}\" í fullri stærð",
     "Select image {imageName}" : "Veldu mynd {imageName}",
     "Open the \"{name}\" folder" : "Opna \"{name}\" möppuna",
-    "Back to {folder}" : "Til baka í {folder}",
     "Go back" : "Fara til baka",
-    "Share this folder" : "Deila þessari möppu",
     "Dates" : "Dagsetningar",
     "Jump to specific date in list" : "Hoppa á ákveðna dagsetningu í lista",
     "Jump to {date}" : "Hoppa á {date}",
@@ -114,14 +111,13 @@ OC.L10N.register(
     "This might take some time depending on the size of your photo library." : "Þetta ferli getur tekið nokkurn tíma eftir stærð ljósmyndasafnsins þíns.",
     "Recognized people will show up here" : "Fólk sem þekkist mun birtast hér",
     "This folder does not exist" : "Þessi mappa er ekki til",
-    "Loading folders …" : "Hleð inn möppum …",
+    "Loading folders…" : "Hleð inn möppum…",
     "No photos in here" : "Engar ljósmyndir hér",
     "Taken on {date} at {time}" : "Tekin þann {date} kl. {time}",
     "This place does not have any photos or videos yet!" : "Þessi staður er enn ekki með neinar ljósmyndir eða  myndskeið!",
     "Add photos to this place" : "Bæta við ljósmyndum á þennan stað",
     "Cover photo for place {placeName}" : "Forsíðumynd fyrir staðinn {placeName}",
     "There is no place yet!" : "Það er enn enginn staður!",
-    "Cover photo for shared album {albumName}." : "Forsíðumynd fyrir sameiginlega albúmið {albumName}.",
     "Back to tags overview" : "Fara aftur í yfirlit merkja",
     "No photos with this tag yet" : "Ennþá engar ljósmyndir með þessu merki",
     "No tags yet" : "Engin merki ennþá",
@@ -133,7 +129,6 @@ OC.L10N.register(
     "Delete selection" : "Eyða vali",
     "No photos or videos in here" : "Engar ljósmyndir eða myndskeið hér",
     "Unassigned faces" : "Óúthlutuð andlit",
-    "_%n photos_::_%n photos_" : ["%n ljósmynd","%n ljósmyndir"],
     "Failed to fetch collection." : "Mistókst að sækja safn.",
     "Failed to fetch collections list." : "Mistókst að ná í lista með söfnum.",
     "Failed to fetch faces list." : "Mistókst að ná í lista með andlitum.",
@@ -145,15 +140,15 @@ OC.L10N.register(
     "Tagged photos" : "Merktar ljósmyndir",
     "Tagged photo {title}" : "Merkt ljósmynd {title}",
     "{title}'s face" : "Andlit á {title}",
+    "Last week" : "Í síðustu viku",
     "{startDate} to {endDate}" : "{startDate} til {endDate}",
     "Details" : "Nánar",
-    "Failed to rename {oldName} to {faceName}." : "Mistókst að endurnefna {oldName} sem {faceName}.",
-    "Failed to delete {faceName}." : "Tókst ekki að eyða {faceName}.",
-    "Failed to delete {fileId}." : "Tókst ekki að eyða {fileId}.",
-    "Failed to delete {fileName}." : "Tókst ekki að eyða {fileName}.",
-    "Failed to set favorite state for {fileId}." : "Mistókst að setja stöðu sem eftirlæti fyrir {fileId}.",
-    "Failed to set favorite state for {fileName}." : "Mistókst að setja stöðu sem eftirlæti fyrir {fileName}.",
     "Could not load photos folder" : "Gat ekki að hlaðið inn ljósmyndamöppunni",
+    "Group" : "Hópur",
+    "Remove {collaboratorLabel} from the collaborators list" : "Fjarlægja {collaboratorLabel} af listanum yfir samstarfsfólk",
+    "Back to {folder}" : "Til baka í {folder}",
+    "Share this folder" : "Deila þessari möppu",
+    "Loading folders …" : "Hleð inn möppum …",
     "One of the source folders does not exists" : "Ein af upprunamöppunum er ekki til",
     "Add" : "Bæta við"
 },
