@@ -12,7 +12,7 @@ OC.L10N.register(
     "Favorites" : "Mėgstamos",
     "On this day" : "Šią dieną",
     "Shared with you" : "Bendrinama su jumis",
-    "Tags" : "Žymės",
+    "Tags" : "Žymos",
     "Map" : "Žemėlapis",
     "Photos settings" : "Nuotraukų nustatymai",
     "Name of the album" : "Albumo pavadinimas",
@@ -36,11 +36,10 @@ OC.L10N.register(
     "Share via public link" : "Bendrinti per viešąją nuorodą",
     "This collection does not exist" : "Šios kolekcijos nėra",
     "An error occurred" : "Įvyko klaida",
+    "_%n photos_::_%n photos_" : ["%n nuotrauka","%n nuotraukos","%n nuotraukų","%n nuotrauka"],
     "Favorite" : "Mėgstamas",
     "Open the full size \"{name}\" image" : "Atverti viso dydžio „{name}“ paveikslą",
-    "Back to {folder}" : "Atgal į {folder}",
     "Go back" : "Grįžti",
-    "Share this folder" : "Bendrinti šį aplanką",
     "Dates" : "Datos",
     "Add to {destination}" : "Pridėti į {destination}",
     "The destination folder is owned by {owner}" : "Paskirties aplanko savininkas yra {owner}",
@@ -72,25 +71,28 @@ OC.L10N.register(
     "This might take some time depending on the size of your photo library." : "Tai, priklausomai nuo jūsų nuotraukų bibliotekos dydžio, gali šiek tiek užtrukti.",
     "Recognized people will show up here" : "Čia bus rodomi atpažinti žmonės",
     "This folder does not exist" : "Šio aplanko nėra",
-    "Loading folders …" : "Įkeliami aplankai…",
+    "Loading folders…" : "Įkeliami aplankai…",
     "No photos in here" : "Čia nuotraukų nėra",
-    "Back to tags overview" : "Atgal į žymių apžvalgą",
-    "No photos with this tag yet" : "Kol kas nėra nuotraukų su šia žyme",
-    "No tags yet" : "Kol kas žymių nėra",
-    "Photos with tags will show up here" : "Čia bus rodomos nuotraukos su žymėmis",
-    "Popular tags" : "Populiarios žymės",
-    "All tags" : "Visos žymės",
+    "Back to tags overview" : "Atgal į žymų apžvalgą",
+    "No photos with this tag yet" : "Kol kas nėra nuotraukų, turinčių šią žymą",
+    "No tags yet" : "Kol kas žymų nėra",
+    "Photos with tags will show up here" : "Čia bus rodomos nuotraukos, turinčios žymas",
+    "Popular tags" : "Populiarios žymos",
+    "All tags" : "Visos žymos",
     "Add to album" : "Pridėti į albumą",
     "Delete selection" : "Ištrinti žymėjimą",
     "No photos or videos in here" : "Čia nėra jokių nuotraukų ar vaizdo įrašų",
-    "_%n photos_::_%n photos_" : ["%n nuotrauka","%n nuotraukos","%n nuotraukų","%n nuotrauka"],
     "Failed to fetch faces list." : "Nepavyko gauti veidų sąrašo.",
     "All your media" : "Visa jūsų medija",
     "Shared Albums" : "Bendrinami albumai",
-    "Tagged photos" : "Pažymėtos nuotraukos",
+    "Tagged photos" : "Nuotraukos, turinčios žymas",
+    "Last week" : "Praeitą savaitę",
     "{startDate} to {endDate}" : "Nuo {startDate} iki {endDate}",
     "Details" : "Išsamiau",
     "Could not load photos folder" : "Nepavyko įkelti nuotraukų aplanko",
+    "Back to {folder}" : "Atgal į {folder}",
+    "Share this folder" : "Bendrinti šį aplanką",
+    "Loading folders …" : "Įkeliami aplankai…",
     "One of the source folders does not exists" : "Vieno iš šaltinio aplankų nėra",
     "Add" : "Pridėti"
 },
