@@ -39,8 +39,6 @@ OC.L10N.register(
     "Add people or groups who can edit your album" : "Додайте людей або групи, які можуть редагувати ваш альбом",
     "Search people or groups" : "Пошук людей або груп",
     "No recommendations. Start typing." : "Відсутні рекомендації. Будь ласка, додайте.",
-    "Group" : "Група",
-    "Remove {collaboratorLabel} from the collaborators list" : "Вилучити {collaboratorLabel} зі списку співавторів",
     "Copy the public link" : "Копіювати публічне посилання",
     "Public link copied!" : "Публічне посилання скопійовано!",
     "Copy public link" : "Копіювати публічне посилання",
@@ -52,15 +50,18 @@ OC.L10N.register(
     "No picture for this day" : "Відсутні зображення цього дня",
     "Picture taken on this day will show up here." : "Зображення, які було отримано цього дня, будуть показані тут.",
     "More photos from this day" : "Більше світлин з цього дня",
+    "_%n photos_::_%n photos_" : ["%n фото","%n фотографії","%n фотографії","%n фотографії"],
     "_%n unassigned photo_::_%n unassigned photos_" : ["%n неідентифікована світлина","%n неідентифіковані світлини","%n неідентифікованих світлин","%n неідентифікованих світлин"],
     "Favorite" : "Із зірочкою",
     "Favorite image, open the full size \"{name}\" image" : "Вподобати зображення, відкрити повнорозмірне зображення: \"{name}\"",
     "Open the full size \"{name}\" image" : "Відкрити повнорозмірне зображення: \"{name}\"",
     "Select image {imageName}" : "Виберіть зображення {imageName}",
     "Open the \"{name}\" folder" : "Відкрити каталог \"{name}\"",
-    "Back to {folder}" : "Повернутися до каталогу {folder}",
     "Go back" : "Повернутися назад",
-    "Share this folder" : "Надати спільний доступ до каталогу",
+    "Select a custom date range" : "Виберіть власний діапазон дат",
+    "Select a date range" : "Виберіть часовий проміжок",
+    "Date range" : "Проміжок часу",
+    "Select filters" : "Вибрати фільтри",
     "Dates" : "Дати",
     "Jump to specific date in list" : "Перейти до певної дати зі списку",
     "Jump to {date}" : "Перейти до {date}",
@@ -115,7 +116,7 @@ OC.L10N.register(
     "This might take some time depending on the size of your photo library." : "Це може зайняти деякий час залежно від розміру вашої бібліотеки фотографій.",
     "Recognized people will show up here" : "Тут відображатимуться розпізнані люди",
     "This folder does not exist" : "Цей каталог не існує",
-    "Loading folders …" : "Завантаження папок…",
+    "Loading folders…" : "Завантаження теки...",
     "No photos in here" : "Тут немає світлин",
     "Taken on {date} at {time}" : "Зроблено {date} о {time}",
     "This place does not have any photos or videos yet!" : "У цього місця ще немає жодної фотографії чи відео!",
@@ -129,15 +130,16 @@ OC.L10N.register(
     "Photos with tags will show up here" : "Світлини з мітками буде показано тут",
     "Popular tags" : "Популярні мітки",
     "All tags" : "Всі мітки",
+    "Create new album from filters" : "Новий альбом на основі фільтрів",
     "One of the source folders does not exist" : "Один із каталогів призначення відсутній",
     "Add to album" : "Додати в альбом",
     "Delete selection" : "Вилучити виділення",
     "No photos or videos in here" : "Тут немає фотографій та відео",
     "Unassigned faces" : "Неідентифіковані обличчя",
-    "_%n photos_::_%n photos_" : ["%n фото","%n фотографії","%n фотографії","%n фотографії"],
     "Failed to fetch collection." : "Не вдалося отримати колекцію.",
     "Failed to fetch collections list." : "Не вдалося отримати список колекцій.",
     "Failed to fetch faces list." : "Не вдалося отримати список зображень облич.",
+    "Error fetching files" : "Помилка під час отримання файлів",
     "All your media" : "Усі ваші зображення та відео",
     "Album {title}" : "Альбом {title}",
     "Shared Albums" : "Спільні альбоми",
@@ -146,8 +148,19 @@ OC.L10N.register(
     "Tagged photos" : "Світлини з мітками",
     "Tagged photo {title}" : "Світлина з міткою {title}",
     "{title}'s face" : "обличчя {title}",
+    "Last week" : "Минулого тижня",
+    "Last Month" : "Минулого місяця",
+    "Custom…" : "Власний…",
     "{startDate} to {endDate}" : "{startDate} до {endDate}",
     "Details" : "Деталі",
+    "Failed to add {fileBaseName} to collection {collectionFileName}" : "Не вдалося додати {fileBaseName} до колекції {collectionFileName}",
+    "Failed to delete {fileBaseName}" : "Не вдалося вилучити {fileBaseName}",
+    "Failed to create {collectionFileName}" : "Не вдалося створити {collectionFileName}",
+    "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "Не вдалося перейменувати {currentCollectionFileName} у {newCollectionFileName}",
+    "Failed to update properties of {collectionFileName} with {properties}" : "Не вдалося оновити властивості {collectionFileName} на {properties}",
+    "Failed to delete {collectionFileName}" : "Не вдалося вилучити {collectionFileName}",
+    "Failed to move {fileBaseName} to person {faceName}" : "Не вдалося перенести {fileBaseName} до особи {faceName}",
+    "Failed to remove {fileBaseName}" : "Не вдалося вилучити {fileBaseName}",
     "Failed to rename {oldName} to {faceName}" : "Не вдалося перейменувати {oldName} у {faceName}",
     "Failed to delete {faceName}" : "Не вдалося вилучити {faceName}",
     "Failed to delete {fileId}" : "Не вдалося вилучити {fileId}",
@@ -155,6 +168,11 @@ OC.L10N.register(
     "Failed to set favorite state for {fileId}" : "Не вдалося додати зірочку до {fileId}",
     "Failed to set favorite state for {fileName}" : "Не вдалося додати зірочку до {fileName}",
     "Could not load photos folder" : "Неможливо завантажити каталог зі світлинами",
+    "Group" : "Група",
+    "Remove {collaboratorLabel} from the collaborators list" : "Вилучити {collaboratorLabel} зі списку співавторів",
+    "Back to {folder}" : "Повернутися до каталогу {folder}",
+    "Share this folder" : "Надати спільний доступ до каталогу",
+    "Loading folders …" : "Завантаження папок…",
     "One of the source folders does not exists" : "Один з каталогів джерел відсутній",
     "Add" : "Додати"
 },
