@@ -4,28 +4,8 @@ declare(strict_types=1);
 
 
 /**
- * Circles - Bring cloud-users closer together.
- *
- * This file is licensed under the Affero General Public License version 3 or
- * later. See the COPYING file.
- *
- * @author Maxence Lange <maxence@artificial-owl.com>
- * @copyright 2022
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2022 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 
@@ -35,7 +15,7 @@ use DateInterval;
 use DateTime;
 use Doctrine\DBAL\Query\QueryBuilder as DBALQueryBuilder;
 use Exception;
-use OC;
+use OC\DB\ConnectionAdapter;
 use OC\DB\QueryBuilder\QueryBuilder;
 use OC\SystemConfig;
 use OCA\RelatedResources\Tools\Exceptions\DateTimeException;
@@ -44,7 +24,7 @@ use OCA\RelatedResources\Tools\Exceptions\RowNotFoundException;
 use OCA\RelatedResources\Tools\Traits\TArrayTools;
 use OCP\DB\QueryBuilder\ICompositeExpression;
 use OCP\DB\QueryBuilder\IQueryBuilder;
-use OCP\IDBConnection;
+use OCP\Server;
 use Psr\Log\LoggerInterface;
 
 class ExtendedQueryBuilder extends QueryBuilder {
@@ -56,9 +36,9 @@ class ExtendedQueryBuilder extends QueryBuilder {
 
 	public function __construct() {
 		parent::__construct(
-			OC::$server->get(IDBConnection::class),
-			OC::$server->get(SystemConfig::class),
-			OC::$server->get(LoggerInterface::class)
+			Server::get(ConnectionAdapter::class),
+			Server::get(SystemConfig::class),
+			Server::get(LoggerInterface::class)
 		);
 	}
 
@@ -555,7 +535,9 @@ class ExtendedQueryBuilder extends QueryBuilder {
 
 		$expr = $this->expr();
 
-		return $expr->in($field, $this->createNamedParameter($values, IQueryBuilder::PARAM_STR_ARRAY));
+		return $expr->in(
+			$field, $this->createNamedParameter($values, IQueryBuilder::PARAM_STR_ARRAY)
+		);
 	}
 
 
