@@ -99,7 +99,7 @@ OC.L10N.register(
     "Administration" : "Ylläpito",
     "Users" : "Käyttäjät",
     "Additional settings" : "Lisäasetukset",
-    "Artificial Intelligence" : "Tekoäly",
+    "Assistant" : "Avustaja",
     "Administration privileges" : "Ylläpitäjän oikeudet",
     "Groupware" : "Groupware",
     "Overview" : "Yleiskuvaus",
@@ -109,6 +109,7 @@ OC.L10N.register(
     "Calendar" : "Kalenteri",
     "Personal info" : "Henkilökohtaiset tiedot",
     "Mobile & desktop" : "Mobiili ja työpöytä",
+    "Artificial Intelligence" : "Tekoäly",
     "Email server" : "Sähköpostipalvelin",
     "Background jobs" : "Taustatyöt",
     "Unlimited" : "Rajoittamaton",
@@ -122,10 +123,12 @@ OC.L10N.register(
     "Internet connectivity" : "Internet-yhdistettävyys",
     "Disabled" : "Pois käytöstä",
     "The old server-side-encryption format is enabled. We recommend disabling this." : "Vanha palvelinpuolen salausmenetelmä on käytössä. Suosittelemme sen ottamista pois käytöstä.",
+    "Logging level" : "Lokitustaso",
     "Maintenance window start" : "Huoltoikkunan alku",
     "Memcache" : "Memcache",
     "You are not using MySQL" : "Et käytä MySQL:ää",
     "MySQL Unicode support" : "MySQL:n Unicode-tuki",
+    "PHP APCu configuration" : "PHP APCu -määritys",
     "PHP default charset" : "PHP:n oletusmerkistö",
     "PHP set_time_limit" : "PHP:n set_time_limit",
     "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP-funktio \"set_time_limit\" ei ole käytettävissä. Tämä saattaa johtaa siihen, että skriptien suoritus päättyy ennenaikaisesti ja Nextcloud-asennus rikkoutuu. Funktion käyttäminen on erittäin suositeltavaa.",
@@ -152,11 +155,11 @@ OC.L10N.register(
     ".well-known URLs" : ".well-known-URL-osoitteet",
     "Profile information" : "Profiilitiedot",
     "Nextcloud settings" : "Nextcloud-asetukset",
-    "Task:" : "Tehtävä:",
     "Enable" : "Käytä",
     "Machine translation" : "Konekäännös",
     "Image generation" : "Kuvien generointi",
     "Text processing" : "Tekstinkäsittely",
+    "Task:" : "Tehtävä:",
     "Here you can decide which group can access certain sections of the administration settings." : "Tässä voit päättää, mitkä ryhmät voivat käyttää tiettyja osioita ylläpitäjän asetuksista.",
     "Unable to modify setting" : "Asetuksen muokkaaminen ei onnistu",
     "None" : "Ei mitään",
@@ -190,6 +193,7 @@ OC.L10N.register(
     "Two-factor authentication is not enforced for members of the following groups." : "Kaksivaiheisen tunnistautuminen ei ole pakotettu seuraavien ryhmien jäsenille.",
     "Excluded groups" : "Poissuljetut ryhmät",
     "Save changes" : "Tallenna muutokset",
+    "Default" : "Oletus",
     "Show details for {appName} app" : "Näytä sovelluksen {appName} tiedot",
     "Update to {update}" : "Päivitä versioon {update}",
     "Remove" : "Poista",
@@ -209,6 +213,14 @@ OC.L10N.register(
     "No apps found for your version" : "Sovelluksia ei löytynyt versiollesi",
     "_%n app has an update available_::_%n apps have an update available_" : ["%n sovelluksella on päivitys saatavilla","%n sovelluksella on päivitys saatavilla"],
     "_Update_::_Update all_" : ["Päivitä","Päivitä kaikki"],
+    "Failed to load groups" : "Ryhmien lataaminen epäonnistui",
+    "Failed to create group" : "Ryhmän luonti epäonnistui",
+    "Creating group…" : "Luodaan ryhmä…",
+    "Create group" : "Luo ryhmä",
+    "Group name" : "Ryhmän nimi",
+    "Please enter a valid group name" : "Kirjoita kelvollinen ryhmän nimi",
+    "Search groups…" : "Etsi ryhmiä…",
+    "Loading groups…" : "Ladataan ryhmiä…",
     "Nothing to show" : "Ei mitään näytettävää",
     "Loading" : "Ladataan",
     "Fetching the latest news…" : "Noudetaan viimeisimpiä uutisia…",
@@ -221,20 +233,19 @@ OC.L10N.register(
     "Type" : "Tyyppi",
     "Display Name" : "Näyttönimi",
     "Learn more" : "Opi lisää",
+    "Environment variables" : "Ympäristömuuttujat",
     "Confirm" : "Vahvista",
     "Cancel" : "Peru",
     "Description" : "Kuvaus",
     "View in store" : "Näytä kaupassa",
     "Visit website" : "Käy verkkosivustolla",
-    "Admin documentation" : "Ylläpitäjän ohjeistus",
+    "Admin documentation" : "Ylläpitäjän dokumentaatio",
     "Developer documentation" : "Kehittäjädokumentaatio",
-    "Details" : "Yksityiskohdat",
+    "Details" : "Tiedot",
     "All" : "Kaikki",
     "Limit app usage to groups" : "Rajoita sovelluskäyttö ryhmiin",
     "No results" : "Ei tuloksia",
     "Update to {version}" : "Päivitä versioon {version}",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Tämä sovellus ei ole määritellyt minimi Nextcloud-versiota. Tämä tulee olemaan ongelma tulevaisuudessa.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Tämä sovellus ei ole määritellyt maksimi Nextcloud-versiota. Tämä tulee olemaan ongelma tulevaisuudessa.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Tätä sovellusta ei voi asentaa, koska seuraavat riippuvuudet eivät täyty:",
     "Author" : "Tekijä",
     "Categories" : "Luokat",
@@ -252,6 +263,8 @@ OC.L10N.register(
     "{productName} Talk for iOS" : "{productName} Talk iOS:lle",
     "{productName} Talk for Android" : "{productName} Talk Androidille",
     "This session" : "Tämä istunto",
+    "{client} - {version} ({system})" : "{client} - {version} ({system})",
+    "{client} - {version}" : "{client} - {version}",
     "Device name" : "Laitteen nimi",
     "Save new name" : "Tallenna uusi nimi",
     "Marked for remote wipe" : "Merkitty etätyhjennettäväksi",
@@ -280,9 +293,11 @@ OC.L10N.register(
     "Use system cron service to call the cron.php file every 5 minutes." : "Käytä järjestelmän cron-palvelua cron.php-skriptin suorittamiseen 5 minuutin välein",
     "Last job execution ran {time}. Something seems wrong." : "Viimeisimmän työn suoritus {time}. Jokin vaikuttaa olevan pielessä.",
     "Last job ran {relativeTime}." : "Viimeisin työ ajettiin {relativeTime}.",
+    "AJAX" : "AJAX",
     "Cron (Recommended)" : "Cron (suositeltu)",
     "Unable to update profile default setting" : "Profiilin oletusasetuksen päivittäminen ei onnistunut",
     "Profile" : "Profiili",
+    "Password confirmation is required" : "Salasanavahvistus vaaditaan",
     "Server-side encryption" : "Palvelinpään salaus",
     "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Palvelimelle ladatut tiedostot voidaan salata. Salaus aiheuttaa muun muassa palvelimen suorituskyvyn laskua, joten ota salaus käyttöön vain tarvittaessa.",
     "Enable server-side encryption" : "Käytä palvelinpään salausta",
@@ -295,12 +310,11 @@ OC.L10N.register(
     "Be aware that encryption always increases the file size." : "Ota huomioon, että salaus kasvattaa aina tiedostojen kokoa.",
     "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Säännöllisten varmuuskopioiden ottaminen on erittäin tärkeää. Jos olet ottanut salauksen käyttöön, huolehdi salausavainten varmuuskopioinnista.",
     "This is the final warning: Do you really want to enable encryption?" : "Tämä on viimeinen varoitus: haluatko varmasti ottaa salauksen käyttöön?",
-    "Failed to remove group \"{group}\"" : "Ryhmän \"{group}\" poistaminen epäonnistui",
+    "Failed to delete group \"{group}\"" : "Ryhmän \"{group}\" poistaminen epäonnistui",
     "Please confirm the group removal" : "Vahvista ryhmän poistaminen",
-    "You are about to remove the group \"{group}\". The accounts will NOT be deleted." : "Olet aikeissa poistaa ryhmän \"{group}\". Tilejä EI poisteta.",
     "Submit" : "Lähetä",
     "Rename group" : "Nimeä ryhmä uudelleen",
-    "Remove group" : "Poista ryhmä",
+    "Delete group" : "Poista ryhmä",
     "Current password" : "Nykyinen salasana",
     "New password" : "Uusi salasana",
     "Change password" : "Vaihda salasana",
@@ -318,8 +332,11 @@ OC.L10N.register(
     "Picture provided by original account" : "Kuvan tarjoaa alkuperäinen tili",
     "Set as profile picture" : "Aseta profiilikuvaksi",
     "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Ota huomioon, että profiilikuvasi päivittyminen kaikkialle saattaa kestää jopa 24 tuntia.",
+    "Your biography. Markdown is supported." : "Esittelytekstisi. Markdown on tuettu.",
     "Unable to update date of birth" : "Syntymäpäivää ei voitu päivittää",
     "Enter your date of birth" : "Kirjoita syntymäpäiväsi",
+    "You are using {s}{usage}{/s}" : "Käytössäsi on {s}{usage}{/s}",
+    "You are using {s}{usage}{/s} of {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})" : "Käytössäsi on {s}{usage}{/s}/{s}{totalSpace}{/s} ({s}{usageRelative}%{/s})",
     "You are a member of the following groups:" : "Olet seuraavien ryhmien jäsen:",
     "Your full name" : "Koko nimesi",
     "Email options" : "Sähköpostiasetukset",
@@ -348,6 +365,7 @@ OC.L10N.register(
     "Edit your Profile visibility" : "Muokkaa profiilisi näkyvyyttä",
     "Enable profile" : "Ota profiili käyttöön",
     "Your role" : "Roolisi",
+    "Timezone" : "Aikavyöhyke",
     "Your website" : "Verkkosivustosi",
     "Invalid value" : "Virheellinen arvo",
     "Add additional email" : "Lisää toissijainen sähköpostiosoite",
@@ -356,6 +374,11 @@ OC.L10N.register(
     "Change" : "Muuta",
     "Delete" : "Poista",
     "Reshare" : "Jaa edelleen",
+    "Large organization" : "Suuri organisaatio",
+    "Big organization" : "Iso organisaatio",
+    "Small organization" : "Pieni organisaatio",
+    "University" : "Yliopisto",
+    "School" : "Koulu",
     "Default language" : "Oletuskieli",
     "Common languages" : "Yleiset kielet",
     "Other languages" : "Muut kielet",
@@ -388,7 +411,6 @@ OC.L10N.register(
     "Disable account" : "Poista tili käytöstä",
     "Enable account" : "Ota tili käyttöön",
     "Resend welcome email" : "Lähetä uudelleen tervetuloviesti",
-    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Laitteen kadotessa tai organisaatiosta poistuessa voidaan käyttäjälle {userid} Nextcloudiin yhdistetyistä laitteista pyyhkiä  tiedot. Toimii vain laitteiden ollessa yhteydessä Internetiin.",
     "Remote wipe of devices" : "Laitteiden etätyhjennys",
     "Wipe {userid}'s devices" : "Tyhjennä käyttäjän {userid} laitteet",
     "Wiped {userid}'s devices" : "Tyhjennetty käyttäjän {userid} laitteet",
@@ -396,7 +418,9 @@ OC.L10N.register(
     "Account deletion" : "Tilin poistaminen",
     "Delete {userid}'s account" : "Poista käyttäjän {userid} tili",
     "Display name was successfully changed" : "Näyttönimi vaihdettiin onnistuneesti",
+    "Password can't be empty" : "Salasana ei voi olla tyhjä",
     "Password was successfully changed" : "Salasana vaihdettiin onnistuneesti",
+    "Email can't be empty" : "Sähköposti ei voi olla tyhjä",
     "Email was successfully changed" : "Sähköpostiosoite vaihdettiin onnistuneesti",
     "Welcome mail sent!" : "Tervetuloviesti lähetetty!",
     "Loading account …" : "Ladataan tiliä…",
@@ -430,19 +454,22 @@ OC.L10N.register(
     "No devices configured." : "Laitteita ei ole määritetty.",
     "The following devices are configured for your account:" : "Seuraavat laitteet on määritetty tilillesi:",
     "Your browser does not support WebAuthn." : "Selaimesi ei tue WebAuthn-standardia.",
+    "Security & setup warnings" : "Turvallisuus- ja asetusvaroitukset",
+    "Try again" : "Yritä uudelleen",
+    "All checks passed." : "Läpäistiin kaikki tarkistukset.",
+    "There are some errors regarding your setup." : "Asetuksiin liittyen on muutamia virheitä.",
+    "There are some warnings regarding your setup." : "Asetuksiin liittyen on muutamia varoituksia.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Ylläpitäjänä voit hienosäätää jakamista. Katso dokumentaatiosta lisätietoa.",
     "Loading app list" : "Ladataan sovellusluetteloa",
     "Loading categories" : "Ladataan luokkia",
     "Developer documentation ↗" : "Kehittäjien dokumentaatio ↗",
     "Version {version}, {license}-licensed" : "Versio {version}, lisenssi {license}",
+    "Version {version}" : "Versio {version}",
+    "Apply" : "Toteuta",
+    "All accounts" : "Kaikki tilit",
     "Admins" : "Ylläpitäjät",
     "Account group: {group}" : "Tiliryhmä: {group}",
-    "Failed to create group" : "Ryhmän luonti epäonnistui",
     "Account management" : "Tilihallinta",
-    "Creating group…" : "Luodaan ryhmä…",
-    "Create group" : "Luo ryhmä",
-    "Group name" : "Ryhmän nimi",
-    "Please enter a valid group name" : "Kirjoita kelvollinen ryhmän nimi",
     "Sending…" : "Lähetetään…",
     "Email sent" : "Sähköposti lähetetty",
     "Location" : "Sijainti",
@@ -460,6 +487,8 @@ OC.L10N.register(
     "Website" : "Verkkosivusto",
     "Profile visibility" : "Profiilin näkyvyys",
     "Locale" : "Aluekohtainen asetus",
+    "First day of week" : "Viikon ensimmäinen päivä",
+    "timezone" : "aikavyöhyke",
     "Your apps" : "Sovelluksesi",
     "Active apps" : "Aktiiviset sovellukset",
     "Disabled apps" : "Käytöstä poistetut sovellukset",
@@ -474,7 +503,6 @@ OC.L10N.register(
     "Disable" : "Poista käytöstä",
     "Allow untested app" : "Salli testaamaton sovellus",
     "The app will be downloaded from the App Store" : "Sovellus ladataan sovelluskaupasta",
-    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Sovellusta ei ole merkattu yhteensopivaksi Nextcloud-versiosi kanssa. Voit kuitenkin jatkaa ja asentaa sovelluksen. Huomioi, että sovellus ei välttämättä toimi odotetusti.",
     "Unknown" : "Tuntematon",
     "Never" : "Ei koskaan",
     "Could not register device: Network error" : "Laitetta ei voitu rekisteröidä: verkkovirhe",
@@ -511,14 +539,6 @@ OC.L10N.register(
     "SMTP Password" : "SMTP-salasana",
     "Save" : "Tallenna",
     "Test and verify email settings" : "Testaa ja vahvista sähköpostiasetukset",
-    "Security & setup warnings" : "Turvallisuus- ja asetusvaroitukset",
-    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Turvallisuuden ja suorituskyvyn vuoksi on tärkeää, että palvelimen asetukset ovat määritetty oikein. Apuna on joitain automaattisia tarkistuksia. Lue lisätietoja linkitetystä dokumentaatiosta.",
-    "All checks passed." : "Läpäistiin kaikki tarkistukset.",
-    "There are some errors regarding your setup." : "Asetuksiin liittyen on muutamia virheitä.",
-    "There are some warnings regarding your setup." : "Asetuksiin liittyen on muutamia varoituksia.",
-    "Checking for system and security issues." : "Tarkistetaan mahdollisia järjestelmä- ja tietoturvaongelmia.",
-    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Lue tarkkaan <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">asennusohjeet ↗</a>, ja tarkista virheet sekä varoitukset <a href=\"%2$s\">lokista</a>.",
-    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Tarkista Nextcloudisi turvallisuus käyttäen <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">tietoturvakartoitustamme ↗</a>.",
     "Reasons to use Nextcloud in your organization" : "Nextcloudin käytön edut organisaatiossasi",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Kehityksestä on vastannut {communityopen}Nextcloud-yhteisö{linkclose}, {githubopen}lähdekoodi{linkclose} on {licenseopen}AGPL-lisensoitu{linkclose}.",
     "Like our Facebook page" : "Tykkää Facebook-sivustamme",
@@ -528,33 +548,18 @@ OC.L10N.register(
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Tätä yhteisöjulkaisua Nextcloudista ei tueta, ja pikailmoitukset eivät ole saatavilla.",
     "Use a second factor besides your password to increase security for your account." : "Käytä toista vaihetta salasanasi lisäksi parantaaksesi tilisi tietoturvaa.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Jos yhdistät kolmannen osapuolen ohjelmia Nextcloudiin, määritä niille sovellussalasanat ennen kaksiosaisen todentamismenetelmän käyttöönottoa.",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Tietokannasta puuttuu indeksejä. Suuriin tauluihin indeksien lisääminen saattaa kestää kauan, ja sen vuoksi indeksejä ei lisätty automaattisesti. Suorita \"occ db:add-missing-indices\" lisätäksesi puuttuvat indeksit manuaalisesti samalla, kun instanssi pysyy käynnissä. Kun indeksit on lisätty, kyselyt kyseisiin tauluihin ovat yleensä huomattavasti aiempaa nopeampia.",
     "File locking" : "Tiedostolukitus",
-    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "MariaDB:n versio \"%s\" on käytössä. Nextcloud 21 ja uudemmat eivät tue tätä versiota, vaatimus on MariaDB:n versio 10.2 tai uudempi.",
-    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "MySQL:n versio \"%s\" on käytössä. Nextcloud 21 ja uudemmat eivät tue tätä versiota, vaatimus on MySQL:n versio 8.0 tai MariaDB:n versio 10.2 tai uudempi.",
-    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "PostgreSQL:n versio \"%s\" on käytössä. Nextcloud 21 ja uudemmat eivät tue tätä versiota, vaatimus on PostgreSQL:n versio 9.6 tai uudempi.",
-    "Speech-To-Text" : "Puheesta tekstiksi",
     "Set default expiration date for shares" : "Aseta oletusarvoinen vanhenemispäivä jaoille",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Tämä sovellus ei ole määritellyt minimi Nextcloud-versiota. Tämä tulee olemaan ongelma tulevaisuudessa.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Tämä sovellus ei ole määritellyt maksimi Nextcloud-versiota. Tämä tulee olemaan ongelma tulevaisuudessa.",
     "Your biography" : "Sinun elämäkertasi",
     "You are using <strong>{usage}</strong>" : "Käytössäsi on <strong>{usage}</strong>",
     "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Käytössäsi on <strong>{usage}</strong>/<strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
-    "Username will be autogenerated" : "Käyttäjänimi luodaan automaattisesti",
-    "Username (required)" : "Käyttäjänimi (pakollinen)",
-    "New user" : "Uusi käyttäjä",
-    "Groups (required)" : "Ryhmät (pakollinen)",
-    "Set user groups" : "Aseta käyttäjäryhmät",
-    "Set user quota" : "Aseta käyttäjäkiintiö",
-    "Add new user" : "Lisää uusi käyttäjä",
-    "_{userCount} user …_::_{userCount} users …_" : ["{userCount} käyttäjä…","{userCount} käyttäjää…"],
-    "_{userCount} user_::_{userCount} users_" : ["{userCount} käyttäjä","{userCount} käyttäjää"],
-    "Loading users …" : "Ladataan käyttäjiä…",
-    "Username" : "Käyttäjätunnus",
-    "User backend" : "Käyttäjätaustaosa",
-    "User actions" : "Käyttäjätoiminnot",
-    "Add user to group" : "Lisää käyttäjä ryhmään",
-    "Server error while trying to add WebAuthn device" : "Palvelinvirhe kun yritettiin lisätä WebAuthn-laitetta",
-    "Name your device" : "Nimeä laitteesi",
-    "Active accounts" : "Aktiiviset tilit",
-    "Follow us on Twitter" : "Seuraa meitä Twitterissä"
+    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Laitteen kadotessa tai organisaatiosta poistuessa voidaan käyttäjälle {userid} Nextcloudiin yhdistetyistä laitteista pyyhkiä  tiedot. Toimii vain laitteiden ollessa yhteydessä Internetiin.",
+    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Sovellusta ei ole merkattu yhteensopivaksi Nextcloud-versiosi kanssa. Voit kuitenkin jatkaa ja asentaa sovelluksen. Huomioi, että sovellus ei välttämättä toimi odotetusti.",
+    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Turvallisuuden ja suorituskyvyn vuoksi on tärkeää, että palvelimen asetukset ovat määritetty oikein. Apuna on joitain automaattisia tarkistuksia. Lue lisätietoja linkitetystä dokumentaatiosta.",
+    "Checking for system and security issues." : "Tarkistetaan mahdollisia järjestelmä- ja tietoturvaongelmia.",
+    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Lue tarkkaan <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">asennusohjeet ↗</a>, ja tarkista virheet sekä varoitukset <a href=\"%2$s\">lokista</a>.",
+    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Tarkista Nextcloudisi turvallisuus käyttäen <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">tietoturvakartoitustamme ↗</a>."
 },
 "nplurals=2; plural=(n != 1);");
