@@ -109,15 +109,13 @@ OC.L10N.register(
     "Description" : "คำอธิบาย",
     "View in store" : "ดูในร้านค้า",
     "Visit website" : "เข้าสู่เว็บไซต์",
-    "Admin documentation" : "เอกสารประกอบสำหรับผู้ดูแลระบบ",
-    "Developer documentation" : "เอกสารประกอบสำหรับนักพัฒนา",
+    "Admin documentation" : "เอกสารสำหรับผู้ดูแลระบบ",
+    "Developer documentation" : "เอกสารสำหรับนักพัฒนา",
     "Details" : "รายละเอียด",
     "All" : "ทั้งหมด",
     "Limit app usage to groups" : "จำกัดการใช้แอปสำหรับกลุ่ม",
     "No results" : "ไม่มีผลลัพธ์",
     "Update to {version}" : "อัปเดตเป็น {version}",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "แอปนี้ไม่ได้ระบุรุ่นขั้นต่ำของ Nextcloud ซึ่งอาจเป็นปัญหาในอนาคตได้",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "แอปนี้ไม่ได้ระบุรุ่นสูงสุดของ Nextcloud ซึ่งอาจเป็นปัญหาในอนาคตได้",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "ไม่สามารถติดตั้งแอปนี้ เนื่องจากสิ่งที่พึ่งพาต่อไปนี้ยังไม่ครบ:",
     "Categories" : "หมวดหมู่",
     "Resources" : "ทรัพยากร",
@@ -159,10 +157,8 @@ OC.L10N.register(
     "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "การสำรองข้อมูลของคุณเป็นประจำเป็นเรื่องที่ดีเสมอ ในกรณีของการเข้ารหัส อย่าลืมสำรองคีย์เข้ารหัสพร้อมข้อมูลของคุณด้วย",
     "This is the final warning: Do you really want to enable encryption?" : "นี่คือการเตือนครั้งสุดท้าย: คุณต้องการเปิดใช้การเข้ารหัสจริง ๆ หรือไม่?",
     "Submit" : "ส่ง",
-    "Remove group" : "ลบกลุ่ม",
     "Current password" : "รหัสผ่านปัจจุบัน",
     "New password" : "รหัสผ่านใหม่",
-    "Change password" : "เปลี่ยนรหัสผ่าน",
     "Picture provided by original account" : "ใช้รูปภาพจากบัญชีเดิม",
     "Email options" : "ตัวเลือกอีเมล",
     "Remove primary email" : "ลบอีเมลหลักออก",
@@ -172,7 +168,7 @@ OC.L10N.register(
     "No email address set" : "ไม่ได้ระบุที่อยู่อีเมล",
     "Help translate" : "ช่วยแปล",
     "No language set" : "ไม่ได้ตั้งภาษา",
-    "Add" : "เพิ่ม",
+    "Week starts on {firstDayOfWeek}" : "เริ่มต้นสัปดาห์{firstDayOfWeek}",
     "Create" : "สร้าง",
     "Change" : "เปลี่ยนแปลง",
     "Delete" : "ลบ",
@@ -191,14 +187,12 @@ OC.L10N.register(
     "{size} used" : "ใช้ไป {size}",
     "Delete account" : "ลบบัญชี",
     "Resend welcome email" : "ส่งอีเมลยินดีต้อนรับซ้ำ",
-    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "ในกรณีที่อุปกรณ์สูญหายหรือออกจากองค์กร ตัวเลือกนี้สามารถล้างข้อมูล Nextcloud จากทุกอุปกรณ์ที่เชื่อมโยงกับ {userid} จากระยะไกล การล้างข้อมูลจะทำงานเฉพาะเมื่ออุปกรณ์เชื่อมต่อกับอินเทอร์เน็ตเท่านั้น",
     "Remote wipe of devices" : "ล้างอุปกรณ์จากระยะไกล",
     "Wipe {userid}'s devices" : "ล้างอุปกรณ์ของ {userid}",
     "Fully delete {userid}'s account including all their personal files, app data, etc." : "ลบบัญชีของ {userid} ทั้งหมด รวมถึงไฟล์ส่วนตัว ข้อมูลแอป และอื่น ๆ ทั้งหมด",
     "Account deletion" : "การลบบัญชี",
     "Delete {userid}'s account" : "ลบบัญชีของ {userid}",
     "Welcome mail sent!" : "ส่งอีเมลยินดีต้อนรับแล้ว!",
-    "Done" : "เสร็จสิ้น",
     "Edit" : "แก้ไข",
     "Show storage path" : "แสดงเส้นทางจัดเก็บข้อมูล",
     "Show last login" : "แสดงการเข้าสู่ระบบล่าสุด",
@@ -216,6 +210,11 @@ OC.L10N.register(
     "No devices configured." : "ไม่มีอุปกรณ์ที่กำหนดค่า",
     "The following devices are configured for your account:" : "อุปกรณ์เหล่านี้มีการกำหนดค่าสำหรับบัญชีของคุณแล้ว:",
     "Your browser does not support WebAuthn." : "เบราว์เซอร์ของคุณไม่รองรับ WebAuthn",
+    "Security & setup warnings" : "คำเตือนความปลอดภัยและการติดตั้ง",
+    "All checks passed." : "ผ่านการตรวจสอบทั้งหมด",
+    "There are some errors regarding your setup." : "มีข้อผิดพลาดบางอย่างเกี่ยวกับการติดตั้งของคุณ",
+    "There are some warnings regarding your setup." : "มีคำเตือนบางอย่างเกี่ยวกับการติดตั้งของคุณ",
+    "Apply" : "นำไปใช้",
     "Admins" : "ผู้ดูแลระบบ",
     "Sending…" : "กำลังส่ง....",
     "Email sent" : "ส่งอีเมลแล้ว",
@@ -236,7 +235,6 @@ OC.L10N.register(
     "Download and enable" : "ดาวน์โหลดและเปิดใช้งาน",
     "Disable" : "ปิดใช้งาน",
     "The app will be downloaded from the App Store" : "แอปจะถูกดาวน์โหลดจากร้านค้าแอป",
-    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "แอปนี้ยังไม่ถูกระบุว่ารองรับกับรุ่น Nextcloud ของคุณ หากคุณดำเนินการต่อ คุณจะสามารถติดตั้งแอปได้ แต่แอปอาจไม่ทำงานอย่างที่คาดหวังไว้",
     "Unknown" : "ไม่ทราบ",
     "Never" : "ไม่เคย",
     "Error: This app cannot be enabled because it makes the server unstable" : "ข้อผิดพลาด: ไม่สามารถเปิดใช้งานแอปนี้เพราะทำให้เซิร์ฟเวอร์ไม่เสถียร",
@@ -263,22 +261,16 @@ OC.L10N.register(
     "Credentials" : "ข้อมูลส่วนตัวสำหรับเข้าระบบ",
     "SMTP Password" : "รหัสผ่าน SMTP",
     "Save" : "บันทึก",
-    "Security & setup warnings" : "คำเตือนความปลอดภัยและการติดตั้ง",
-    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "การกำหนดค่าทุกอย่างให้ถูกต้องเป็นสิ่งสำคัญสำหรับความปลอดภัยและประสิทธิภาพของเซิร์ฟเวอร์ของคุณ เพื่อช่วยคุณในเรื่องนี้ เรากำลังทำการตรวจสอบอัตโนมัติ โปรดดูเอกสารประกอบที่ลิงก์มาสำหรับข้อมูลเพิ่มเติม",
-    "All checks passed." : "ผ่านการตรวจสอบทั้งหมด",
-    "There are some errors regarding your setup." : "มีข้อผิดพลาดบางอย่างเกี่ยวกับการติดตั้งของคุณ",
-    "There are some warnings regarding your setup." : "มีคำเตือนบางอย่างเกี่ยวกับการติดตั้งของคุณ",
-    "Checking for system and security issues." : "กำลังตรวจสอบปัญหาระบบและความปลอดภัย",
-    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "โปรดตรวจสอบ<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">คู่มือการติดตั้ง ↗</a>ซ้ำ และตรวจสอบข้อผิดพลาดหรือคำเตือนใน<a href=\"%2$s\">บันทึก</a>",
-    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "ตรวจสอบความปลอดภัยของ Nextcloud ของคุณผ่าน<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">การสแกนความปลอดภัยของเรา ↗</a>",
     "Reasons to use Nextcloud in your organization" : "เหตุผลที่ควรใช้ Nextcloud ในองค์กรของคุณ",
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "รุ่นที่ออกโดยชุมชนของ Nextcloud นี้ไม่ได้รับการสนับสนุน และไม่สามารถใช้งานการแจ้งเตือนทันทีได้",
     "Set default expiration date for shares" : "ตั้งวันหมดอายุค่าเริ่มต้นสำหรับการแชร์",
-    "New user" : "ผู้ใช้ใหม่",
-    "Username" : "ชื่อผู้ใช้",
-    "User backend" : "แบ็กเอนด์ของผู้ใช้",
-    "Add user to group" : "เพิ่มผู้ใช้เข้ากลุ่ม",
-    "Server error while trying to add WebAuthn device" : "เกิดข้อผิดพลาดเซิร์ฟเวอร์ขณะกำลังพยายามเพิ่มอุปกรณ์ WebAuthn",
-    "Name your device" : "ตั้งชื่ออุปกรณ์ของคุณ"
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "แอปนี้ไม่ได้ระบุรุ่นขั้นต่ำของ Nextcloud ซึ่งอาจเป็นปัญหาในอนาคตได้",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "แอปนี้ไม่ได้ระบุรุ่นสูงสุดของ Nextcloud ซึ่งอาจเป็นปัญหาในอนาคตได้",
+    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "ในกรณีที่อุปกรณ์สูญหายหรือออกจากองค์กร ตัวเลือกนี้สามารถล้างข้อมูล Nextcloud จากทุกอุปกรณ์ที่เชื่อมโยงกับ {userid} จากระยะไกล การล้างข้อมูลจะทำงานเฉพาะเมื่ออุปกรณ์เชื่อมต่อกับอินเทอร์เน็ตเท่านั้น",
+    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "แอปนี้ยังไม่ถูกระบุว่ารองรับกับรุ่น Nextcloud ของคุณ หากคุณดำเนินการต่อ คุณจะสามารถติดตั้งแอปได้ แต่แอปอาจไม่ทำงานอย่างที่คาดหวังไว้",
+    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "การกำหนดค่าทุกอย่างให้ถูกต้องเป็นสิ่งสำคัญสำหรับความปลอดภัยและประสิทธิภาพของเซิร์ฟเวอร์ของคุณ เพื่อช่วยคุณในเรื่องนี้ เรากำลังทำการตรวจสอบอัตโนมัติ โปรดดูเอกสารประกอบที่ลิงก์มาสำหรับข้อมูลเพิ่มเติม",
+    "Checking for system and security issues." : "กำลังตรวจสอบปัญหาระบบและความปลอดภัย",
+    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "โปรดตรวจสอบ<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">คู่มือการติดตั้ง ↗</a>ซ้ำ และตรวจสอบข้อผิดพลาดหรือคำเตือนใน<a href=\"%2$s\">บันทึก</a>",
+    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "ตรวจสอบความปลอดภัยของ Nextcloud ของคุณผ่าน<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">การสแกนความปลอดภัยของเรา ↗</a>"
 },
 "nplurals=1; plural=0;");
