@@ -9,15 +9,21 @@ OC.L10N.register(
     "Missing a temporary folder" : "Trūkst pagaidu mapes",
     "Could not write file to disk" : "Nevarēja ierakstīt datni diskā",
     "A PHP extension stopped the file upload" : "PHP paplašinājums apturēja datnes augšupielādi",
+    "text document" : "teksta dokuments",
+    "{user} has mentioned you in the text document {node}" : "{user} pieminēja Tevi teksta dokumentā {node}",
     "File not found" : "Datne nav atrasta",
     "Text" : "Teksts",
     "Translate" : "Tulkot",
     "Guest" : "Viesis",
+    "you" : "Tu",
+    "edit" : "rediģēt",
+    "Open in new tab" : "Atvērt jaunā cilnē",
     "Remove link" : "Noņemt saiti",
     "guest" : "viesis",
     "Offline" : "Bezsaistē",
     "Saving …" : "Saglabā ...",
     "Saved" : "Saglabāts",
+    "Unsaved changes" : "Nesaglabātas izmaiņas",
     "Keyboard shortcuts" : "Tastatūras saīsnes",
     "Bold" : "Treknraksts",
     "Italic" : "Slīpraksts",
@@ -26,21 +32,27 @@ OC.L10N.register(
     "Action" : "Darbība",
     "Undo" : "Atsaukt",
     "Redo" : "Atcelt atsaukšanu",
+    "Copy link to clipboard" : "Ievietot saiti starpliktuvē",
+    "Open link" : "Atvērt saiti",
+    "Save changes" : "Saglabāt izmaiņas",
     "Cancel" : "Atcelt",
     "URL" : "URL",
     "Update link" : "Atjaunināt saiti",
     "Select language" : "Atlasīt valodu",
     "to" : "kam",
     "Replace" : "Aizvietot",
+    "Upload" : "Augšupielādēt",
+    "Insert Table" : "Ievietot tabulu",
     "Edit" : "Labot",
     "Source code" : "Izejas kods",
     "Done" : "Pabeigts",
-    "Details" : "Detaļas",
+    "Details" : "Informācija",
     "Insert link" : "Ievietojiet saiti",
     "Command" : "Komanda",
+    "Choose" : "Izvēlēties",
     "Add folder description" : "Pievienot mapes aprakstu",
     "Use current version" : "Izmantot pašreizējo versiju",
-    "Info" : "Info",
+    "Info" : "Informācija",
     "Warning" : "Brīdinājums"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
