@@ -27,6 +27,7 @@ OC.L10N.register(
     "Could not complete login" : "Impossible de terminer la connexion",
     "State token missing" : "Jeton d’état manquant",
     "Your login token is invalid or has expired" : "Votre jeton de connexion est invalide ou a expiré",
+    "Please use original client" : "Veuillez utiliser le client d'origine",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "Cette version communautaire de Nextcloud n’est pas prise en charge et les notifications push sont limitées.",
     "Login" : "S’identifier",
     "Unsupported email length (>255)" : "Longueur de l’e-mail non supportée (> 255 caractères)",
@@ -39,10 +40,11 @@ OC.L10N.register(
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Cliquez sur le bouton suivant pour réinitialiser votre mot de passe. Si vous n’avez pas demandé cette réinitialisation de mot de passe, vous pouvez ignorer cet e-mail.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Cliquer sur le lien suivant pour réinitialiser votre mot de passe. Si vous n’avez pas demandé cette réinitialisation de mot de passe, alors ignorez cet e-mail.",
     "Reset your password" : "Réinitialiser votre mot de passe",
-    "The given provider is not available" : "Le fournisseur donné n'est pas disponible",
+    "The given provider is not available" : "Le fournisseur indiqué n'est pas disponible",
     "Task not found" : "Tâche non trouvée",
     "Internal error" : "Erreur interne",
     "Not found" : "Non trouvé",
+    "Node is locked" : "Le noeud est verrouillé",
     "Bad request" : "Requête erronée",
     "Requested task type does not exist" : "Le type de tâche demandé n’existe pas",
     "Necessary language model provider is not available" : "Le fournisseur de modèle de langage nécessaire n’est pas disponible",
@@ -51,6 +53,11 @@ OC.L10N.register(
     "No translation provider available" : "Aucun fournisseur de traduction n’est disponible",
     "Could not detect language" : "Impossible de détecter la langue",
     "Unable to translate" : "Impossible de traduire",
+    "[%d / %d]: %s" : "[%d / %d] : %s",
+    "Repair step:" : "Étape de réparation :",
+    "Repair info:" : "Informations de réparation :",
+    "Repair warning:" : "Avertissement de réparation :",
+    "Repair error:" : "Erreur de réparation :",
     "Nextcloud Server" : "Serveur Nextcloud",
     "Some of your link shares have been removed" : "Certains de vos liens partagés ont été supprimés.",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "En raison d’une faille de sécurité, nous avons supprimé certains de vos liens partagés. Consultez le lien ci-dessus pour plus d’informations.",
@@ -58,11 +65,6 @@ OC.L10N.register(
     "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Saisissez votre clé de licence dans l’application Support afin d’augmenter la limite de comptes. Cela vous donne également tous les avantages supplémentaires que Nextcloud Enterprise offre et est fortement recommandé pour l’exploitation dans les entreprises.",
     "Learn more ↗" : " En savoir plus ↗",
     "Preparing update" : "Préparation de la mise à jour",
-    "[%d / %d]: %s" : "[%d / %d] : %s",
-    "Repair step:" : "Étape de réparation :",
-    "Repair info:" : "Informations de réparation :",
-    "Repair warning:" : "Avertissement de réparation :",
-    "Repair error:" : "Erreur de réparation :",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "Veuillez utiliser la mise à jour en ligne de commande, car la mise à jour via le navigateur est désactivée dans votre fichier config.php.",
     "Turned on maintenance mode" : "Mode de maintenance activé",
     "Turned off maintenance mode" : "Mode de maintenance désactivé",
@@ -72,15 +74,132 @@ OC.L10N.register(
     "Update app \"%s\" from App Store" : "Mise à jour l’application « %s » depuis le magasin d’applications",
     "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Vérification de la possibilité de mettre à jour le schéma de la base de données pour %s (cela peut prendre un certain temps selon la taille de la base de données)",
     "Updated \"%1$s\" to %2$s" : "Mise à jour de « %1$s » vers %2$s",
-    "Set log level to debug" : "Réglage du niveau de journalisation à « débogage »",
-    "Reset log level" : "Réinitialisation du niveau de journalisation",
+    "Set log level to debug" : "Définir le niveau de journalisation sur débogage",
+    "Reset log level" : "Réinitialiser le niveau de journalisation",
     "Starting code integrity check" : "Lancement de la vérification d’intégrité du code",
     "Finished code integrity check" : "Fin de la vérification d’intégrité du code",
     "%s (incompatible)" : "%s (incompatible)",
     "The following apps have been disabled: %s" : "Les applications suivantes ont été désactivées : %s",
     "Already up to date" : "Déjà à jour",
-    "Error occurred while checking server setup" : "Une erreur s’est produite lors de la vérification de la configuration du serveur",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "Pour plus d’information, voir la {linkstart}documentation ↗{linkend}.",
+    "Windows Command Script" : "Script de commande Windows",
+    "Electronic book document" : "Livre électronique",
+    "TrueType Font Collection" : "Collection de police TrueType",
+    "Web Open Font Format" : "Format Web Open Font",
+    "GPX geographic data" : "Données géographiques GPX",
+    "Gzip archive" : "Archive Gzip",
+    "Adobe Illustrator document" : "Document Adobe Illustrator",
+    "Java source code" : "Code source Java",
+    "JavaScript source code" : "Code source Javascript",
+    "JSON document" : "Document JSON",
+    "Microsoft Access database" : "Base de données Microsoft Access",
+    "Microsoft OneNote document" : "Document Microsoft One Note",
+    "Microsoft Word document" : "Document Microsoft Word",
+    "Unknown" : "Inconnu",
+    "PDF document" : "Document PDF",
+    "PostScript document" : "Document PostScript",
+    "RSS summary" : "Résumé RSS",
+    "Android package" : "Paquet Android",
+    "KML geographic data" : "Données géographiques KML",
+    "KML geographic compressed data" : "Données géographiques compressées KML",
+    "Lotus Word Pro document" : "Document Lotus Word Pro",
+    "Excel spreadsheet" : "Feuille de calcul Excel",
+    "Excel add-in" : "Extension Excel",
+    "Excel 2007 binary spreadsheet" : "Feuille de calcul binaire Excel 2007",
+    "Excel spreadsheet template" : "Modèle de feuille de calcul Excel",
+    "Outlook Message" : "Message Outlook",
+    "PowerPoint presentation" : "Présentation Powerpoint",
+    "PowerPoint add-in" : "Extension PowerPoint",
+    "PowerPoint presentation template" : "Modèle de présentation PowerPoint",
+    "Word document" : "Document Word",
+    "ODF formula" : "Formule ODF",
+    "ODG drawing" : "Dessin ODG",
+    "ODG drawing (Flat XML)" : "Dessin ODG (Flat XML)",
+    "ODG template" : "Modèle ODG",
+    "ODP presentation" : "Présentation ODP",
+    "ODP presentation (Flat XML)" : "Présentation ODP (Flat XML)",
+    "ODP template" : "Modèle ODP",
+    "ODS spreadsheet" : "Feuille de calcul ODS",
+    "ODS spreadsheet (Flat XML)" : "Feuille de calcul ODS (Flat XML)",
+    "ODS template" : "Modèle ODS",
+    "ODT document" : "Document ODT",
+    "ODT document (Flat XML)" : "Document ODF (Flat XML)",
+    "ODT template" : "Modèle ODT",
+    "PowerPoint 2007 presentation" : "Présentation PowerPoint 2007",
+    "PowerPoint 2007 show" : "Diaporama PowerPoint 2007",
+    "PowerPoint 2007 presentation template" : "Modèle de présentation PowerPoint 2007",
+    "Excel 2007 spreadsheet" : "Feuille de calcul Excel 2007",
+    "Excel 2007 spreadsheet template" : "Modèle de feuille de calcul Excel 2007",
+    "Word 2007 document" : "Document Word 2007",
+    "Word 2007 document template" : "Modèle de document Word 2007",
+    "Microsoft Visio document" : "Document Microsoft Visio",
+    "WordPerfect document" : "Document WordPerfect",
+    "7-zip archive" : "Archive 7-zip",
+    "Blender scene" : "Scène Blender",
+    "Bzip2 archive" : "Archive Bzip2",
+    "Debian package" : "Paquet Debian",
+    "FictionBook document" : "Document FictionBook",
+    "Unknown font" : "Police de caractère inconnue",
+    "Krita document" : "Document Krita",
+    "Mobipocket e-book" : "Livre électronique Mobipocket",
+    "Windows Installer package" : "Paquet d'installation Windows",
+    "Perl script" : "Script Perl",
+    "PHP script" : "Script PHP",
+    "Tar archive" : "Archive Tar",
+    "XML document" : "Document XML",
+    "YAML document" : "Document YAML",
+    "Zip archive" : "Archive Zip",
+    "Zstandard archive" : "Archive Zstandard",
+    "AAC audio" : "Fichier audio AAC",
+    "FLAC audio" : "Fichier audio FLAC",
+    "MPEG-4 audio" : "Fichier audio MPEG-4",
+    "MP3 audio" : "Fichier audio MP3",
+    "Ogg audio" : "Fichier audio Ogg",
+    "RIFF/WAVe standard Audio" : "Fichier audio standard RIFF/WAVe",
+    "WebM audio" : "Fichier audio WebM",
+    "MP3 ShoutCast playlist" : "Liste de lecture ShoutCast MP3",
+    "Windows BMP image" : "Image Windows BMP",
+    "Better Portable Graphics image" : "Image Better Portable Graphics",
+    "EMF image" : "Image EMF",
+    "GIF image" : "Image GIF",
+    "HEIC image" : "Image HEIC",
+    "HEIF image" : "Image HEIF",
+    "JPEG-2000 JP2 image" : "Image JPEG-2000 JP2",
+    "JPEG image" : "Image JPEG",
+    "PNG image" : "Image PNG",
+    "SVG image" : "Image SVG",
+    "Truevision Targa image" : "Image Truevision Targa",
+    "TIFF image" : "Image TIFF",
+    "WebP image" : "Image WebP",
+    "Digital raw image" : "Image Digital raw",
+    "Windows Icon" : "Icône Windows",
+    "Email message" : "E-mail",
+    "VCS/ICS calendar" : "Calendrier VCS/ICS",
+    "CSS stylesheet" : "Feuille de style CSS",
+    "CSV document" : "Document CSV",
+    "HTML document" : "Document HTML",
+    "Markdown document" : "Document Markdown",
+    "Org-mode file" : "Fichier Org-mode",
+    "Plain text document" : "Document texte brut",
+    "Rich Text document" : "Document texte enrichi",
+    "Electronic business card" : "Carte de visite électronique",
+    "C++ source code" : "Code source C++",
+    "LDIF address book" : "Carnet d'adresses LDIF",
+    "NFO document" : "Document NFO",
+    "PHP source" : "Code source PHP",
+    "Python script" : "Script Python",
+    "ReStructuredText document" : "Document ReStructuredText",
+    "3GPP multimedia file" : "Fichier multimédia 3GPP",
+    "MPEG video" : "Vidéo MPEG",
+    "DV video" : "Vidéo DV",
+    "MPEG-2 transport stream" : "Flux de transport MPEG-2",
+    "MPEG-4 video" : "Vidéo MPEG-4",
+    "Ogg video" : "Vidéo OGG",
+    "QuickTime video" : "Vidéo QuickTime",
+    "WebM video" : "Vidéo WebM",
+    "Flash video" : "Vidéo Flash",
+    "Matroska video" : "Vidéo Matroska",
+    "Windows Media video" : "Vidéo Windows Media",
+    "AVI video" : "Vidéo AVI",
     "unknown text" : "texte inconnu",
     "Hello world!" : "Hello world!",
     "sunny" : "ensoleillé",
@@ -105,11 +224,11 @@ OC.L10N.register(
     "Yes" : "Oui",
     "The remote URL must include the user." : "L'URL distante doit inclure l'utilisateur.",
     "Invalid remote URL." : "URL distante invalide.",
-    "Failed to add the public link to your Nextcloud" : "Échec de l'ajout du lien public à votre Nextcloud",
+    "Failed to add the public link to your Nextcloud" : "Impossible d'ajouter le lien public à votre Nextcloud",
     "Federated user" : "Utilisateur fédéré",
     "user@your-nextcloud.org" : "utilisateur@votre-nextcloud.org",
     "Create share" : "Créer un partage",
-    "Direct link copied to clipboard" : "Lien direct copié dans le presse-papiers",
+    "Direct link copied" : "Lien direct copié",
     "Please copy the link manually:" : "Veuillez copier le lien manuellement :",
     "Custom date range" : "Plage de dates personnalisée",
     "Pick start date" : "Sélectionner une date de début",
@@ -133,6 +252,7 @@ OC.L10N.register(
     "Search people" : "Rechercher des personnes",
     "People" : "Personnes",
     "Filter in current view" : "Filtrer dans la vue actuelle",
+    "Search connected services" : "Services connectés de recherche",
     "Results" : "Résultats",
     "Load more results" : "Charger plus de résultats",
     "Search in" : "Rechercher dans",
@@ -146,8 +266,8 @@ OC.L10N.register(
     "Account name" : "Nom du compte",
     "Server side authentication failed!" : "L’authentification sur le serveur a échoué !",
     "Please contact your administrator." : "Veuillez contacter votre administrateur.",
-    "Temporary error" : "Erreur temporaire",
-    "Please try again." : "Veuillez réessayer.",
+    "Session error" : "Erreur de session",
+    "It appears your session token has expired, please refresh the page and try again." : "Il semblerait que votre jeton de session ait expiré, veuillez rafraîchir la page et essayer à nouveau.",
     "An internal error occurred." : "Une erreur interne est survenue.",
     "Please try again or contact your administrator." : "Veuillez réessayer ou contactez votre administrateur.",
     "Password" : "Mot de passe",
@@ -197,7 +317,7 @@ OC.L10N.register(
     "No results for {query}" : "Aucun résultat pour {query}",
     "Press Enter to start searching" : "Appuyer sur Entrée pour démarrer la recherche",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Veuillez saisir au moins {minSearchLength} caractère pour lancer la recherche","Veuillez saisir au moins {minSearchLength} caractères pour lancer la recherche","Veuillez saisir au moins {minSearchLength} caractères pour lancer la recherche"],
-    "An error occurred while searching for {type}" : "Une erreur s’est produite lors de la recherche de {type}",
+    "An error occurred while searching for {type}" : "Une erreur est survenue lors de la recherche de {type}",
     "Search starts once you start typing and results may be reached with the arrow keys" : "La recherche démarre dès que vous commencez à taper et les résultats peuvent être atteints avec les flèches du clavier",
     "Search for {name} only" : "Rechercher pour {name} uniquement",
     "Loading more results …" : "Chargement de plus de résultats …",
@@ -205,11 +325,32 @@ OC.L10N.register(
     "Back to login form" : "Retour au formulaire de connexion",
     "Back" : "Retour",
     "Login form is disabled." : "Le formulaire de connexion est désactivé.",
-    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Le formulaire de connexion Nextcloud est désactivé. Utilisez une autre option de connexion si disponible ou contactez votre administration.",
-    "More actions" : "Plus d'actions…",
+    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Le formulaire de connexion Nextcloud est désactivé. Utilisez une autre option de connexion si disponible ou contactez un administrateur.",
+    "More actions" : "Plus d'actions",
+    "User menu" : "Menu utilisateur",
+    "Your guest name: {user}" : "Votre nom d'invité : {user}",
+    "You are currently not identified." : "Vous n'êtes actuellement pas identifié.",
+    "Set public name" : "Définir le nom public",
+    "Change public name" : "Changer le nom public",
+    "Password is too weak" : "Mot de passe trop faible",
+    "Password is weak" : "Mot de passe faible",
+    "Password is average" : "Mot de passe moyen",
+    "Password is strong" : "Mot de passe fort",
+    "Password is very strong" : "Mot de passe très fort",
+    "Password is extremely strong" : "Mot de passe extrêmement fort",
+    "Unknown password strength" : "Sécurité du mot de passe inconnue",
+    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Votre répertoire de données est certainement accessible depuis Internet car le fichier <code>.htaccess</code> ne fonctionne pas.",
+    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Pour savoir comment configurer correctement votre serveur, veuillez lire la {linkStart}documentation{linkEnd}.",
+    "Autoconfig file detected" : "Fichier de configuration automatique détecté",
+    "The setup form below is pre-filled with the values from the config file." : "Le formulaire de configuration ci-dessous est pré-rempli avec les valeurs du fichier de configuration.",
     "Security warning" : "Avertissement de sécurité",
+    "Create administration account" : "Créer un compte administrateur",
+    "Administration account name" : "Nom du compte administrateur",
+    "Administration account password" : "Mot de passe du compte administrateur",
     "Storage & database" : "Stockage & base de données",
     "Data folder" : "Répertoire des données",
+    "Database configuration" : "Configuration de la base de données",
+    "Only {firstAndOnlyDatabase} is available." : "Seul(e) {firstAndOnlyDatabase} est disponible.",
     "Install and activate additional PHP modules to choose other database types." : "Installez et activez les modules PHP additionnels adéquats pour choisir d’autres types de base de données.",
     "For more details check out the documentation." : "Consultez la documentation pour plus de détails.",
     "Performance warning" : "Avertissement à propos des performances",
@@ -222,6 +363,7 @@ OC.L10N.register(
     "Database tablespace" : "Espace de stockage de la base de données",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Veuillez spécifier le numéro du port avec le nom de l’hôte (par exemple, localhost:5432).",
     "Database host" : "Hôte de la base de données",
+    "localhost" : "localhost",
     "Installing …" : "Installation...",
     "Install" : "Installer",
     "Need help?" : "Besoin d’aide ?",
@@ -283,16 +425,17 @@ OC.L10N.register(
     "Admin" : "Administration",
     "Help" : "Aide",
     "Access forbidden" : "Accès non autorisé",
+    "You are not allowed to access this page." : "Vous n'êtes pas autorisé à accéder à cette page.",
+    "Back to %s" : "Retour à %s",
     "Page not found" : "Page non trouvée",
     "The page could not be found on the server or you may not be allowed to view it." : "La page n'a pas pu être trouvée sur le serveur ou vous n'avez pas le droit de la visualiser.",
-    "Back to %s" : "Retour à %s",
     "Too many requests" : "Trop de requêtes",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Il y a trop de requêtes depuis votre réseau. Réessayez plus tard ou contactez votre administrateur s'il s'agit d'une erreur.",
     "Error" : "Erreur",
     "Internal Server Error" : "Erreur interne du serveur",
     "The server was unable to complete your request." : "Le serveur est incapable d'exécuter votre requête.",
     "If this happens again, please send the technical details below to the server administrator." : "Si cela se reproduit, veuillez envoyer les détails techniques ci-dessous à l'administrateur du serveur.",
-    "More details can be found in the server log." : "Le fichier journal du serveur peut fournir plus de renseignements.",
+    "More details can be found in the server log." : "Le fichier log du serveur peut fournir plus de renseignements.",
     "For more details see the documentation ↗." : "Pour plus de détails, voir la documentation ↗.",
     "Technical details" : "Renseignements techniques",
     "Remote Address: %s" : "Adresse distante : %s",
@@ -315,7 +458,7 @@ OC.L10N.register(
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Si vous n'essayez pas d'ajouter un nouveau périphérique ou une nouvelle application, quelqu'un fait une tentative d'accès à vos données. Dans ce cas, ne continuez pas et contactez votre administrateur système.",
     "App password" : "Mot de passe d'application",
     "Grant access" : "Autoriser l'accès",
-    "Alternative log in using app password" : "Authentification alternative en utilisant un mot de passe d'application",
+    "Alternative log in using app password" : "Connexion à l'aide d'un mot de passe d'application",
     "Account access" : "Accès au compte",
     "Currently logged in as %1$s (%2$s)." : "Connecté en tant que %1$s (%2$s).",
     "You are about to grant %1$s access to your %2$s account." : "Vous êtes sur le point d’accorder à « %1$s » l’accès à votre compte « %2$s ».",
@@ -351,7 +494,7 @@ OC.L10N.register(
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Veuillez vous assurer qu’une copie de sauvegarde de la base de données, du dossier de configuration (config) et du dossier de données (data) a été réalisée avant de commencer.",
     "Start update" : "Démarrer la mise à jour",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Afin d'éviter les délais d'expiration avec les installations de volume conséquent, vous pouvez exécuter la commande suivante depuis le répertoire d'installation :",
-    "Detailed logs" : "Journaux détaillés",
+    "Detailed logs" : "Logs détaillés",
     "Update needed" : "Mise à jour nécessaire",
     "Please use the command line updater because you have a big instance with more than 50 accounts." : "Veuillez utiliser la mise à jour en ligne de commande car votre instance est volumineuse avec plus de 50 comptes.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Pour obtenir de l'aide, lisez la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>.",
@@ -361,16 +504,14 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Cette instance de %s est en cours de maintenance, cela peut prendre du temps.",
     "This page will refresh itself when the instance is available again." : "Cette page se rafraîchira d'elle-même lorsque le serveur sera de nouveau disponible.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Veuillez contacter votre administrateur système si ce message persiste ou apparaît de façon inattendue.",
-    "Currently open" : "Actuellement ouvert",
-    "Login with username or email" : "Se connecter avec un nom d’utilisateur ou un e-mail",
-    "Login with username" : "Se connecter avec un nom d’utilisateur",
+    "Error occurred while checking server setup" : "Une erreur est survenue lors de la vérification de la configuration du serveur",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "Pour plus d’information, voir la {linkstart}documentation ↗{linkend}.",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Discussions, appels vidéo, partage d’écran, réunions en ligne et conférences web – depuis votre navigateur et les applications mobiles.",
     "You have not added any info yet" : "Vous n’avez pas ajouté d’informations pour le moment",
     "{user} has not added any info yet" : "{user} n’a pas ajouté d’informations pour le moment",
     "Error opening the user status modal, try hard refreshing the page" : "Erreur lors de l'ouverture du modal du statut de l'utilisateur, essayez d'actualiser la page",
     "Edit Profile" : "Modifier le profil",
     "The headline and about sections will show up here" : "Le titre et la section « À propos » apparaîtront ici",
-    "Error loading message template: {error}" : "Erreur lors du chargement du modèle de message : {error}",
     "Very weak password" : "Mot de passe très faible",
     "Weak password" : "Mot de passe faible",
     "So-so password" : "Mot de passe tout juste acceptable",
@@ -382,11 +523,12 @@ OC.L10N.register(
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Pour les informations de configuration de votre serveur, veuillez lire la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>.",
     "<strong>Create an admin account</strong>" : "<strong>Créer un compte administrateur</strong>",
     "New admin account name" : "Nouveau nom de compte administrateur",
-    "New admin password" : "Nouveau mot de passe admin",
+    "New admin password" : "Nouveau mot de passe administrateur",
     "Show password" : "Afficher le mot de passe",
     "Toggle password visibility" : "Activer/Désactiver la visibilité du mot de passe",
     "Configure the database" : "Configurer la base de données",
     "Only %s is available." : "Seul(e) %s est disponible.",
-    "Database account" : "Compte de base de données"
+    "Database account" : "Compte de base de données",
+    "Direct link copied to clipboard" : "Lien direct copié dans le presse-papiers"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
