@@ -27,6 +27,7 @@ OC.L10N.register(
     "Could not complete login" : "Non foi posíbel completar o acceso",
     "State token missing" : "Falta o testemuño de estado",
     "Your login token is invalid or has expired" : "O seu testemuño de acceso non é válido ou caducou",
+    "Please use original client" : "Utilice o cliente orixinal",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "Esta edición comunitaria de Nextcloud non é compatíbel e as notificacións emerxentes son limitadas.",
     "Login" : "Acceder",
     "Unsupported email length (>255)" : "Lonxitude de correo-e non admitida (>255)",
@@ -43,6 +44,7 @@ OC.L10N.register(
     "Task not found" : "Non se atopou a tarefa",
     "Internal error" : "Produciuse un erro interno",
     "Not found" : "Non atopado",
+    "Node is locked" : "O nodo está bloqueado",
     "Bad request" : "Solicitude incorrecta",
     "Requested task type does not exist" : "O tipo de tarefa solicitado non existe",
     "Necessary language model provider is not available" : "O provedor de modelos de linguaxe necesario non está dispoñíbel",
@@ -51,6 +53,11 @@ OC.L10N.register(
     "No translation provider available" : "Non hai ningún provedor de tradución dispoñíbel",
     "Could not detect language" : "Non foi posíbel detectar o idioma",
     "Unable to translate" : "Non é posíbel traducir",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair step:" : "Paso do arranxo:",
+    "Repair info:" : "Información do arranxo:",
+    "Repair warning:" : "Advertencia de arranxo:",
+    "Repair error:" : "Erro do arranxo:",
     "Nextcloud Server" : "Servidor de Nextcloud",
     "Some of your link shares have been removed" : "Retiráronse algunhas das súas ligazóns para compartir",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Por mor dun fallo de seguranza tivemos que retirar algunhas das súas ligazóns para compartir. Vexa a ligazón para obter máis información.",
@@ -58,11 +65,6 @@ OC.L10N.register(
     "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Introduza a súa chave de subscrición na aplicación de asistencia para aumentar o límite da conta. Isto tamén lle outorga todos os beneficios adicionais que ofrece Nextcloud Enterprise e é moi recomendábel para a operativa nas empresas.",
     "Learn more ↗" : "Máis información ↗",
     "Preparing update" : "Preparando a actualización",
-    "[%d / %d]: %s" : "[%d / %d]: %s",
-    "Repair step:" : "Paso do arranxo:",
-    "Repair info:" : "Información do arranxo:",
-    "Repair warning:" : "Advertencia de arranxo:",
-    "Repair error:" : "Erro do arranxo:",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "Use o actualizador da liña de ordes porque a actualización a través do navegador está desactivada no seu config.php.",
     "Turned on maintenance mode" : "Modo de mantemento activado",
     "Turned off maintenance mode" : "Modo de mantemento desactivado",
@@ -79,8 +81,125 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (incompatíbel)",
     "The following apps have been disabled: %s" : "As seguintes aplicacións foron desactivadas: %s",
     "Already up to date" : "Xa está actualizado",
-    "Error occurred while checking server setup" : "Aconteceu un erro mentras se comprobaba a configuración do servidor",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "Para obter máis detalles revise a {linkstart}documentación ↗{linkend}.",
+    "Windows Command Script" : "Script de ordes de Windows",
+    "Electronic book document" : "Documento de libro electrónico",
+    "TrueType Font Collection" : "Colección de tipos de letra TrueType",
+    "Web Open Font Format" : "Formato de tipo de letra aberto para a web (WOFF)",
+    "GPX geographic data" : "Datos xeográficos GPX",
+    "Gzip archive" : "Arquivo Gzip",
+    "Adobe Illustrator document" : "Documento de Adobe Illustrator",
+    "Java source code" : "Código fonte de Java",
+    "JavaScript source code" : "Código fonte de JavaScript",
+    "JSON document" : "Documento JSON",
+    "Microsoft Access database" : "Base de datos de Microsoft Access",
+    "Microsoft OneNote document" : "Documento de Microsoft OneNote",
+    "Microsoft Word document" : "Documento de Microsoft Word",
+    "Unknown" : "Descoñecido",
+    "PDF document" : "Documento PDF",
+    "PostScript document" : "Documento PostScript",
+    "RSS summary" : "Resumo RSS",
+    "Android package" : "Paquete para Android",
+    "KML geographic data" : "Datos xeográficos KML",
+    "KML geographic compressed data" : "Datos xeográficos comprimidos de KML.",
+    "Lotus Word Pro document" : "Documento de Lotus Word Pro",
+    "Excel spreadsheet" : "Folla de cálculo de Excel",
+    "Excel add-in" : "Engadido de Excel",
+    "Excel 2007 binary spreadsheet" : "Folla de cálculo binaria de Excel 2007",
+    "Excel spreadsheet template" : "Modelo de folla de cálculo de Excel",
+    "Outlook Message" : "Mensaxe de Outlook",
+    "PowerPoint presentation" : "Presentación en PowerPoint",
+    "PowerPoint add-in" : "Engadido de PowerPoint",
+    "PowerPoint presentation template" : "Modelo de presentación de PowerPoint",
+    "Word document" : "Documento de Word",
+    "ODF formula" : "Fórmula ODF",
+    "ODG drawing" : "Debuxo ODG",
+    "ODG drawing (Flat XML)" : "Debuxo ODG (XML sinxelo)",
+    "ODG template" : "Modelo ODG",
+    "ODP presentation" : "Presentación ODP",
+    "ODP presentation (Flat XML)" : "Presentación ODP (XML sinxelo)",
+    "ODP template" : "Modelo ODP",
+    "ODS spreadsheet" : "Folla de cálculo ODS",
+    "ODS spreadsheet (Flat XML)" : "Folla de cálculo ODS (XML sinxelo)",
+    "ODS template" : "Modelo ODS",
+    "ODT document" : "Documento ODT",
+    "ODT document (Flat XML)" : "Documento ODT (XML sinxelo)",
+    "ODT template" : "Modelo ODT",
+    "PowerPoint 2007 presentation" : "Presentación de PowerPoint 2007",
+    "PowerPoint 2007 show" : "Amosar PowerPoint 2007",
+    "PowerPoint 2007 presentation template" : "Modelo de presentación de PowerPoint 2007",
+    "Excel 2007 spreadsheet" : "Folla de cálculo de Excel 2007",
+    "Excel 2007 spreadsheet template" : "Modelo de folla de cálculo de Excel 2007",
+    "Word 2007 document" : "Documento de Word 2007",
+    "Word 2007 document template" : "Modelo de documento de Word 2007",
+    "Microsoft Visio document" : "Documento de Microsoft Visio",
+    "WordPerfect document" : "Documento de WordPerfect",
+    "7-zip archive" : "Arquivo 7-zip",
+    "Blender scene" : "Escena de Blender",
+    "Bzip2 archive" : "Arquivo Bzip2",
+    "Debian package" : "Paquete para Debian",
+    "FictionBook document" : "Documento de FictionBook",
+    "Unknown font" : "Tipo de letra descoñecido",
+    "Krita document" : "Documento de Krita",
+    "Mobipocket e-book" : "Libro electrónico de Mobipocket",
+    "Windows Installer package" : "Paquete do programa de instalación de Windows",
+    "Perl script" : "Script de Perl",
+    "PHP script" : "Script de PHP",
+    "Tar archive" : "Arquivo Tar",
+    "XML document" : "Documento XML",
+    "YAML document" : "Documento YAML",
+    "Zip archive" : "Arquivo Zip",
+    "Zstandard archive" : "Arquivo Zstandard",
+    "AAC audio" : "Son dixital AAC",
+    "FLAC audio" : "Son dixital FLAC",
+    "MPEG-4 audio" : "Son dixital MPEG-4",
+    "MP3 audio" : "Son dixital MP3",
+    "Ogg audio" : "Son dixital Ogg",
+    "RIFF/WAVe standard Audio" : "Son dixital estándar RIFF/WAVe",
+    "WebM audio" : "Son dixital WebM",
+    "MP3 ShoutCast playlist" : "Lista de reprodución ShoutCast en MP3",
+    "Windows BMP image" : "Imaxe BMP de Windows",
+    "Better Portable Graphics image" : "Imaxe «Better Portable Graphic»",
+    "EMF image" : "Imaxe EMF",
+    "GIF image" : "Imaxe GIF",
+    "HEIC image" : "Imaxe HEIC",
+    "HEIF image" : "Imaxe HEIF",
+    "JPEG-2000 JP2 image" : "Imaxe JPEG-2000 JP2",
+    "JPEG image" : "Imaxe JPEG",
+    "PNG image" : "Imaxe PNG",
+    "SVG image" : "Imaxe SVG",
+    "Truevision Targa image" : "Imaxe Targa de Truevision",
+    "TIFF image" : "Imaxe TIFF",
+    "WebP image" : "Imaxe WebP",
+    "Digital raw image" : "Imaxe dixital crúa",
+    "Windows Icon" : "Icona de Windows",
+    "Email message" : "Mensaxe de correo-e",
+    "VCS/ICS calendar" : "Calendario VCS/ICS",
+    "CSS stylesheet" : "Folla de estilo CSS",
+    "CSV document" : "Documento CSV",
+    "HTML document" : "Documento HTML",
+    "Markdown document" : "Documento Markdown",
+    "Org-mode file" : "Ficheiro Org-mode",
+    "Plain text document" : "Documento de texto simple",
+    "Rich Text document" : "Documento de texto mellorado",
+    "Electronic business card" : "Tarxeta de visita electrónica",
+    "C++ source code" : "Código fonte de C++",
+    "LDIF address book" : "Caderno de enderezos LDIF",
+    "NFO document" : "Documento NFO",
+    "PHP source" : "Orixe en PHP",
+    "Python script" : "Script de Python",
+    "ReStructuredText document" : "Documento ReStructuredText",
+    "3GPP multimedia file" : "Ficheiro multimedia 3GPP",
+    "MPEG video" : "Vídeo MPEG",
+    "DV video" : "Vídeo DV",
+    "MPEG-2 transport stream" : "Fluxo de transporte MPEG-2",
+    "MPEG-4 video" : "Vídeo MPEG-4",
+    "Ogg video" : "Vídeo Ogg",
+    "QuickTime video" : "Vídeo QuickTime",
+    "WebM video" : "Vídeo WebM",
+    "Flash video" : "Vídeo Flash",
+    "Matroska video" : "Vídeo Matroska",
+    "Windows Media video" : "Vídeo Windows Media",
+    "AVI video" : "Vídeo AVI",
     "unknown text" : "texto descoñecido",
     "Hello world!" : "Ola xente!",
     "sunny" : "soleado",
@@ -109,7 +228,7 @@ OC.L10N.register(
     "Federated user" : "Usuario federado",
     "user@your-nextcloud.org" : "usuario@o-seu-nextcloud.org",
     "Create share" : "Crear compartición",
-    "Direct link copied to clipboard" : "A ligazón directa foi copiada no portapapeis",
+    "Direct link copied" : "Ligazón directa copiada",
     "Please copy the link manually:" : "Copie a ligazón manualmente:",
     "Custom date range" : "Intervalo de datas personalizado",
     "Pick start date" : "Escolla a data de inicio",
@@ -117,7 +236,7 @@ OC.L10N.register(
     "Search in date range" : "Buscar nun intervalo de datas",
     "Search in current app" : "Buscar na aplicación actual",
     "Clear search" : "Limpar a busca",
-    "Search everywhere" : "Buscar por todas partes",
+    "Search everywhere" : "Buscar en todos os sitios",
     "Searching …" : "Buscando…",
     "Start typing to search" : "Comece a escribir para buscar",
     "No matching results" : "Non hai resultados coincidentes",
@@ -133,6 +252,7 @@ OC.L10N.register(
     "Search people" : "Buscar persoas",
     "People" : "Persoas",
     "Filter in current view" : "Filtrar na vista actual",
+    "Search connected services" : "Buscar servizos conectados",
     "Results" : "Resultados",
     "Load more results" : "Cargando máis resultados",
     "Search in" : "Buscar en",
@@ -146,8 +266,8 @@ OC.L10N.register(
     "Account name" : "Nome da conta",
     "Server side authentication failed!" : "A autenticación fracasou do lado do servidor!",
     "Please contact your administrator." : "Contacte coa administración desta instancia.",
-    "Temporary error" : "produciuse un erro temporal",
-    "Please try again." : "Ténteo de novo",
+    "Session error" : " Produciuse un erro na sesión",
+    "It appears your session token has expired, please refresh the page and try again." : "Semella  que o testemuño de sesión caducou, actualice a páxina e ténteo de novo.",
     "An internal error occurred." : "Produciuse un erro interno",
     "Please try again or contact your administrator." : "Ténteo de novo ou póñase en contacto coa administración desta instancia.",
     "Password" : "Contrasinal",
@@ -207,9 +327,30 @@ OC.L10N.register(
     "Login form is disabled." : "O formulario de acceso está bloqueado.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "O formulario de acceso a Nextcloud está desactivado. Use outra opción de acceso se está dispoñíbel ou póñase en contacto coa súa administración.",
     "More actions" : "Máis accións",
+    "User menu" : "Menú de usuario",
+    "Your guest name: {user}" : "Nome do seu convidado: {user}",
+    "You are currently not identified." : "Actualmente non está identificado.",
+    "Set public name" : "Definir o nome público",
+    "Change public name" : "Cambiar o nome público",
+    "Password is too weak" : "O contrasinal é demasiado feble",
+    "Password is weak" : "O contrasinal é feble",
+    "Password is average" : "O contrasinal é normaliño",
+    "Password is strong" : "O contrasinal é seguro",
+    "Password is very strong" : "O contrasinal é moi seguro",
+    "Password is extremely strong" : "O contrasinal é extremadamente seguro",
+    "Unknown password strength" : "Descoñecese a seguridade do contrasinal",
+    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "O seu directorio de datos e os ficheiros probabelmente sexan accesíbeis desde a Internet xa que o ficheiro <code>.htaccess</code> non está a traballar.",
+    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Para obter información de como configurar axeitadamente o servidor, {linkStart}vexa a documentación{linkEnd}.",
+    "Autoconfig file detected" : "Detectouse o ficheiro de configuración automática",
+    "The setup form below is pre-filled with the values from the config file." : "O seguinte formulario de configuración está precuberto cos valores do ficheiro de configuración.",
     "Security warning" : "Advertencia de seguranza",
+    "Create administration account" : "Crear unha conta de administración",
+    "Administration account name" : "Nome da conta de administración",
+    "Administration account password" : "Contrasinal da conta de administración",
     "Storage & database" : "Almacenamento e base de datos",
     "Data folder" : "Cartafol de datos",
+    "Database configuration" : "Configuración da base de datos",
+    "Only {firstAndOnlyDatabase} is available." : "Só está dispoñíbel {firstAndOnlyDatabase}.",
     "Install and activate additional PHP modules to choose other database types." : "Instale e active os módulos de PHP adicionais para escoller outros tipos de bases de datos.",
     "For more details check out the documentation." : "Para obter máis detalles revise a documentación.",
     "Performance warning" : "Advertencia de rendemento",
@@ -222,6 +363,7 @@ OC.L10N.register(
     "Database tablespace" : "Táboa de espazos da base de datos",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Especifique o número do porto xunto co nome do anfitrión (p. ex. localhost:5432)",
     "Database host" : "Servidor da base de datos",
+    "localhost" : "localhost",
     "Installing …" : "Instalando…",
     "Install" : "Instalar",
     "Need help?" : "Precisa axuda?",
@@ -232,7 +374,7 @@ OC.L10N.register(
     "Continue with this unsupported browser" : "Continuar con este navegador non compatíbel",
     "Supported versions" : "Versións compatíbeis",
     "Search {types} …" : "Buscando {types}…",
-    "Choose {file}" : "Escoller  {file}",
+    "Choose {file}" : "Escoller {file}",
     "Choose" : "Escoller",
     "Copy to {target}" : "Copiar en {target}",
     "Copy" : "Copiar",
@@ -283,9 +425,10 @@ OC.L10N.register(
     "Admin" : "Administración",
     "Help" : "Axuda",
     "Access forbidden" : "Acceso denegado",
+    "You are not allowed to access this page." : "Vde. non ten permiso para acceder a esta páxina.",
+    "Back to %s" : "Volver a %s",
     "Page not found" : "Non se atopou a páxina",
     "The page could not be found on the server or you may not be allowed to view it." : "Non foi posíbel atopar a páxina no servidor ou é posíbel que non teña permiso para vela.",
-    "Back to %s" : "Volver a %s",
     "Too many requests" : "Demasiadas solicitudes",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Houbo demasiadas solicitudes da súa rede. Volva tentalo máis adiante ou póñase en contacto coa administración desta instancia se se trata dun erro.",
     "Error" : "Erro",
@@ -328,7 +471,7 @@ OC.L10N.register(
     "Please type in your email address to request a temporary password" : "Escriba o seu enderezo de correo para solicitar un contrasinal temporal",
     "Email address" : "Enderezo de correo",
     "Password sent!" : "Contrasinal enviado!",
-    "You are not authorized to request a password for this share" : "Non ten autorización para solicitar un contrasinal para esta compartición",
+    "You are not authorized to request a password for this share" : "Vde. non ten autorización para solicitar un contrasinal para esta compartición",
     "Two-factor authentication" : "Autenticación de dous factores",
     "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Foi activada a seguranza obrigatoria para a súa conta. Escolla un segundo factor para a autenticación. ",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Non foi posíbel cargar alomenos un dos seus métodos de autenticación de dous factores. Póñase en contacto cun administrador.",
@@ -361,16 +504,14 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Esta instancia de %s atopase en modo de mantemento, isto pode levar un anaco.",
     "This page will refresh itself when the instance is available again." : "Esta páxina actualizarase automaticamente cando a instancia estea dispoñíbel de novo.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Póñase en contacto coa administración do sistema se persiste esta mensaxe ou se aparece de forma inesperada.",
-    "Currently open" : "Aberto actualmente",
-    "Login with username or email" : "Acceder co nome de usuario ou co correo-e",
-    "Login with username" : "Acceder co nome de usuario",
+    "Error occurred while checking server setup" : "Aconteceu un erro mentras se comprobaba a configuración do servidor",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "Para obter máis detalles revise a {linkstart}documentación ↗{linkend}.",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Parolas, videochamadas, compartición de pantalla, xuntanzas en liña e conferencias web;  no seu navegador e con aplicacións móbiles.",
     "You have not added any info yet" : "Aínda non engadiu ningunha información",
     "{user} has not added any info yet" : "{user} aínda non engadiu ningunha información",
     "Error opening the user status modal, try hard refreshing the page" : "Produciuse un erro ao abrir a xanela modal de estado do usuario, tente forzar a actualización da páxina",
     "Edit Profile" : "Editar o perfil",
     "The headline and about sections will show up here" : "As seccións título e sobre aparecerán aquí",
-    "Error loading message template: {error}" : "Produciuse un erro ao cargar o modelo da mensaxe: {error}",
     "Very weak password" : "Contrasinal moi feble",
     "Weak password" : "Contrasinal feble",
     "So-so password" : "Contrasinal non moi aló",
@@ -387,6 +528,7 @@ OC.L10N.register(
     "Toggle password visibility" : "Alternar a visibilidade do contrasinal",
     "Configure the database" : "Configurar a base de datos",
     "Only %s is available." : "Só está dispoñíbel %s.",
-    "Database account" : "Conta da base de datos"
+    "Database account" : "Conta da base de datos",
+    "Direct link copied to clipboard" : "A ligazón directa foi copiada no portapapeis"
 },
 "nplurals=2; plural=(n != 1);");
