@@ -27,6 +27,7 @@ OC.L10N.register(
     "Could not complete login" : "Не могу да довршим пријављивање",
     "State token missing" : "Недостаје жетон стања",
     "Your login token is invalid or has expired" : "Ваш жетон за пријављивање је неисправан или је истекао",
+    "Please use original client" : "Молимо вас да користите оригинални клијент",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "Ово Nextcloud издање заједнице није подржано и брза обавештења су ограничена.",
     "Login" : "Пријава",
     "Unsupported email length (>255)" : "Није подржана дужина и-мејла (>255)",
@@ -43,6 +44,7 @@ OC.L10N.register(
     "Task not found" : "Задатак није пронађен",
     "Internal error" : "Интерна грешка",
     "Not found" : "Није нађено",
+    "Node is locked" : "Чвор је закључан.",
     "Bad request" : "Неисправан захтев",
     "Requested task type does not exist" : "Тражени тип задатка не постоји",
     "Necessary language model provider is not available" : "Није доступан неопходни пружалац услуге језичког модела",
@@ -51,6 +53,11 @@ OC.L10N.register(
     "No translation provider available" : "Није доступан ниједан пружалац услуге превода",
     "Could not detect language" : "Не може да се детектује језик",
     "Unable to translate" : "Не може да се преведе",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair step:" : "Корак поправке:",
+    "Repair info:" : "Инфо о поправци:",
+    "Repair warning:" : "Упозорење о поправци:",
+    "Repair error:" : "Грешка поправке:",
     "Nextcloud Server" : "Nextcloud сервер",
     "Some of your link shares have been removed" : "Неке везе дељења су уклоњене",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Услед безбедоносних мера, морали смо да уклонимо неке од ваших веза дељења. Кликните везу за више информација.",
@@ -58,11 +65,6 @@ OC.L10N.register(
     "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Унестите ваш кључ претплате у апликацију за подршку да бисте увећали границу броја налога. На овај начин добијате још погодности које нуди Nextcloud Enterprise и топло се препоручује за рад у компанијама.",
     "Learn more ↗" : "Сазнајте више ↗",
     "Preparing update" : "Припремам ажурирање",
-    "[%d / %d]: %s" : "[%d / %d]: %s",
-    "Repair step:" : "Корак поправке:",
-    "Repair info:" : "Инфо о поправци:",
-    "Repair warning:" : "Упозорење о поправци:",
-    "Repair error:" : "Грешка поправке:",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "Молимо вас да користите алат за ажурирање из командне линије јер је ажурирање из прегледача искључено у вашем config.php.",
     "Turned on maintenance mode" : "Режим одржавања укључен",
     "Turned off maintenance mode" : "Режим одржавања искључен",
@@ -79,8 +81,125 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (некомпатибилан)",
     "The following apps have been disabled: %s" : "Следеће апликације су искључене: %s",
     "Already up to date" : "Већ је ажурна",
-    "Error occurred while checking server setup" : "Дошло је до грешке при провери поставки сервера",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "За више детаља погледајте {linkstart}документацију ↗{linkend}.",
+    "Windows Command Script" : "Windows командна скрипта",
+    "Electronic book document" : "Документ електронске књиге",
+    "TrueType Font Collection" : "Колекција TrueType фонтова",
+    "Web Open Font Format" : "Web Open Font формат",
+    "GPX geographic data" : "GPX географски подаци",
+    "Gzip archive" : "Gzip архива",
+    "Adobe Illustrator document" : "Adobe Illustrator документ",
+    "Java source code" : "Java изворни кôд",
+    "JavaScript source code" : "JavaScript изворни кôд",
+    "JSON document" : "JSON документ",
+    "Microsoft Access database" : "Microsoft Access база података",
+    "Microsoft OneNote document" : "Microsoft OneNote документ",
+    "Microsoft Word document" : "Microsoft Word документ",
+    "Unknown" : "Непознато",
+    "PDF document" : "PDF документ",
+    "PostScript document" : "PostScript документ",
+    "RSS summary" : "RSS сажетак",
+    "Android package" : "Android пакет",
+    "KML geographic data" : "KML географски подаци",
+    "KML geographic compressed data" : "KML компресовани географски подаци",
+    "Lotus Word Pro document" : "Lotus Word Pro документ",
+    "Excel spreadsheet" : "Excel табела",
+    "Excel add-in" : "Excel додатак",
+    "Excel 2007 binary spreadsheet" : "Excel 2007 бинарна табела",
+    "Excel spreadsheet template" : "Excel шаблон табеле",
+    "Outlook Message" : "Outlook порука",
+    "PowerPoint presentation" : "PowerPoint презентација",
+    "PowerPoint add-in" : "PowerPoint додатак",
+    "PowerPoint presentation template" : "PowerPoint шаблон презентације",
+    "Word document" : "Word документ",
+    "ODF formula" : "ODF формула",
+    "ODG drawing" : "ODG цртеж",
+    "ODG drawing (Flat XML)" : "ODG цртеж (Равни XML)",
+    "ODG template" : "ODG шаблон",
+    "ODP presentation" : "ODP презентација",
+    "ODP presentation (Flat XML)" : "ODP презентација (РавниXML)",
+    "ODP template" : "ODP шаблон",
+    "ODS spreadsheet" : "ODS табела",
+    "ODS spreadsheet (Flat XML)" : "ODS табела (Равни XML)",
+    "ODS template" : "ODS шаблон",
+    "ODT document" : "ODT документ",
+    "ODT document (Flat XML)" : "ODT документ (Равни XML)",
+    "ODT template" : "ODT шаблон",
+    "PowerPoint 2007 presentation" : "PowerPoint 2007 презентација",
+    "PowerPoint 2007 show" : "PowerPoint 2007 шоу",
+    "PowerPoint 2007 presentation template" : "PowerPoint 2007 шаблон презентације",
+    "Excel 2007 spreadsheet" : "Excel 2007 табела",
+    "Excel 2007 spreadsheet template" : "Excel 2007 шаблон табеле",
+    "Word 2007 document" : "Word 2007 документ",
+    "Word 2007 document template" : "Word 2007 шаблон документа",
+    "Microsoft Visio document" : "Microsoft Visio документ",
+    "WordPerfect document" : "WordPerfect документ",
+    "7-zip archive" : "7-zip архива",
+    "Blender scene" : "Blender сцена",
+    "Bzip2 archive" : "Bzip2 архива",
+    "Debian package" : "Debian пакет",
+    "FictionBook document" : "FictionBook документ",
+    "Unknown font" : "Непознати фонт",
+    "Krita document" : "Krita документ",
+    "Mobipocket e-book" : "Mobipocket е-књига",
+    "Windows Installer package" : "Windows Installer пакет",
+    "Perl script" : "Perl скрипта",
+    "PHP script" : "PHP скрипта",
+    "Tar archive" : "Tar архива",
+    "XML document" : "XML документ",
+    "YAML document" : "YAML документ",
+    "Zip archive" : "Zip архива",
+    "Zstandard archive" : "Zstandard архива",
+    "AAC audio" : "AAC аудио",
+    "FLAC audio" : "FLAC аудио",
+    "MPEG-4 audio" : "MPEG-4 аудио",
+    "MP3 audio" : "MP3 аудио",
+    "Ogg audio" : "Ogg аудио",
+    "RIFF/WAVe standard Audio" : "RIFF/WAVe стандардни аудио",
+    "WebM audio" : "WebM аудио",
+    "MP3 ShoutCast playlist" : "MP3 ShoutCast плејлиста",
+    "Windows BMP image" : "Windows BMP слика",
+    "Better Portable Graphics image" : "Better Portable Graphics слика",
+    "EMF image" : "EMF слика",
+    "GIF image" : "GIF слика",
+    "HEIC image" : "HEIC слика",
+    "HEIF image" : "HEIF слика",
+    "JPEG-2000 JP2 image" : "JPEG-2000 JP2 слика",
+    "JPEG image" : "JPEG слика",
+    "PNG image" : "ПНГ слика",
+    "SVG image" : "SVG слика",
+    "Truevision Targa image" : "Truevision Targa слика",
+    "TIFF image" : "TIFF слика",
+    "WebP image" : "WebP слика",
+    "Digital raw image" : "Сирова дигитална слика",
+    "Windows Icon" : "Windows икона",
+    "Email message" : "И-мејл порука",
+    "VCS/ICS calendar" : "VCS/ICS календар",
+    "CSS stylesheet" : "CSS листа стилова",
+    "CSV document" : "CSV документ",
+    "HTML document" : "HTML документ",
+    "Markdown document" : "Markdown документ",
+    "Org-mode file" : "Фајл org-режима",
+    "Plain text document" : "Документ чистог текста",
+    "Rich Text document" : "Документ обогаћеног текста",
+    "Electronic business card" : "Електронска визит карта",
+    "C++ source code" : "C++ изворни кôд",
+    "LDIF address book" : "LDIF адресар",
+    "NFO document" : "NFO документ",
+    "PHP source" : "PHP извор",
+    "Python script" : "Python скрипта",
+    "ReStructuredText document" : "ReStructuredText документ",
+    "3GPP multimedia file" : "3GPP мултимедијални фајл",
+    "MPEG video" : "MPEG видео",
+    "DV video" : "DV видео",
+    "MPEG-2 transport stream" : "MPEG-2 транспортни ток",
+    "MPEG-4 video" : "MPEG-4 видео",
+    "Ogg video" : "Ogg видео",
+    "QuickTime video" : "QuickTime видео",
+    "WebM video" : "WebM видео",
+    "Flash video" : "Flash видео",
+    "Matroska video" : "Matroska видео",
+    "Windows Media video" : "Windows Media видео",
+    "AVI video" : "AVI видео",
     "unknown text" : "непознат текст",
     "Hello world!" : "Здраво свете!",
     "sunny" : "сунчано",
@@ -109,7 +228,7 @@ OC.L10N.register(
     "Federated user" : "Федерисани корисник",
     "user@your-nextcloud.org" : "korisnik@vas-nextcloud.org",
     "Create share" : "Kreirajte deljenje",
-    "Direct link copied to clipboard" : "Директни линк је копиран у клипборд",
+    "Direct link copied" : "Директни линк је копиран",
     "Please copy the link manually:" : "Молимо вас да ручно корпирате линк:",
     "Custom date range" : "Произвољни опсег датума",
     "Pick start date" : "Изаберите почетни датум",
@@ -133,6 +252,7 @@ OC.L10N.register(
     "Search people" : "Претрага људи",
     "People" : "Људи",
     "Filter in current view" : "Филтрирај у текућем погледу",
+    "Search connected services" : "Претражи повезане уређаје",
     "Results" : "Резултати",
     "Load more results" : "Учитај још резултата",
     "Search in" : "Претражи у",
@@ -207,6 +327,11 @@ OC.L10N.register(
     "Login form is disabled." : "Форма за пријаву је искључена.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud формулар за пријаву је искључен. Ако је доступна, користите неку другу могућност пријаве, или се обратите администрацији.",
     "More actions" : "Још акција",
+    "User menu" : "Кориснички мени",
+    "Your guest name: {user}" : "Ваше име госта: {user}",
+    "You are currently not identified." : "Тренутно нисте идентификовани.",
+    "Set public name" : "Постави јавно име",
+    "Change public name" : "Измени јавно име",
     "Password is too weak" : "Лозинка је сувише слаба",
     "Password is weak" : "Лозинка је слаба",
     "Password is average" : "Лозинка је просечна",
@@ -300,9 +425,10 @@ OC.L10N.register(
     "Admin" : "Администрација",
     "Help" : "Помоћ",
     "Access forbidden" : "Забрањен приступ",
+    "You are not allowed to access this page." : "Није вам дозвољено да приступите овој страници.",
+    "Back to %s" : "Назад на %s",
     "Page not found" : "Страна није нађена",
     "The page could not be found on the server or you may not be allowed to view it." : "Страница не може да се пронађе на серверу или можда немате права да је видите.",
-    "Back to %s" : "Назад на %s",
     "Too many requests" : "Превише захтева",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Са ваше мреже долази превише захтева. Покушајте поново касније или контактирајте администратора уколико је ово нека грешка.",
     "Error" : "Грешка",
@@ -378,16 +504,14 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Овај %s је тренутно у режиму одржавања што може потрајати.",
     "This page will refresh itself when the instance is available again." : "Ова страница ће се сама освежити када инстанца постане поново доступна.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Контактирајте администратора ако се порука понавља или се неочекивано појавила.",
-    "Currently open" : "Тренутно отворена",
-    "Login with username or email" : "Пријавa са корисничким именом или и-мејлом",
-    "Login with username" : "Пријава са корисничким именом",
+    "Error occurred while checking server setup" : "Дошло је до грешке при провери поставки сервера",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "За више детаља погледајте {linkstart}документацију ↗{linkend}.",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Ћаскање, видео позиви, дељење екрана, састанци на интернету & веб конференције – на десктоп рачунару и преко мобилних апликација.",
     "You have not added any info yet" : "Још увек нисте додали никакве информације",
     "{user} has not added any info yet" : "{user} још увек није унео никакве информације",
     "Error opening the user status modal, try hard refreshing the page" : "Грешка приликом отварања модалног прозора за статус корисника, покушајте да освежите страну уз брисање кеша",
     "Edit Profile" : "Уреди профил",
     "The headline and about sections will show up here" : "Овде ће се појавити насловна линија и одељак „о”",
-    "Error loading message template: {error}" : "Грешка при учитавању шаблона поруке: {error}",
     "Very weak password" : "Веома слаба лозинка",
     "Weak password" : "Слаба лозинка",
     "So-so password" : "Осредња лозинка",
@@ -404,6 +528,7 @@ OC.L10N.register(
     "Toggle password visibility" : "Укључи/искључи видљивост лозинке",
     "Configure the database" : "Подешавање базе",
     "Only %s is available." : "Само %s је доступна.",
-    "Database account" : "Налог базе података"
+    "Database account" : "Налог базе података",
+    "Direct link copied to clipboard" : "Директни линк је копиран у клипборд"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
