@@ -17,7 +17,7 @@ OC.L10N.register(
     "No image or file provided" : "没有提供图片或文件",
     "Unknown filetype" : "未知的文件类型",
     "An error occurred. Please contact your admin." : "发生了错误，请联系管理员。",
-    "Invalid image" : "无效的图像",
+    "Invalid image" : "无效的图片",
     "No temporary profile picture available, try again" : "没有临时个人页图片可用，请重试",
     "No crop data provided" : "没有提供剪裁数据",
     "No valid crop data provided" : "没有提供有效的裁剪数据",
@@ -27,6 +27,7 @@ OC.L10N.register(
     "Could not complete login" : "无法完成登录",
     "State token missing" : "状态令牌丢失",
     "Your login token is invalid or has expired" : "你的登录 token 无效或已过期",
+    "Please use original client" : "请使用原始客户端",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "这个 Nextcloud 的社区版本不受支持，推送通知功能受限。",
     "Login" : "登录",
     "Unsupported email length (>255)" : "不支持的电子邮箱长度（>255）",
@@ -43,14 +44,20 @@ OC.L10N.register(
     "Task not found" : "找不到任务",
     "Internal error" : "内部错误",
     "Not found" : "未找到",
+    "Node is locked" : "节点已锁定",
     "Bad request" : "请求错误",
     "Requested task type does not exist" : "请求的任务类型不存在",
     "Necessary language model provider is not available" : "无必要的语言模型提供程序",
-    "No text to image provider is available" : "没有可用的文字转图像提供者",
-    "Image not found" : "未找到图像",
+    "No text to image provider is available" : "没有可用的文字转图片提供者",
+    "Image not found" : "未找到图片",
     "No translation provider available" : "没有可用的翻译提供程序",
     "Could not detect language" : "无法检测语言",
     "Unable to translate" : "无法翻译",
+    "[%d / %d]: %s" : "[%d / %d]：%s",
+    "Repair step:" : "修复日志 步骤：",
+    "Repair info:" : "修复 信息：",
+    "Repair warning:" : "修复 警告：",
+    "Repair error:" : "修复 错误：",
     "Nextcloud Server" : "Nextcloud 服务器",
     "Some of your link shares have been removed" : "您的一些链接共享已被移除",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "由于一个安全缺陷，我们必须移除您的部分链接共享。更多信息请查看此链接。",
@@ -58,11 +65,6 @@ OC.L10N.register(
     "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "在支持应用中输入你的订阅秘钥以拓展账号数量限制。这也确保您可以体验到 Nextcloud Enterprise 额外优势，强烈建议在公司应用场景中启用订阅。",
     "Learn more ↗" : "了解更多 ↗",
     "Preparing update" : "正在准备更新",
-    "[%d / %d]: %s" : "[%d / %d]：%s",
-    "Repair step:" : "修复日志 步骤：",
-    "Repair info:" : "修复 信息：",
-    "Repair warning:" : "修复 警告：",
-    "Repair error:" : "修复 错误：",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "请使用命令行更新程序，因为通过浏览器更新在您的config.php中被禁用。",
     "Turned on maintenance mode" : "启用维护模式",
     "Turned off maintenance mode" : "关闭维护模式",
@@ -79,8 +81,125 @@ OC.L10N.register(
     "%s (incompatible)" : "%s （不兼容）",
     "The following apps have been disabled: %s" : "以下应用已被禁用：%s",
     "Already up to date" : "已经是最新版本",
-    "Error occurred while checking server setup" : "检查服务器设置时出错",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "了解更多详情，请参见{linkstart}文档 ↗{linkend}。",
+    "Windows Command Script" : "Windows 命令脚本",
+    "Electronic book document" : "电子书文档",
+    "TrueType Font Collection" : "TrueType 字体集",
+    "Web Open Font Format" : "Web 开放字体格式",
+    "GPX geographic data" : "GPX 地理数据",
+    "Gzip archive" : "Gzip 归档文件",
+    "Adobe Illustrator document" : "Adobe Illustrator 文档",
+    "Java source code" : "Java 源代码",
+    "JavaScript source code" : "JavaScript 源代码",
+    "JSON document" : "JSON 文档",
+    "Microsoft Access database" : "Microsoft Access 数据库",
+    "Microsoft OneNote document" : "Microsoft OneNote 文档",
+    "Microsoft Word document" : "Microsoft Word 文档",
+    "Unknown" : "未知",
+    "PDF document" : "PDF 文档",
+    "PostScript document" : "PostScript 文档",
+    "RSS summary" : "RSS 摘要",
+    "Android package" : "Android 软件包",
+    "KML geographic data" : "KML 地理数据",
+    "KML geographic compressed data" : "KML 地理压缩数据",
+    "Lotus Word Pro document" : "Lotus Word Pro document文档",
+    "Excel spreadsheet" : "Excel 电子表格",
+    "Excel add-in" : "Excel 插件",
+    "Excel 2007 binary spreadsheet" : "Excel 2007 二进制电子表格",
+    "Excel spreadsheet template" : "Excel 电子表格模板",
+    "Outlook Message" : "Outlook 邮件",
+    "PowerPoint presentation" : "PowerPoint 演示文稿",
+    "PowerPoint add-in" : "PowerPoint 插件",
+    "PowerPoint presentation template" : "PowerPoint 演示文稿模板",
+    "Word document" : "Word 文档",
+    "ODF formula" : "ODF 公式",
+    "ODG drawing" : "ODG 绘图",
+    "ODG drawing (Flat XML)" : "ODG 绘图（Flat XML）",
+    "ODG template" : "ODG 模板",
+    "ODP presentation" : "ODP 演示文稿",
+    "ODP presentation (Flat XML)" : "ODP 演示文稿（Flat XML）",
+    "ODP template" : "ODP 模板",
+    "ODS spreadsheet" : "ODS 电子表格",
+    "ODS spreadsheet (Flat XML)" : "ODS 电子表格（Flat XML）",
+    "ODS template" : "ODS 模板",
+    "ODT document" : "ODT 文档",
+    "ODT document (Flat XML)" : "ODT 文档（Flat XML）",
+    "ODT template" : "ODT 模板",
+    "PowerPoint 2007 presentation" : "PowerPoint 2007 演示文稿",
+    "PowerPoint 2007 show" : "PowerPoint 2007 放映",
+    "PowerPoint 2007 presentation template" : "PowerPoint 2007 演示文稿模板",
+    "Excel 2007 spreadsheet" : "Excel 2007 电子表格",
+    "Excel 2007 spreadsheet template" : "Excel 2007 电子表格模板",
+    "Word 2007 document" : "Word 2007 文档",
+    "Word 2007 document template" : "Word 2007 文档模板",
+    "Microsoft Visio document" : "Microsoft Visio 文档",
+    "WordPerfect document" : "WordPerfect 文档",
+    "7-zip archive" : "7-zip 归档文件",
+    "Blender scene" : "Blender 场景",
+    "Bzip2 archive" : "Bzip2 归档文件",
+    "Debian package" : "Debian 软件包",
+    "FictionBook document" : "FictionBook 文档",
+    "Unknown font" : "未知字体",
+    "Krita document" : "Krita 文档",
+    "Mobipocket e-book" : "Mobipocket 电子书",
+    "Windows Installer package" : "Windows Installer 安装包",
+    "Perl script" : "Perl 脚本",
+    "PHP script" : "PHP 脚本",
+    "Tar archive" : "Tar 归档文件",
+    "XML document" : "XML 文档",
+    "YAML document" : "YAML 文档",
+    "Zip archive" : "Zip 归档文件",
+    "Zstandard archive" : "Zstandard 归档文件",
+    "AAC audio" : "AAC 音频",
+    "FLAC audio" : "FLAC 音频",
+    "MPEG-4 audio" : "MPEG-4 音频",
+    "MP3 audio" : "MP3 音频",
+    "Ogg audio" : "Ogg 音频",
+    "RIFF/WAVe standard Audio" : "RIFF/WAVe 标准音频",
+    "WebM audio" : "WebM 音频",
+    "MP3 ShoutCast playlist" : "MP3 ShoutCast 播放列表",
+    "Windows BMP image" : "Windows BMP 图片",
+    "Better Portable Graphics image" : "Better Portable Graphics 图片",
+    "EMF image" : "EMF 图片",
+    "GIF image" : "GIF 图片",
+    "HEIC image" : "HEIC 图片",
+    "HEIF image" : "HEIF 图片",
+    "JPEG-2000 JP2 image" : "JPEG-2000 JP2 图片",
+    "JPEG image" : "JPEG 图片",
+    "PNG image" : "PNG 图片",
+    "SVG image" : "SVG 图片",
+    "Truevision Targa image" : "Truevision Targa 图片",
+    "TIFF image" : "TIFF 图片",
+    "WebP image" : "WebP 图片",
+    "Digital raw image" : "数字原始图像",
+    "Windows Icon" : "Windows 图标",
+    "Email message" : "电子邮件消息",
+    "VCS/ICS calendar" : "VCS/ICS 日历",
+    "CSS stylesheet" : "CSS 样式表",
+    "CSV document" : "CSV 文档",
+    "HTML document" : "HTML 文档",
+    "Markdown document" : "Markdown 文档",
+    "Org-mode file" : "Org-mode 文件",
+    "Plain text document" : "纯文本文档",
+    "Rich Text document" : "富文本文档",
+    "Electronic business card" : "电子名片",
+    "C++ source code" : "C++ 源代码",
+    "LDIF address book" : "LDIF 通讯录",
+    "NFO document" : "NFO 文档",
+    "PHP source" : "PHP 源代码",
+    "Python script" : "Python 脚本",
+    "ReStructuredText document" : "ReStructuredText 文档",
+    "3GPP multimedia file" : "3GPP 多媒体文件",
+    "MPEG video" : "MPEG 视频",
+    "DV video" : "DV 视频",
+    "MPEG-2 transport stream" : "MPEG-2 传输流",
+    "MPEG-4 video" : "MPEG-4 视频",
+    "Ogg video" : "Ogg 视频",
+    "QuickTime video" : "QuickTime 视频",
+    "WebM video" : "WebM 视频",
+    "Flash video" : "Flash 视频",
+    "Matroska video" : "Matroska 视频",
+    "Windows Media video" : "Windows 媒体视频",
+    "AVI video" : "AVI 视频",
     "unknown text" : "未知文字",
     "Hello world!" : "你好，世界！",
     "sunny" : "晴",
@@ -105,11 +224,11 @@ OC.L10N.register(
     "Yes" : "是",
     "The remote URL must include the user." : "远程 URL 必须包含用户。",
     "Invalid remote URL." : "无效远程 URL。",
-    "Failed to add the public link to your Nextcloud" : "添加公开链接到您的Nextcloud失败",
+    "Failed to add the public link to your Nextcloud" : "无法将公开链接添加到您的 Nextcloud",
     "Federated user" : "联合云用户",
     "user@your-nextcloud.org" : "user@your-nextcloud.org",
     "Create share" : "创建共享",
-    "Direct link copied to clipboard" : "直链已复制至粘贴板",
+    "Direct link copied" : "直接链接已复制",
     "Please copy the link manually:" : "请手动复制链接：",
     "Custom date range" : "自定义日期范围",
     "Pick start date" : "选择起始日期",
@@ -128,11 +247,12 @@ OC.L10N.register(
     "Last year" : "去年",
     "Unified search" : "统一搜索",
     "Search apps, files, tags, messages" : "搜索应用程序、文件、标签，信息",
-    "Places" : "地点",
+    "Places" : "位置",
     "Date" : "日期",
-    "Search people" : "搜索人物",
-    "People" : "人物",
+    "Search people" : "搜索用户",
+    "People" : "用户",
     "Filter in current view" : "在当前视图中筛选",
+    "Search connected services" : "搜索已连接的服务",
     "Results" : "结果",
     "Load more results" : "加载更多结果",
     "Search in" : "搜索",
@@ -146,8 +266,8 @@ OC.L10N.register(
     "Account name" : "账号名称",
     "Server side authentication failed!" : "服务端身份验证失败！",
     "Please contact your administrator." : "请联系您的管理员。",
-    "Temporary error" : "临时错误",
-    "Please try again." : "请重试。",
+    "Session error" : "会话错误",
+    "It appears your session token has expired, please refresh the page and try again." : "您的会话令牌似乎已过期，请刷新页面并重试。",
     "An internal error occurred." : "发生了内部错误。",
     "Please try again or contact your administrator." : "请重试或联系您的管理员。",
     "Password" : "密码",
@@ -207,6 +327,11 @@ OC.L10N.register(
     "Login form is disabled." : "登录表单已禁用",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud 登录表单已禁用。如果可以，请使用其他登录选项或联系你的管理人员。",
     "More actions" : "更多操作 ",
+    "User menu" : "用户菜单",
+    "Your guest name: {user}" : "您的访客名称：{user}",
+    "You are currently not identified." : "您当前未被标识。",
+    "Set public name" : "设置公开名称",
+    "Change public name" : "更改公开名称",
     "Password is too weak" : "密码太弱",
     "Password is weak" : "弱密码",
     "Password is average" : "一般密码",
@@ -276,9 +401,9 @@ OC.L10N.register(
     "Show details" : "显示详情",
     "Hide details" : "隐藏详细信息",
     "Rename project" : "重命名项目",
-    "Failed to rename the project" : "重命名项目失败",
-    "Failed to create a project" : "创建项目失败",
-    "Failed to add the item to the project" : "添加条目到项目中失败",
+    "Failed to rename the project" : "无法重命名项目",
+    "Failed to create a project" : "无法创建项目",
+    "Failed to add the item to the project" : "无法将条目添加到项目中",
     "Connect items to a project to make them easier to find" : "将条目关联到项目以使它们更容易查找",
     "Type to search for existing projects" : "输入以搜索已有项目",
     "New in" : "新品",
@@ -300,9 +425,10 @@ OC.L10N.register(
     "Admin" : "管理",
     "Help" : "帮助",
     "Access forbidden" : "访问禁止",
+    "You are not allowed to access this page." : "不允许您访问此页面。",
+    "Back to %s" : "返回 %s",
     "Page not found" : "未找到页面",
     "The page could not be found on the server or you may not be allowed to view it." : "该页面在服务器上无法找到，或者您可能不被允许浏览。",
-    "Back to %s" : "返回 %s",
     "Too many requests" : "请求过多",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "您的网络请求过多。如果出现错误，请稍后重试或与您的管理员联系。",
     "Error" : "错误",
@@ -378,16 +504,14 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "该实例 %s 当前处于维护模式，这将花费一些时间。",
     "This page will refresh itself when the instance is available again." : "当实例再次可用时，页面会自动刷新。",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "如果这个消息一直存在或不停出现，请联系您的系统管理员。",
-    "Currently open" : "当前打开",
-    "Login with username or email" : "使用用户名或电子邮箱进行登录",
-    "Login with username" : "使用用户名登录",
+    "Error occurred while checking server setup" : "检查服务器设置时出错",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "了解更多详情，请参见{linkstart}文档 ↗{linkend}。",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "在浏览器和移动设备应用中进行聊天，视频通话，屏幕共享，线上见面和网络会议。",
     "You have not added any info yet" : "您尚未添加任何信息",
     "{user} has not added any info yet" : "{user} 尚未添加任何信息",
     "Error opening the user status modal, try hard refreshing the page" : "打开用户状态模块时出错，请努力刷新页面",
     "Edit Profile" : "编辑个人资料",
     "The headline and about sections will show up here" : "标题和关于部分将显示在此处",
-    "Error loading message template: {error}" : "加载消息模板出错：{error}",
     "Very weak password" : "非常弱的密码",
     "Weak password" : "弱密码",
     "So-so password" : "一般强度的密码",
@@ -404,6 +528,7 @@ OC.L10N.register(
     "Toggle password visibility" : "切换密码可见性",
     "Configure the database" : "配置数据库",
     "Only %s is available." : "仅 %s 可用。",
-    "Database account" : "数据库账号"
+    "Database account" : "数据库账号",
+    "Direct link copied to clipboard" : "直链已复制至粘贴板"
 },
 "nplurals=1; plural=0;");
