@@ -93,6 +93,8 @@ OC.L10N.register(
     "Destination does not exist" : "Ziel existiert nicht",
     "Destination is not creatable" : "Ziel kann nicht erstellt werden",
     "Dot files are not allowed" : "Dateinamen mit einem Punkt am Anfang sind nicht erlaubt",
+    "%1$s (renamed)" : "%1$s (umbenannt)",
+    "renamed file" : "Umbenannte Datei",
     "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" ist ein unzulässiger Datei- oder Ordnername.",
     "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\" ist ein unzulässiges Präfix für Datei- oder Ordnernamen.",
     "\"%1$s\" is not allowed inside a file or folder name." : "\"%1$s\" ist in einem Datei- oder Ordnernamen unzulässig.",
@@ -101,7 +103,7 @@ OC.L10N.register(
     "Invalid parent path" : "Ungültiger übergeordneter Pfad",
     "File already exists" : "Datei bereits vorhanden",
     "Invalid path" : "Ungültiger Pfad",
-    "Failed to create file from template" : "Fehler beim Erstellen der Datei aus Vorlage",
+    "Failed to create file from template" : "Datei konnte nicht aus Vorlage erstellt werden",
     "Templates" : "Vorlagen",
     "Storage %s cannot be moved" : "Speicherplatz %s kann nicht verschoben werden",
     "Moving a share (%s) into a shared folder is not allowed" : "Verschieben einer Freigabe (%s) in einen freigegebenen Ordner ist unzulässig",
@@ -120,13 +122,15 @@ OC.L10N.register(
     "__language_name__" : "Deutsch (Persönlich: Du)",
     "This is an automatically sent email, please do not reply." : "Dies ist eine automatisch gesendete E-Mail. Bitte antworte nicht auf diese E-Mail.",
     "Help & privacy" : "Hilfe & Datenschutz",
-    "Appearance and accessibility" : "Erscheinungsbild und Barrierefreiheit",
+    "Appearance and accessibility" : "Aussehen und Barrierefreiheit",
     "Apps" : "Apps",
     "Personal settings" : "Persönliche Einstellungen",
-    "Administration settings" : "Verwaltungseinstellungen",
+    "Administration settings" : "Administrationseinstellungen",
     "Settings" : "Einstellungen",
     "Log out" : "Abmelden",
     "Accounts" : "Konten",
+    "Bluesky" : "Bluesky",
+    "View %s on Bluesky" : "%s auf Bluesky anzeigen",
     "Email" : "E-Mail",
     "Mail %s" : "E-Mail %s",
     "Fediverse" : "Fediverse",
@@ -142,7 +146,7 @@ OC.L10N.register(
     "About" : "Über",
     "Display name" : "Anzeigename",
     "Headline" : "Überschrift",
-    "Organisation" : "Organisation",
+    "Organization" : "Organisation",
     "Role" : "Funktion",
     "Pronouns" : "Pronomen",
     "Unknown account" : "Unbekanntes Konto",
@@ -273,6 +277,7 @@ OC.L10N.register(
     "A valid Login must be provided" : "Ein gültiger Anmeldename muss eingegeben werden.",
     "Login contains whitespace at the beginning or at the end" : "Anmeldename enthält Leerzeichen am Anfang oder am Ende",
     "Login must not consist of dots only" : "Der Anmeldename darf nicht nur aus Punkten bestehen",
+    "Username is too long" : "Benutzername ist zu lang",
     "Login is invalid because files already exist for this user" : "Der Anmeldename ist ungültig, da bereits Dateien von diesem Konto existieren",
     "Account disabled" : "Konto deaktiviert",
     "Login canceled by app" : "Anmeldung durch die App abgebrochen",
@@ -285,8 +290,6 @@ OC.L10N.register(
     "Cannot write into \"config\" directory." : "Schreiben in das \"config\"-Verzeichnis ist nicht möglich.",
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Dies kann zumeist behoben werden, indem dem Webserver Schreibzugriff auf das Konfigurationsverzeichnis eingeräumt wird. Siehe auch %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Oder wenn du lieber möchtest, dass die Datei config.php schreibgeschützt bleiben soll, dann setze die Option \"config_is_read_only\" in der Datei auf true. Siehe %s",
-    "Cannot write into \"apps\" directory." : "Schreiben in das \"apps\"-Verzeichnis ist nicht möglich.",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Dies kann normalerweise behoben werden, indem dem Webserver Schreibzugriff auf das App-Verzeichnis gegeben wird, oder der App-Store in der Konfigurationsdatei deaktiviert wird.",
     "Cannot create \"data\" directory." : "Kann das \"data\"-Verzeichnis nicht erstellen.",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Dies kann zumeist behoben werden, indem dem Webserver Schreibzugriff auf das Wurzel-Verzeichnis eingeräumt wird. Siehe auch %s",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Berechtigungen können zumeist korrigiert werden, indem dem Webserver Schreibzugriff auf das Wurzel-Verzeichnis eingeräumt wird. Siehe auch %s. ",
@@ -297,8 +300,6 @@ OC.L10N.register(
     "Please ask your server administrator to install the module." : "Bitte für die Installation des Moduls die Serveradministration kontaktieren.",
     "PHP setting \"%s\" is not set to \"%s\"." : "PHP-Einstellung \"%s\" ist nicht auf \"%s\" gesetzt.",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Eine Änderung dieser Einstellung in der php.ini kann diese Nextcloud wieder lauffähig machen.",
-    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> ist auf <code>%s</code> gesetzt und nicht auf den erwarteten Wert <code>0</code>.",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Zum Beheben dieses Problems bitte <code>mbstring.func_overload</code> in der php.ini auf <code>0</code> setzen.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP ist offenbar so konfiguriert, dass PHPDoc-Blöcke in der Anweisung entfernt werden. Dadurch sind mehrere Kern-Apps nicht erreichbar.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dies wird wahrscheinlich durch Zwischenspeicher/Beschleuniger wie etwa Zend OPcache oder eAccelerator verursacht.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP-Module wurden installiert, werden aber als noch fehlend gelistet?",
@@ -323,25 +324,48 @@ OC.L10N.register(
     "Storage is temporarily not available" : "Speicher ist vorübergehend nicht verfügbar",
     "Storage connection timeout. %s" : "Zeitüberschreitung der Verbindung zum Speicherplatz. %s",
     "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Damit diese Prüfung ausgeführt werden kann, muß sichergestellt sein, dass der Webserver eine Verbindung zu sich selbst herstellen kann. Daher muss er in der Lage sein, mindestens eine seiner `trusted_domains` oder `overwrite.cli.url` aufzulösen und eine Verbindung zu ihnen herzustellen. Dieser Fehler kann das Ergebnis einer serverseitigen DNS-Nichtübereinstimmung oder einer ausgehenden Firewall-Regel sein.",
+    "Analyze images" : "Bilder analysieren",
+    "Ask a question about the given images." : "Eine Frage zu den gewählten Bildern stellen.",
+    "Images" : "Bilder",
+    "Images to ask a question about" : "Bilder, zu denen eine Frage gestellt werden soll",
+    "Question" : "Frage",
+    "What to ask about the images." : "Was alles zu den Bildern gefragt werden kann.",
+    "Generated response" : "Erzeugte Antwort",
+    "The answer to the question" : "Die Antwort auf die Frage",
+    "Audio chat" : "Audio-Chat",
+    "Voice chat with the assistant" : "Sprachchat mit dem Assistenten",
+    "System prompt" : "Systemaufforderung",
+    "Define rules and assumptions that the assistant should follow during the conversation." : "Regeln und Annahmen definieren, die der Assistent während des Gesprächs befolgen soll.",
+    "Chat voice message" : "Chat-Sprachnachricht",
+    "Describe a task that you want the assistant to do or ask a question." : "Eine Aufgabe, die der Assistent erledigen soll, beschreiben, oder eine Frage stellen.",
+    "Chat history" : "Chatverlauf",
+    "The history of chat messages before the current message, starting with a message by the user." : "Chatverlauf vor der aktuellen Nachricht, beginnend mit einer Nachricht des Benutzers.",
+    "Input transcript" : "Eingabetranskript",
+    "Transcription of the audio input" : "Transkription der Audio-Eingabe",
+    "Response voice message" : "Antwort-Sprachnachricht",
+    "The generated voice response as part of the conversation" : "Die erstellte Sprachantwort als Teil des Gesprächs",
+    "Output transcript" : "Ausgabetranskript",
+    "Transcription of the audio output" : "Transkription der Audio-Ausgabe",
     "Transcribe audio" : "Audio transkribieren",
     "Transcribe the things said in an audio" : "Inhalt der Audiodatei transkribieren",
     "Audio input" : "Audioeingang",
     "The audio to transcribe" : "Die Audio-Datei zum Transkribieren",
     "Transcription" : "Transkription",
     "The transcribed text" : "Der transkribierte Text",
-    "Chat with an agent" : "Mit einem Agenten chatten",
-    "Chat message" : "Chatnachricht",
-    "A chat message to send to the agent." : "Eine Chatnachricht, die an den Agenten gesendet wird.",
+    "Chat by voice with an agent" : "Per Stimme mit einem Agenten chatten",
+    "Describe a task that you want the agent to do or ask a question." : "Eine Aufgabe, die der Assistent erledigen soll, beschreiben, oder eine Frage stellen.",
     "Confirmation" : "Bestätigung",
     "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "Ob zuvor angeforderte Aktionen bestätigt werden sollen: 0 für Verweigerung und 1 für Bestätigung.",
     "Conversation token" : "Unterhaltungstoken",
     "A token representing the conversation." : "Ein Token, das die Unterhaltung repräsentiert.",
-    "Generated response" : "Erzeugte Antwort",
-    "The response from the chat model." : "Die Antwort des Chat-Modells.",
     "The new conversation token" : "Das neue Unterhaltungstoken",
     "Send this along with the next interaction." : "Dies zusammen mit der nächsten Interaktion senden.",
     "Requested actions by the agent" : "Vom Agenten angeforderte Aktionen",
     "Actions that the agent would like to carry out in JSON format." : "Aktionen, die der Agent durchführen möchte, im JSON-Format.",
+    "Chat with an agent" : "Mit einem Agenten chatten",
+    "Chat message" : "Chatnachricht",
+    "A chat message to send to the agent." : "Eine Chatnachricht, die an den Agenten gesendet wird.",
+    "The response from the chat model." : "Die Antwort des Chat-Modells.",
     "Context write" : "Kontext schreiben",
     "Writes text in a given style based on the provided source material." : "Schreibt Text in einem vorgegebenen Stil auf Basis des bereitgestellten Quellmaterials.",
     "Writing style" : "Schreibstil",
@@ -363,6 +387,11 @@ OC.L10N.register(
     "How many images to generate" : "Wie viele Bilder erstellt werden sollen",
     "Output images" : "Ausgegebene Bilder",
     "The generated images" : "Die erstellten Bilder",
+    "Generate speech" : "Sprache erstellen",
+    "Generate speech from a transcript" : "Sprache aus einem Transkript erstellen",
+    "Write transcript that you want the assistant to generate speech from" : "Schreibe ein Transkript, aus dem der Assistent Sprache erstellen soll",
+    "Output speech" : "Sprachausgabe",
+    "The generated speech" : "Die erstellte Sprache",
     "Free text to text prompt" : "Freie Text-zu-Text-Eingabeaufforderung",
     "Runs an arbitrary prompt through a language model that returns a reply" : "Führt eine beliebige Eingabeaufforderung mit einem Sprachmodell aus, das eine Antwort zurückgibt",
     "Describe a task that you want the assistant to do or ask a question" : "Eine Aufgabe beschreiben, die der Assistent erledigen soll, oder eine Frage stellen",
@@ -376,9 +405,6 @@ OC.L10N.register(
     "The rewritten text in the desired tone, written by the assistant:" : "Der umgeschriebene Text im gewünschten Ton, erstellt vom Assistenten:",
     "Chat" : "Chat",
     "Chat with the assistant" : "Mit dem Assistenten chatten",
-    "System prompt" : "Systemaufforderung",
-    "Define rules and assumptions that the assistant should follow during the conversation." : "Regeln und Annahmen definieren, die der Assistent während des Gesprächs befolgen soll.",
-    "Chat history" : "Chatverlauf",
     "The history of chat messages before the current message, starting with a message by the user" : "Chatverlauf vor der aktuellen Nachricht, beginnend mit einer Nachricht des Benutzers",
     "Response message" : "Antwortnachricht",
     "The generated response as part of the conversation" : "Die erstellte Antwort als Teil der Unterhaltung",
@@ -442,20 +468,13 @@ OC.L10N.register(
     "Generate headline" : "Überschrift erzeugen",
     "Summarizes text by reducing its length without losing key information." : "Fasst Text zusammen, indem die Länge reduziert wird, ohne dass wichtige Informationen verloren gehen.",
     "Extracts topics from a text and outputs them separated by commas." : "Extrahiert Themen aus einem Text und gibt sie durch Kommas getrennt aus.",
-    "Education Edition" : "Bildungsausgabe",
-    "File name is a reserved word" : "Der Dateiname ist ein reserviertes Wort",
-    "File name contains at least one invalid character" : "Der Dateiname enthält mindestens ein ungültiges Zeichen",
-    "File name is too long" : "Dateiname ist zu lang",
-    "Users" : "Benutzer",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s hat »%2$s« mit dir geteilt und möchte folgendes hinzufügen:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$shat »%2$s« mit dir geteilt und möchte folgendes hinzufügen",
-    "»%s« added a note to a file shared with you" : "»%s« hat eine Bemerkung zu einer mit dir geteilten Datei hinzugefügt",
-    "Open »%s«" : "»%s« öffnen",
-    "%1$s shared »%2$s« with you" : "%1$s hat »%2$s« mit dir geteilt",
-    "%1$s shared »%2$s« with you." : "%1$s hat »%2$s« mit dir geteilt.",
-    "Click the button below to open it." : "Klicke zum Öffnen auf die untere Schaltfläche.",
+    "Organisation" : "Organisation",
     "File is currently busy, please try again later" : "Die Datei ist in Benutzung, bitte versuche es später noch einmal",
     "Cannot download file" : "Datei kann nicht heruntergeladen werden.",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Stelle sicher, dass eine Datei \".ocdata\" im Wurzelverzeichnis des data-Verzeichnisses existiert."
+    "Cannot write into \"apps\" directory." : "Schreiben in das \"apps\"-Verzeichnis ist nicht möglich.",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Dies kann normalerweise behoben werden, indem dem Webserver Schreibzugriff auf das App-Verzeichnis gegeben wird, oder der App-Store in der Konfigurationsdatei deaktiviert wird.",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> ist auf <code>%s</code> gesetzt und nicht auf den erwarteten Wert <code>0</code>.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Zum Beheben dieses Problems bitte <code>mbstring.func_overload</code> in der php.ini auf <code>0</code> setzen.",
+    "Login is too long" : "Die Anmeldung dauert zu lange"
 },
 "nplurals=2; plural=(n != 1);");
