@@ -1,7 +1,7 @@
 OC.L10N.register(
     "lib",
     {
-    "Cannot write into \"config\" directory!" : "Ezin da idatzi \"config\" karpetan!",
+    "Cannot write into \"config\" directory!" : "Ezin da idatzi \"config\" direktorioan!",
     "This can usually be fixed by giving the web server write access to the config directory." : "Hau normalean konpon daiteke web zerbitzariari konfigurazio direktoriorako idazteko sarbidea emanez.",
     "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Bestela, config.php fitxategia irakurtzeko soilik mantendu nahi baduzu, ezarri bertan \"config_is_read_only\" aukerari 'egia' balioa.",
     "See %s" : "Ikusi %s",
@@ -38,6 +38,7 @@ OC.L10N.register(
     "Server version %s or higher is required." : "Zerbitzariaren %s bertsioa edo berriagoa behar da.",
     "Server version %s or lower is required." : "Zerbitzariaren %s bertsioa edo zaharragoa behar da.",
     "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Saioa hasitako kontua administratzailea, azpi-administratzailea edo baimen berezi bat duena izan behar da ezarpen hau aldatzeko.",
+    "Your current IP address doesn't allow you to perform admin actions" : "Zure oraingo IP helbideak ez dizu administrazio ekintzarik egiteko aukerarik ematen",
     "Logged in account must be an admin or sub admin" : "Saioa hasitako kontua administratzaile edo azpi-administratzailea izan behar du",
     "Logged in account must be an admin" : "Saioa hasitako kontua administratzailea izan behar du",
     "Wiping of device %s has started" : "%s gailuaren garbiketa hasi da",
@@ -58,7 +59,11 @@ OC.L10N.register(
     "Avatar image is not square" : "Abatarreko irudia ez da karratua",
     "Files" : "Fitxategiak",
     "View profile" : "Ikusi profila",
+    "same time" : "aldi berean",
     "_%nh_::_%nh_" : ["%nh","%nh"],
+    "_%nm_::_%nm_" : ["%nm","%nm"],
+    "%s ahead" : "%s aurrera",
+    "%s behind" : "%s atzean",
     "Local time: %s" : "Ordu lokala: %s",
     "today" : "gaur",
     "tomorrow" : "bihar",
@@ -81,7 +86,15 @@ OC.L10N.register(
     "seconds ago" : "duela segundo batzuk",
     "Empty file" : "Fitxategi hutsa",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "%s IDa duen modulua ez da existitzen. Gaitu zure aplikazioen ezarpenetan edo jarri harremanetan administratzailearekin.",
+    "No file conversion providers available" : "Ez dago bihurtze-hornitzailerik erabilgarri",
+    "File is too large to convert" : "Fitxategia handiegia da bihurtzeko",
+    "Destination does not match conversion extension" : "Helmuga ez dator bihurketa luzapenarekin",
+    "Could not convert file" : "Ezin da fitxategia bihurtu",
+    "Destination does not exist" : "Helmuga ez dago",
+    "Destination is not creatable" : "Helmuga ezin da sortu",
     "Dot files are not allowed" : "Dot fitxategiak ez dira onartzen",
+    "%1$s (renamed)" : "%1$s (berrizendatua)",
+    "renamed file" : "fitxategia berrizendatu da",
     "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" debekatutako fitxategi edo karpeta-izen bat da.",
     "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\" debekatutako aurrizkia da fitxategi edo karpeten izenetarako.",
     "\"%1$s\" is not allowed inside a file or folder name." : "\"%1$s\" ez da onartzen fitxategi edo karpeta-izen baten barruan.",
@@ -116,6 +129,8 @@ OC.L10N.register(
     "Settings" : "Ezarpenak",
     "Log out" : "Amaitu saioa",
     "Accounts" : "Kontuak",
+    "Bluesky" : "Bluesky",
+    "View %s on Bluesky" : "Ikusi %s Blueskyn",
     "Email" : "Posta elektronikoa",
     "Mail %s" : "Idatzi %s(r)i",
     "Fediverse" : "Fedibertsoa",
@@ -131,7 +146,7 @@ OC.L10N.register(
     "About" : "Honi buruz",
     "Display name" : "Erakusteko izena",
     "Headline" : "Izenburua",
-    "Organisation" : "Erakundea",
+    "Organization" : "Antolakuntza",
     "Role" : "Zeregina",
     "Pronouns" : "Izenordainak",
     "Unknown account" : "Kontu ezezaguna",
@@ -145,6 +160,7 @@ OC.L10N.register(
     "Oracle connection could not be established" : "Ezin da Oracle konexioa sortu",
     "Oracle Login and/or password not valid" : "Oracle saio edota pasahitza baliogabea",
     "PostgreSQL Login and/or password not valid" : "PostgreSQL saio edota pasahitza baliogabea",
+    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X ez da onartzen eta %s ez da ondo funtzionatuko plataforma honetan. Erabili zure ardurapean!",
     "For the best results, please consider using a GNU/Linux server instead." : "Emaitza hobeak izateko, mesedez kontsideratu GNU/Linux zerbitzari bat erabiltzea.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Badirudi %s instantzia hau 32 biteko PHP ingurune bat exekutatzen ari dela eta open_basedir aldagaia php.ini fitxategian konfiguratu dela. Honek arazoak sortuko ditu 4 GB baino gehiagoko fitxategiekin eta ez da batere gomendagarria.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Mesedez kendu open_basedir ezarpena zure php.ini-tik edo aldatu 64-biteko PHPra.",
@@ -174,6 +190,7 @@ OC.L10N.register(
     "You cannot share your root folder" : "Ezin duzu zure erro-karpeta partekatu",
     "You are not allowed to share %s" : "Ez duzu %s partekatzeko baimenik",
     "Valid permissions are required for sharing" : "Baliozko baimenak behar dira partekatzeko",
+    "File shares cannot have create or delete permissions" : "Fitxategien partekatzeek ezin dute baimenik sortu edo ezabatu",
     "Cannot increase permissions of %s" : "Ezin dira %s(r)en baimenak handitu",
     "Shares need at least read permissions" : "Partekatzeak gutxienez irakurtzeko baimenak izan behar ditu",
     "Files cannot be shared with delete permissions" : "Fitxategiak ezin dira ezabatze baimenarekin partekatu",
@@ -188,6 +205,7 @@ OC.L10N.register(
     "Path is already shared with this group" : "Bide-izen hau dagoeneko partekatuta dago talde honekin",
     "Link sharing is not allowed" : "Esteken partekatzea ez da onartzen",
     "Public upload is not allowed" : "Igotze publikoa ez da onartzen",
+    "You cannot share a folder that contains other shares" : "Ezin duzu partekatu barnean beste partekatzeak dituen karpeta bat.",
     "Sharing is disabled" : "Partekatzea desgaituta dago",
     "Sharing is disabled for you" : "Partekatzea zuretzat desgaituta dago",
     "Cannot share with the share owner" : "Ezin da partekatzearen jabearekin partekatu",
@@ -259,6 +277,7 @@ OC.L10N.register(
     "A valid Login must be provided" : "Baliozko saioa eman behar da",
     "Login contains whitespace at the beginning or at the end" : "Saioak zuriuneren bat du hasieran edo amaieran",
     "Login must not consist of dots only" : "Saioa ezin da puntuz osatuta soilik egon",
+    "Username is too long" : "Erabiltzaile-izena luzeegia da",
     "Login is invalid because files already exist for this user" : "Saioa ez da baliozkoa erabiltzaile honentzako fitxategiak dagoeneko existitzen direlako",
     "Account disabled" : "Kontua desgaituta",
     "Login canceled by app" : "Aplikazioak saioa bertan behera utzi du",
@@ -271,8 +290,6 @@ OC.L10N.register(
     "Cannot write into \"config\" directory." : "Ezin da \"config\" karpetan idatzi.",
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Hau normalean konpondu daiteke web zerbitzariari konfigurazio direktoriorako sarbidea emanez. Ikus %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Bestela, config.php fitxategia irakurtzeko soilik mantendu nahi baduzu, ezarri bertan \"config_is_read_only\" aukerari 'egia' balioa. Ikusi %s",
-    "Cannot write into \"apps\" directory." : "Ezin da idatzi \"apps\" fitxategian.",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Hau normalean konpondu daiteke web zerbitzariari aplikazioen direktorioko sarbidea emanez edo konfigurazioko fitxategian aplikazioen biltegia (App Store) desgaituz.",
     "Cannot create \"data\" directory." : "Ezin da \"data\" direktorioa sortu.",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Hau normalean konpondu daiteke web zerbitzariari root direktorioko idazketa sarbidea emanez. Ikus %s",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Normalean baimenak konpondu daitezke web zerbitzariari root direktorioko sarbidea emanez. Ikus%s.",
@@ -283,8 +300,6 @@ OC.L10N.register(
     "Please ask your server administrator to install the module." : "Mesedez eskatu zure zerbitzariaren administratzaileari modulua instalatzeko.",
     "PHP setting \"%s\" is not set to \"%s\"." : "\"%s\" PHP ezarpena ez dago \"%s\" gisa jarrita.",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Ezarpen hau php.ini fitxategian doitzen bada, Nextcloud berriro exekutatuko da",
-    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code><code>%s</code>-en ezarrita dago, espero zen <code>0</code> balioaren ordez.",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Arazo hau konpontzeko, ezarri<code>mbstring.func_overload</code> <code>0</code>-en zure php.ini fitxategian.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP lerro bakarreko blokeak mozteko konfiguratua dagoela dirudi. Oinarrizko app batzuk eskuraezin bihurtuko dira.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Hau ziur aski cache/accelerator batek eragin du, hala nola Zend OPcache edo eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP moduluak instalatu dira, baina oraindik falta direla jartzen du?",
@@ -309,26 +324,48 @@ OC.L10N.register(
     "Storage is temporarily not available" : "Biltegia ez dago erabilgarri aldi baterako",
     "Storage connection timeout. %s" : "Biltegiratze-konexioa denboraz kanpo geratu da. %s",
     "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Egiaztapen hau exekuta dadin ziurtatu behar duzu zure web zerbitzaria bere buruarekin konektatu daitekeela. Hori dela eta, bere `trusted_domains` edo `overwrite.cli.url`ra gutxienez ebatzi eta konektatzeko gai izan behar du. Baliteke hutsegite hau zerbitzariaren aldeko DNS ez bat etortzea edo irteerako suebakiaren arauaren ondorioa izatea.",
+    "Analyze images" : "Aztertu irudiak",
+    "Ask a question about the given images." : "Egun galdera bat emandako irudiei buruz.",
+    "Images" : "Irudiak",
+    "Images to ask a question about" : " Irudiak galdera bat egiteko",
+    "Question" : "Galdera",
+    "What to ask about the images." : "Zer galdetu irudiei buruz.",
+    "Generated response" : "Sortutako erantzuna",
+    "The answer to the question" : "Galderaren erantzuna",
+    "Audio chat" : "Audio-txata",
+    "Voice chat with the assistant" : "Ahots-txata laguntzailearekin",
+    "System prompt" : "Sistemaren gonbita",
+    "Define rules and assumptions that the assistant should follow during the conversation." : "Definitu elkarrizketan zehar txat laguntzaileak jarraitu beharko lituzkeen arau eta suposizioak.",
+    "Chat voice message" : "Ahots-txataren mezua",
+    "Describe a task that you want the assistant to do or ask a question." : "Deskribatu laguntzaileak egitea nahi duzun zeregina edo galdera bat egin.",
+    "Chat history" : "Txat historia",
+    "The history of chat messages before the current message, starting with a message by the user." : "Txat-mezuen historia uneko mezuaren aurretik, erabiltzailearen mezu batetik hasita.",
+    "Input transcript" : "Sarrerako transkripzioa",
+    "Transcription of the audio input" : "Audio-sarreraren transkripzioa",
+    "Response voice message" : "Erantzun ahots-mezuari",
+    "The generated voice response as part of the conversation" : "Sortutako ahots-erantzuna elkarrizketaren parte da",
+    "Output transcript" : "Irteerako transkripzioa",
+    "Transcription of the audio output" : "Audio-irteeraren transkripzioa",
     "Transcribe audio" : "Audioa transkribatu",
     "Transcribe the things said in an audio" : "Audio batean esandako gauzak transkribatu",
     "Audio input" : "Audio sarrera",
     "The audio to transcribe" : "Transkribatzeko audioa",
     "Transcription" : "Transkripzioa",
     "The transcribed text" : "Transkribatutako testua",
-    "ContextAgent" : "ContextAgent",
-    "Chat with an agent" : "Txateatu agente batekin",
-    "Chat message" : "Txat mezua",
-    "A chat message to send to the agent." : "Agenteari bidaltzeko txat mezu bat.",
+    "Chat by voice with an agent" : "Ahots txata agente batekin",
+    "Describe a task that you want the agent to do or ask a question." : "Deskribatu agenteak egitea nahi duzun zeregina edo galdera bat egin.",
     "Confirmation" : "Berrespena",
     "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "Aurretik eskatutako ekintzak berretsi behar diren ala ez: 0 ukatzeko eta 1 berresteko.",
     "Conversation token" : "Elkarrizketa tokena",
     "A token representing the conversation." : "Elkarrizketa adierazten duen token bat.",
-    "Generated response" : "Sortutako erantzuna",
-    "The response from the chat model." : "Txat modeloaren erantzuna.",
     "The new conversation token" : "Elkarrizketa token berria",
     "Send this along with the next interaction." : "Bidali hau hurrengo interakzioarekin.",
     "Requested actions by the agent" : "Agenteak eskatutako ekintzak",
     "Actions that the agent would like to carry out in JSON format." : "Agenteak egin nahi dituen ekintzak JSON formatuan.",
+    "Chat with an agent" : "Txateatu agente batekin",
+    "Chat message" : "Txat mezua",
+    "A chat message to send to the agent." : "Agenteari bidaltzeko txat mezu bat.",
+    "The response from the chat model." : "Txat modeloaren erantzuna.",
     "Context write" : "Testuingurua idaztea",
     "Writes text in a given style based on the provided source material." : "Testua estilo jakin batean idazten du, emandako iturri-materialean oinarrituta.",
     "Writing style" : "Idazteko estiloa",
@@ -350,6 +387,11 @@ OC.L10N.register(
     "How many images to generate" : "Zenbat irudi sortu behar diren",
     "Output images" : "Irteera irudiak",
     "The generated images" : "Sortutako irudiak",
+    "Generate speech" : "Sortu diskurtsoa",
+    "Generate speech from a transcript" : "Sortu diskurtsoa transkripzio batean oinarrituta",
+    "Write transcript that you want the assistant to generate speech from" : "Idatzi laguntzaileak diskurtsoa sortzea nahi duzun transkripzioa",
+    "Output speech" : "Irteerako diskurtsoa",
+    "The generated speech" : "Sortutako diskurtsoa",
     "Free text to text prompt" : "Testu librea mezuaren testura",
     "Runs an arbitrary prompt through a language model that returns a reply" : "Abisu arbitrario bat exekutatzen du erantzuna itzultzen duen hizkuntza-eredu baten bidez",
     "Describe a task that you want the assistant to do or ask a question" : "Deskribatu laguntzaileak egitea nahi duzun zeregina edo galdera bat egin",
@@ -363,9 +405,6 @@ OC.L10N.register(
     "The rewritten text in the desired tone, written by the assistant:" : "Berridatzitako testua nahi den tonuan, laguntzaileak idatzita:",
     "Chat" : "Chat",
     "Chat with the assistant" : "Hitz egin txat bidez laguntzailarekin",
-    "System prompt" : "Sistemaren gonbita",
-    "Define rules and assumptions that the assistant should follow during the conversation." : "Definitu elkarrizketan zehar txat laguntzaileak jarraitu beharko lituzkeen arau eta suposizioak.",
-    "Chat history" : "Txat historia",
     "The history of chat messages before the current message, starting with a message by the user" : "Uneko mezuaren aurreko txat mezuen historia, erabiltzailearen mezu batetik hasita",
     "Response message" : "Erantzun mezua",
     "The generated response as part of the conversation" : "Sorturiko erantzuna, elkarrizketaren zati gisa",
@@ -429,21 +468,13 @@ OC.L10N.register(
     "Generate headline" : "Sortu izenburua",
     "Summarizes text by reducing its length without losing key information." : "Testua laburtzen du bere luzera murrizten informazio baliotsua galdu gabe.",
     "Extracts topics from a text and outputs them separated by commas." : "Gaiak ateratzen ditu testu batetik eta komaz banatuta erakusten ditu.",
-    "Education Edition" : "Hezkuntza edizioa",
-    "File name is a reserved word" : "Fitxategi izena hitz erreserbatua da",
-    "File name contains at least one invalid character" : "Fitxategi izenak karaktere baliogabe bat du gutxienez ",
-    "File name is too long" : "Fitxategi-izena luzeegia da",
-    "Users" : "Erabiltzaileak",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$serabiltzaileak »%2$s« partekatu du zurekin eta hau gehitu nahi du:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$serabiltzaileak »%2$s« partekatu du zurekin eta hau gehitu nahi du",
-    "»%s« added a note to a file shared with you" : "»%s« erabiltzaileak ohar bat gehitu du partekatu dizun fitxategi batean",
-    "Open »%s«" : "Ireki »%s«",
-    "%1$s shared »%2$s« with you" : "%1$serabiltzaileak »%2$s« partekatu du zurekin",
-    "%1$s shared »%2$s« with you." : "%1$serabiltzaileak »%2$s« partekatu du zurekin.",
-    "Click the button below to open it." : "Egin klik beheko botoian hura irekitzeko.",
+    "Organisation" : "Erakundea",
     "File is currently busy, please try again later" : "Fitxategia lanpetuta dago, saiatu berriro geroago",
     "Cannot download file" : "Ezin da fitxategia deskargatu",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Ziurtatu datu direktorioaren erroan \".ocdata\" izeneko fitxategia dagoela.",
-    "Path contains files shared with you" : "Bide-izenak zurekin partekatutako fitxategiak dauzka"
+    "Cannot write into \"apps\" directory." : "Ezin da idatzi \"apps\" fitxategian.",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Hau normalean konpondu daiteke web zerbitzariari aplikazioen direktorioko sarbidea emanez edo konfigurazioko fitxategian aplikazioen biltegia (App Store) desgaituz.",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code><code>%s</code>-en ezarrita dago, espero zen <code>0</code> balioaren ordez.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Arazo hau konpontzeko, ezarri<code>mbstring.func_overload</code> <code>0</code>-en zure php.ini fitxategian.",
+    "Login is too long" : "Saio hasiera luzeegia d"
 },
 "nplurals=2; plural=(n != 1);");
